/*
Copyright 2017 Google Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

'use strict';

var startTime;
var remoteVideo;

var localStream;
var pc1;

var offerOptions = {
    offerToReceiveAudio: 1,
    offerToReceiveVideo: 0
};

var socket;
function Connect(port){
    try{
        socket=new WebSocket('wss://' + location.host + ':' + port);
    }catch(e){
        alert('error');
        return;
    }
    socket.onopen = sOpen;
    socket.onerror = sError;
    socket.onmessage= sMessage;
    socket.onclose= sClose;
}
function sOpen(){
    trace('connect success!');
    trace('Requesting local stream');
    navigator.mediaDevices.getUserMedia({
        audio: true,
        video: false
    })
    .then(gotStream)
    .catch(function(e) {
        alert('getUserMedia() error: ' + e.name);
    });
}
function sError(e){
    trace("error " + e);
}

function procAnswer(Desc) {

    trace('pc1 setRemoteDescription start');
    pc1.setRemoteDescription(Desc).then(
        function() {
            onSetRemoteSuccess(pc1);
        },
        onSetSessionDescriptionError
    );
}

function sMessage(msg){
    //trace(msg.data);
    var date = JSON.parse(msg.data);

    if (date.event == 'answer') {
        procAnswer(date.data);
    } else if (date.event == 'candidate') {
        pc1.addIceCandidate(date.data)
            .then(
                function() {
                    onAddIceCandidateSuccess(pc1);
                },
                function(err) {
                    onAddIceCandidateError(pc1, err);
                }
            );
    }
}

function sClose(e){
    socket.close();
    trace("connect closed:" + e.code);
}
function Send(){
    socket.send(document.getElementById("msg").value);
}
function Close(){
    socket.close();
}

function Post(context, type) {
    var data = JSON.stringify({
        "event": type,
        "data": context
    });
    socket.send(data);
    //console.log(data);
    //trace('Post Completed!');
}


function getName(pc) {
    return (pc === pc1) ? 'pc1' : 'pc1';
}


function gotStream(stream) {
    trace('Received local stream');
    localStream = stream;
    webrtcCall();
}

function webrtcStart(port) {
    remoteVideo = document.getElementById('remoteVideo');

    Connect(port);
}

function webrtcCall() {
    trace('Starting call');
    startTime = window.performance.now();

    var audioTracks = localStream.getAudioTracks();
    if (audioTracks.length > 0) {
        trace('Using audio device: ' + audioTracks[0].label);
    }

    var servers = null;
    pc1 = new RTCPeerConnection(servers);
    trace('Created local peer connection object pc1');
    pc1.onicecandidate = function(e) {
        onIceCandidate(pc1, e);
    };

    pc1.oniceconnectionstatechange = function(e) {
        onIceStateChange(pc1, e);
    };

    pc1.addStream(localStream);
    trace('Added local stream to pc1');

    pc1.onaddstream = gotRemoteStream;

    trace('pc1 createOffer start');
    pc1.createOffer(
        offerOptions
    ).then(
        onCreateOfferSuccess,
        onCreateSessionDescriptionError
    );

}

function onCreateSessionDescriptionError(error) {
    trace('Failed to create session description: ' + error.toString());
}

function onCreateOfferSuccess(desc) {
    Post(desc,'offer');
    trace('pc1 setLocalDescription start');
    pc1.setLocalDescription(desc).then(
        function() {
            onSetLocalSuccess(pc1);
        },
        onSetSessionDescriptionError
    );
}

function onSetLocalSuccess(pc) {
    trace(getName(pc) + ' setLocalDescription complete');
}

function onSetRemoteSuccess(pc) {
    trace(getName(pc) + ' setRemoteDescription complete');
}

function onSetSessionDescriptionError(error) {
    trace('Failed to set session description: ' + error.toString());
}

function gotRemoteStream(e) {
    remoteVideo.srcObject = e.stream;
    trace('pc1 received remote stream');
}

function onIceCandidate(pc, event) {
    /*getOtherPc(pc).addIceCandidate(event.candidate)
  .then(
    function() {
      onAddIceCandidateSuccess(pc);
    },
    function(err) {
      onAddIceCandidateError(pc, err);
    }
  );*/
    if (event.candidate) Post(event.candidate, 'candidate');
    trace(getName(pc) + ' ICE candidate: \n' + (event.candidate ?
        event.candidate.candidate : '(null)'));
}

function onAddIceCandidateSuccess(pc) {
    trace(getName(pc) + ' addIceCandidate success');
}

function onAddIceCandidateError(pc, error) {
    trace(getName(pc) + ' failed to add ICE Candidate: ' + error.toString());
}

function onIceStateChange(pc, event) {
    if (pc) {
        trace(getName(pc) + ' ICE state: ' + pc.iceConnectionState);
        console.log('ICE state change event: ', event);
    }
}

function webrtcHangup() {
    trace('Ending call');
    pc1 = null;
    socket.close();
}

// logging utility
function trace(arg) {
    var now = (window.performance.now() / 1000).toFixed(3);
    console.log(now + ': ', arg);
}


