<?php

/**
 * This is the model class for table "BrdModeMember".
 *
 * The followings are the available columns in table 'BrdModeMember':
 * @property integer $DevIDMode
 * @property integer $BrdModeID
 * @property string $DeviceID
 *
 * The followings are the available model relations:
 * @property Broadcastmode $brdMode
 * @property Devicelist $device
 */
class BrdModeMember extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'BrdModeMember';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('BrdModeID, DeviceID', 'required'),
			array('BrdModeID', 'numerical', 'integerOnly'=>true),
			array('DeviceID', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('DevIDMode, BrdModeID, DeviceID', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'brdMode' => array(self::BELONGS_TO, 'Broadcastmode', 'BrdModeID'),
			'device' => array(self::BELONGS_TO, 'Devicelist', 'DeviceID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'DevIDMode' => 'Dev Idmode',
			'BrdModeID' => 'Brd Mode',
			'DeviceID' => 'Device',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('DevIDMode',$this->DevIDMode);
		$criteria->compare('BrdModeID',$this->BrdModeID);
		$criteria->compare('DeviceID',$this->DeviceID,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return BrdModeMember the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
