<?php

/**
 * This is the model class for table "DeviceList".
 *
 * The followings are the available columns in table 'DeviceList':
 * @property string $DevID
 * @property string $Dev_Name
 * @property integer $Parent
 * @property integer $DisableParentSchedule
 * @property string $Dev_Description
 * @property string $Dev_Configuration
 * @property string $CameraIpAddr
 * @property integer $CameraPort
 * @property string $CameraUser
 * @property string $CameraPasswd
 * @property integer $CameraType
 *
 * The followings are the available model relations:
 * @property Devclasses $parent
 */
class DeviceList extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'DeviceList';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('DevID', 'required'),
			array('Parent, DisableParentSchedule, CameraPort, CameraType', 'numerical', 'integerOnly'=>true),
			array('DevID', 'length', 'max'=>50),
			array('Dev_Name', 'length', 'max'=>32),
			array('Dev_Description', 'length', 'max'=>96),
			array('Dev_Configuration', 'length', 'max'=>1024),
			array('CameraIpAddr, CameraUser, CameraPasswd', 'length', 'max'=>45),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('DevID, Dev_Name, Parent, DisableParentSchedule, Dev_Description, Dev_Configuration, CameraIpAddr, CameraPort, CameraUser, CameraPasswd, CameraType', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'parent' => array(self::BELONGS_TO, 'Devclasses', 'Parent'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'DevID' => 'Dev',
			'Dev_Name' => 'Dev Name',
			'Parent' => 'Parent',
			'DisableParentSchedule' => 'Disable Parent Schedule',
			'Dev_Description' => 'Dev Description',
			'Dev_Configuration' => 'Dev Configuration',
			'CameraIpAddr' => 'Camera Ip Addr',
			'CameraPort' => 'Camera Port',
			'CameraUser' => 'Camera User',
			'CameraPasswd' => 'Camera Passwd',
			'CameraType' => 'Camera Type',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('DevID',$this->DevID,true);
		$criteria->compare('Dev_Name',$this->Dev_Name,true);
		$criteria->compare('Parent',$this->Parent);
		$criteria->compare('DisableParentSchedule',$this->DisableParentSchedule);
		$criteria->compare('Dev_Description',$this->Dev_Description,true);
		$criteria->compare('Dev_Configuration',$this->Dev_Configuration,true);
		$criteria->compare('CameraIpAddr',$this->CameraIpAddr,true);
		$criteria->compare('CameraPort',$this->CameraPort);
		$criteria->compare('CameraUser',$this->CameraUser,true);
		$criteria->compare('CameraPasswd',$this->CameraPasswd,true);
		$criteria->compare('CameraType',$this->CameraType);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return DeviceList the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
