<?php

/**
 * This is the model class for table "DeviceLog".
 *
 * The followings are the available columns in table 'DeviceLog':
 * @property string $DevLogID
 * @property string $DeviceID
 * @property string $DateTime
 * @property integer $Event
 * @property integer $State
 * @property integer $CtrlUser
 * @property string $MsgContext
 */
class DeviceLog extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'DeviceLog';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Event, State, CtrlUser', 'numerical', 'integerOnly'=>true),
			array('DeviceID', 'length', 'max'=>50),
			array('MsgContext', 'length', 'max'=>256),
			array('DateTime', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('DevLogID, DeviceID, DateTime, Event, State, CtrlUser, MsgContext', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'DevLogID' => 'Dev Log',
			'DeviceID' => 'Device',
			'DateTime' => 'Date Time',
			'Event' => 'Event',
			'State' => 'State',
			'CtrlUser' => 'Ctrl User',
			'MsgContext' => 'Msg Context',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('DevLogID',$this->DevLogID,true);
		$criteria->compare('DeviceID',$this->DeviceID,true);
		$criteria->compare('DateTime',$this->DateTime,true);
		$criteria->compare('Event',$this->Event);
		$criteria->compare('State',$this->State);
		$criteria->compare('CtrlUser',$this->CtrlUser);
		$criteria->compare('MsgContext',$this->MsgContext,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return DeviceLog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
