<?php

/**
 * This is the model class for table "EventModel".
 *
 * The followings are the available columns in table 'EventModel':
 * @property integer $id
 * @property string $Manufacturer
 * @property string $Model
 * @property integer $Magic
 *
 * The followings are the available model relations:
 * @property Event[] $events
 */
class EventModel extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'EventModel';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Manufacturer, Model, Magic', 'required'),
			array('Magic', 'numerical', 'integerOnly'=>true),
			array('Manufacturer, Model', 'length', 'max'=>31),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, Manufacturer, Model, Magic', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'events' => array(self::HAS_MANY, 'Event', 'Model'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'Manufacturer' => 'Manufacturer',
			'Model' => 'Model',
			'Magic' => 'Magic',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('Manufacturer',$this->Manufacturer,true);
		$criteria->compare('Model',$this->Model,true);
		$criteria->compare('Magic',$this->Magic);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return EventModel the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
