<?php

/**
 * This is the model class for table "Messages".
 *
 * The followings are the available columns in table 'Messages':
 * @property integer $ID
 * @property integer $MsgFrom
 * @property integer $MsgTo
 * @property integer $MsgType
 * @property string $MsgTime
 * @property integer $CmdType
 * @property integer $CmdObjType
 * @property string $CmdObjID
 * @property string $CmdObjIP
 */
class Messages extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'Messages';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('MsgFrom, MsgTo', 'required'),
			array('MsgFrom, MsgTo, MsgType, CmdType, CmdObjType', 'numerical', 'integerOnly'=>true),
			array('CmdObjID, CmdObjIP', 'length', 'max'=>50),
			array('MsgTime', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, MsgFrom, MsgTo, MsgType, MsgTime, CmdType, CmdObjType, CmdObjID, CmdObjIP', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID',
			'MsgFrom' => 'Msg From',
			'MsgTo' => 'Msg To',
			'MsgType' => 'Msg Type',
			'MsgTime' => 'Msg Time',
			'CmdType' => 'Cmd Type',
			'CmdObjType' => 'Cmd Obj Type',
			'CmdObjID' => 'Cmd Obj',
			'CmdObjIP' => 'Cmd Obj Ip',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ID',$this->ID);
		$criteria->compare('MsgFrom',$this->MsgFrom);
		$criteria->compare('MsgTo',$this->MsgTo);
		$criteria->compare('MsgType',$this->MsgType);
		$criteria->compare('MsgTime',$this->MsgTime,true);
		$criteria->compare('CmdType',$this->CmdType);
		$criteria->compare('CmdObjType',$this->CmdObjType);
		$criteria->compare('CmdObjID',$this->CmdObjID,true);
		$criteria->compare('CmdObjIP',$this->CmdObjIP,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Messages the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
