<?php

/**
 * This is the model class for table "PlayListFiles".
 *
 * The followings are the available columns in table 'PlayListFiles':
 * @property integer $PlayListFIleId
 * @property integer $FileID
 * @property integer $SequenceID
 * @property integer $SessionID
 * @property integer $Duration
 * @property integer $KeyIndex
 * @property string $PlayerID
 *
 * The followings are the available model relations:
 * @property Mediafiles $file
 * @property Playsessions $session
 */
class PlayListFiles extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'PlayListFiles';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('SequenceID, SessionID', 'required'),
			array('FileID, SequenceID, SessionID, Duration, KeyIndex', 'numerical', 'integerOnly'=>true),
			array('PlayerID', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('PlayListFIleId, FileID, SequenceID, SessionID, Duration, KeyIndex, PlayerID', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'file' => array(self::BELONGS_TO, 'Mediafiles', 'FileID'),
			'session' => array(self::BELONGS_TO, 'Playsessions', 'SessionID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'PlayListFIleId' => 'Play List File',
			'FileID' => 'File',
			'SequenceID' => 'Sequence',
			'SessionID' => 'Session',
			'Duration' => 'Duration',
			'KeyIndex' => 'Key Index',
			'PlayerID' => 'Player',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('PlayListFIleId',$this->PlayListFIleId);
		$criteria->compare('FileID',$this->FileID);
		$criteria->compare('SequenceID',$this->SequenceID);
		$criteria->compare('SessionID',$this->SessionID);
		$criteria->compare('Duration',$this->Duration);
		$criteria->compare('KeyIndex',$this->KeyIndex);
		$criteria->compare('PlayerID',$this->PlayerID,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PlayListFiles the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
