<?php

/**
 * This is the model class for table "PlaySessions".
 *
 * The followings are the available columns in table 'PlaySessions':
 * @property integer $SessionID
 * @property string $SessionName
 * @property integer $SessionType
 * @property integer $Priority
 * @property integer $Status
 * @property integer $CircleLength
 * @property integer $ClassID
 * @property string $PlayerID
 * @property integer $Parent
 * @property integer $BrdMode
 * @property integer $MemberMode
 * @property integer $StreamType
 * @property integer $SysEnabled
 * @property string $RfDevCtrl
 * @property integer $Owner
 * @property integer $PlayMode
 * @property integer $AudioGain
 * @property integer $Template
 *
 * The followings are the available model relations:
 * @property Players $player
 * @property Broadcastmode $brdMode
 * @property Playsessions $parent
 * @property Users $owner
 * @property Tasktemplate $template
 */
class PlaySessions extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'PlaySessions';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('SessionName', 'required'),
			array('SessionID, SessionType, Priority, Status, CircleLength, ClassID, Parent, BrdMode, MemberMode, StreamType, SysEnabled, Owner, PlayMode, AudioGain, Template', 'numerical', 'integerOnly'=>true),
			array('SessionName, PlayerID', 'length', 'max'=>50),
			array('RfDevCtrl', 'length', 'max'=>16),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('SessionID, SessionName, SessionType, Priority, Status, CircleLength, ClassID, PlayerID, Parent, BrdMode, MemberMode, StreamType, SysEnabled, RfDevCtrl, Owner, PlayMode, AudioGain, Template', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'player' => array(self::BELONGS_TO, 'Players', 'PlayerID'),
			'brdMode' => array(self::BELONGS_TO, 'Broadcastmode', 'BrdMode'),
			'parent' => array(self::BELONGS_TO, 'Playsessions', 'Parent'),
			'owner' => array(self::BELONGS_TO, 'Users', 'Owner'),
			'template' => array(self::BELONGS_TO, 'Tasktemplate', 'Template'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'SessionID' => 'Session',
			'SessionName' => 'Session Name',
			'SessionType' => 'Session Type',
			'Priority' => 'Priority',
			'Status' => 'Status',
			'CircleLength' => 'Circle Length',
			'ClassID' => 'Class',
			'PlayerID' => 'Player',
			'Parent' => 'Parent',
			'BrdMode' => 'Brd Mode',
			'MemberMode' => 'Member Mode',
			'StreamType' => 'Stream Type',
			'SysEnabled' => 'Sys Enabled',
			'RfDevCtrl' => 'Rf Dev Ctrl',
			'Owner' => 'Owner',
			'PlayMode' => 'Play Mode',
			'AudioGain' => 'Audio Gain',
			'Template' => 'Template',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('SessionID',$this->SessionID);
		$criteria->compare('SessionName',$this->SessionName,true);
		$criteria->compare('SessionType',$this->SessionType);
		$criteria->compare('Priority',$this->Priority);
		$criteria->compare('Status',$this->Status);
		$criteria->compare('CircleLength',$this->CircleLength);
		$criteria->compare('ClassID',$this->ClassID);
		$criteria->compare('PlayerID',$this->PlayerID,true);
		$criteria->compare('Parent',$this->Parent);
		$criteria->compare('BrdMode',$this->BrdMode);
		$criteria->compare('MemberMode',$this->MemberMode);
		$criteria->compare('StreamType',$this->StreamType);
		$criteria->compare('SysEnabled',$this->SysEnabled);
		$criteria->compare('RfDevCtrl',$this->RfDevCtrl,true);
		$criteria->compare('Owner',$this->Owner);
		$criteria->compare('PlayMode',$this->PlayMode);
		$criteria->compare('AudioGain',$this->AudioGain);
		$criteria->compare('Template',$this->Template);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PlaySessions the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
