<?php

/**
 * This is the model class for table "PlayerStatus".
 *
 * The followings are the available columns in table 'PlayerStatus':
 * @property string $PlayerID
 * @property integer $SessionID
 * @property integer $ScheduleID
 * @property string $IpAddress
 * @property integer $NetID
 * @property integer $ActualSesID
 * @property integer $PlayPort
 * @property integer $PlayType
 */
class PlayerStatus extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'PlayerStatus';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('PlayerID', 'required'),
			array('SessionID, ScheduleID, NetID, ActualSesID, PlayPort, PlayType', 'numerical', 'integerOnly'=>true),
			array('PlayerID, IpAddress', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('PlayerID, SessionID, ScheduleID, IpAddress, NetID, ActualSesID, PlayPort, PlayType', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'PlayerID' => 'Player',
			'SessionID' => 'Session',
			'ScheduleID' => 'Schedule',
			'IpAddress' => 'Ip Address',
			'NetID' => 'Net',
			'ActualSesID' => 'Actual Ses',
			'PlayPort' => 'Play Port',
			'PlayType' => 'Play Type',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('PlayerID',$this->PlayerID,true);
		$criteria->compare('SessionID',$this->SessionID);
		$criteria->compare('ScheduleID',$this->ScheduleID);
		$criteria->compare('IpAddress',$this->IpAddress,true);
		$criteria->compare('NetID',$this->NetID);
		$criteria->compare('ActualSesID',$this->ActualSesID);
		$criteria->compare('PlayPort',$this->PlayPort);
		$criteria->compare('PlayType',$this->PlayType);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PlayerStatus the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
