<?php
class SysDevController extends WebAdminBaseController {
	
	////////////////////////////////////////////////////////////
	//基本信息
	///////////////////////////////////////////////////////////
	/**
	 * 加载基本信息
	 */
	public function actionLoadBaseInfo() {
		
		$out = ASysDevUtil::loadBaseInfo ();
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $out );
	}
	
	/**
	 * 修改基本信息
	 */
	public function actionUpdateBaseInfo() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$SchoolName = $this->GetDataParam ( $DataParam, "SchoolName", "" ); //组织名字
		$ModeOne = $this->GetDataParam ( $DataParam, "ModeOne", "" ); //模式1
		$ModeTwo = $this->GetDataParam ( $DataParam, "ModeTwo", "" ); //模式2
		$ModeThree = $this->GetDataParam ( $DataParam, "ModeThree", "" ); //模式3
		$ModeFour = $this->GetDataParam ( $DataParam, "ModeFour", "" ); //模式4
		

		$sql = "UPDATE BaseInfo SET Description = :Description WHERE InfomationID = 0";
		DBMethodUtils::RunSql ( $sql, array (':Description' => $SchoolName ) );
		
		$sql = "UPDATE BaseInfo SET Description = :Description WHERE InfomationID = 1";
		DBMethodUtils::RunSql ( $sql, array (':Description' => $ModeOne ) );
		
		$sql = "UPDATE BaseInfo SET Description = :Description WHERE InfomationID = 2";
		DBMethodUtils::RunSql ( $sql, array (':Description' => $ModeTwo ) );
		
		$sql = "UPDATE BaseInfo SET Description = :Description WHERE InfomationID = 3";
		DBMethodUtils::RunSql ( $sql, array (':Description' => $ModeThree ) );
		
		$sql = "UPDATE BaseInfo SET Description = :Description WHERE InfomationID = 4";
		DBMethodUtils::RunSql ( $sql, array (':Description' => $ModeFour ) );
		
		$out = ASysDevUtil::loadBaseInfo ();
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $out );
	}
	
	////////////////////////////////////////////////////////////
	//物联设置
	///////////////////////////////////////////////////////////
	/**
	 * 加载物联设备信息
	 */
	public function actionListDevRefInfo() {
		
		////////////////////////////////////////////
		// Type = 0:空调控制器
		// Type = 1:电源开关
		///////////////////////////////////////////
		$sql = "SELECT PwrID, Name, Type FROM PwrDisplaySet ORDER BY PwrID ASC";
		$OutList = DBMethodUtils::listData ( $sql );
		
		if (empty ( $OutList )) {
			$sql = "INSERT INTO PwrDisplaySet(PwrID)VALUES";
			$insert = array ();
			
			for($i = 2; $i <= 15; $i ++) {
				$insert [] = "(" . $i . ")";
				$OutList [] = array ('Name' => '', 'PwrID' => $i, 'Type' => '' );
			}
			$sql .= implode ( ",", $insert );
			DBMethodUtils::RunSql ( $sql );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $OutList );
	}
	
	/**
	 * 更新物联设备信息
	 */
	public function actionUpdateDevRefInfo() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		foreach ( $DataParam as $item ) {
			$PwrID = $this->GetDataParam ( $item, 'PwrID', - 1, true );
			$Name = $this->GetDataParam ( $item, 'Name', "" );
			$Type = $this->GetDataParam ( $item, 'Type', - 1, true );
			
			if ($PwrID < 2 || $PwrID > 15) {
				continue;
			}
			$ParamArr = array ();
			
			if (empty ( $Name ) || ! in_array ( $Type, array (0, 1 ) )) {
				$sql = 'UPDATE PwrDisplaySet SET Name = "", Type = NULL WHERE PwrID = :PwrID';
				$ParamArr [':PwrID'] = $PwrID;
			} else {
				$sql = 'UPDATE PwrDisplaySet SET Name = :Name, Type = :Type WHERE PwrID = :PwrID';
				$ParamArr [':Name'] = $Name;
				$ParamArr [':Type'] = $Type;
				$ParamArr [':PwrID'] = $PwrID;
			}
			DBMethodUtils::RunSql ( $sql, $ParamArr );
		}
		
		$sql = "SELECT PwrID, Name, Type FROM PwrDisplaySet ORDER BY PwrID ASC";
		$OutList = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $OutList );
	}
	
	////////////////////////////////////////////////////////////
	//分区设置
	///////////////////////////////////////////////////////////
	

	/**
	 * 加载分区数据
	 */
	public function actionLoadDeviceClassInfo() {
		
		$UserId = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserId ) && $UserId < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		$ClassTree = ADeviceUtils::LoadDeviceClassTree ( $UserId ); //获取设备分组
		$DeviceTree = ADeviceUtils::LoadDeviceTree ( $UserId, true ); //设备树形结构

		$Out = array ();
		$Out ['DeviceClassTree'] = $ClassTree;
		$Out ['DeviceTree'] = $DeviceTree;
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $Out );
	}
	
	/**
	 * 更新分区数据
	 */
	public function actionUpdateDeviceClassInfo() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam,参数是一个树形结构：包括字段：id、text、
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//更新分区数据
		$ClassIdArr = ASysDevUtil::UpdateDeviceClass ( null, $DataParam );
		
		if (empty ( $ClassIdArr )) {
			//清除设备分区
			$sql = "UPDATE DeviceList SET Parent = NULL";
			DBMethodUtils::RunSql ( $sql );
			
			//删除所有的分区
			$sql = "DELETE FROM DevClasses";
			DBMethodUtils::RunSql ( $sql );
		} else {
			//清除部分设备分区
			$sql = "UPDATE DeviceList SET Parent = NULL WHERE Parent NOT IN(" . implode ( ",", $ClassIdArr ) . ")";
			DBMethodUtils::RunSql ( $sql );
			
			//删除部分的分区
			$sql = "DELETE FROM DevClasses WHERE ClassID NOT IN(" . implode ( ",", $ClassIdArr ) . ")";
			DBMethodUtils::RunSql ( $sql );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", null );
	}
	
	/**
	 * 编辑分区
	 */
	public function actionEditDevClass() {
		
		$UserId = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserId ) && $UserId < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! is_null ( $UserId ) || $UserId > 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Parent = $this->GetDataParam ( $DataParam, 'Parent', null, true ); //所属父节点
		$DevClassId = $this->GetDataParam ( $DataParam, 'DevClassId', null, true ); //分区id，新建不需要
		$Name = $this->GetDataParam ( $DataParam, 'Name', "" ); //分区名字
		

		if (empty ( $Name )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '需要分区名字！', null );
			return;
		}
		$DevClass = null;
		
		if (! empty ( $DevClassId )) {
			$DevClass = DevClasses::model ()->findByPk ( $DevClassId );
		}
		
		if (empty ( $DevClass )) {
			$DevClass = new DevClasses ();
		}
		$DevClass->Name = $Name;
		$DevClass->Parent = $Parent;
		
		if (! empty ( $Parent )) {
			$temp = DevClasses::model ()->findByPk ( $Parent );
			
			if (empty ( $temp )) {
				$DevClass->Parent = null;
			}
		}
		if ($Parent == $DevClassId) {
			$DevClass->Parent = null;
		}
		
		if (! $DevClass->save ()) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '编辑失败', null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '编辑成功！', null );
	}
	
	/**
	 * 删除分区
	 */
	public function actionDeleteDevClass() {
		
		$UserId = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserId ) && $UserId < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! is_null ( $UserId ) || $UserId > 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DevClassId = $this->GetDataParam ( $DataParam, 'DevClassId', null, true ); //分区id
		

		//删除分区
		ASysDevUtil::deleteDevClass ( $DevClassId );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '删除完成', null );
	}
	
	/**
	 * 设备和分区移动
	 */
	public function actionMoveDevices() {
		
		$UserId = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserId ) && $UserId < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! is_null ( $UserId ) || $UserId > 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DevClassIds = $this->GetDataParam ( $DataParam, 'DevClassIds', "" ); //需要移动的设备或分区id，多个用“，”分割
		$DevIds = $this->GetDataParam ( $DataParam, 'DevIds', "" ); //需要移动的设备或分区id，多个用“，”分割
		$Parent = $this->GetDataParam ( $DataParam, 'Parent', 0, true ); //目的分区的id
		

		$temp = DevClasses::model ()->findByPk ( $Parent );
		
		if (empty ( $temp )) {
			$Parent = null;
		}
		$DevIdArr = array ();
		$DevClassIdArr = array ();
		
		if (! empty ( $DevClassIds )) {
			$TempArr = explode ( ",", $DevClassIds );
			
			foreach ( $TempArr as $item ) {
				if (! empty ( $item )) {
					$DevClassIdArr [] = $item;
				}
			}
		}
		if (! empty ( $DevIds )) {
			$TempArr = explode ( ",", $DevIds );
			
			foreach ( $TempArr as $item ) {
				if (! empty ( $item )) {
					$DevIdArr [] = $item;
				}
			}
		}
		
		if (empty ( $DevClassIdArr ) && empty ( $DevIdArr )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '移动失败！', null );
			return;
		}
		if (! empty ( $DevClassIdArr )) { //移动分区
			$sql = "UPDATE DevClasses SET Parent = ";
			$ParamArr = array ();
			
			if (empty ( $Parent )) {
				$sql .= " NULL ";
			} else {
				$sql .= " :Parent ";
				$ParamArr [':Parent'] = $Parent;
			}
			$sql .= " WHERE ClassID IN(" . implode ( ",", $DevClassIdArr ) . ")";
			DBMethodUtils::RunSql ( $sql, $ParamArr );
		}
		if (! empty ( $DevIdArr )) { //移动设备
			$sql = "UPDATE DeviceList SET Parent = ";
			$ParamArr = array ();
			
			if (empty ( $Parent )) {
				$sql .= " NULL ";
			} else {
				$sql .= " :Parent ";
				$ParamArr [':Parent'] = $Parent;
			}
			$sql .= " WHERE DevID IN(" . implode ( ",", $DevIdArr ) . ")";
			DBMethodUtils::RunSql ( $sql, $ParamArr );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '移动完成', null );
	}
	
	/**
	 * 加载分区下的设备和分组 
	 */
	public function actionListDevicesForClass() {
		
		$UserId = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserId ) && $UserId < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! is_null ( $UserId ) || $UserId > 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Parent = $this->GetDataParam ( $DataParam, 'Parent', null, true ); //分组id，顶级传空
		

		//获取分区下的分区
		$ParamArr = array ();
		$sql = "SELECT ClassID AS id, Name AS text, 0 AS isDevice FROM DevClasses WHERE ";
		
		if (is_null ( $Parent )) {
			$sql .= " ISNULL(Parent)";
		} else {
			$ParamArr [':Parent'] = $Parent;
			$sql .= " Parent = :Parent";
		}
		$DevClass = DBMethodUtils::listData ( $sql, $ParamArr );
		$DevClass = empty ( $DevClass ) ? array () : $DevClass;
		
		//获取分区下的设备
		$ParamArr = array ();
		$sql = "SELECT DevID AS id, Dev_Name AS text, 1 AS isDevice FROM DeviceList WHERE ";
		
		if (is_null ( $Parent )) {
			$sql .= " ISNULL(Parent)";
		} else {
			$ParamArr [':Parent'] = $Parent;
			$sql .= " Parent = :Parent";
		}
		$Devices = DBMethodUtils::listData ( $sql, $ParamArr );
		$Devices = empty ( $Devices ) ? array () : $Devices;
		
		$Out = array_merge ( $DevClass, $Devices );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '完成', $Out );
	}
}