<?php
class SysRTMPController extends WebAdminBaseController {
	
	/**
	 * 获取RTMP配置列表 
	 */
	public function actionList() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		//服务器名称、服务器URL
		$sql = "SELECT id, name, server FROM SrsServer";
		
		//获取总数
		$CountSql = "SELECT COUNT(*) c FROM (" . $sql . ") cc";
		$AllCount = 0;
		$AllCountData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $AllCountData ['c'] )) {
			$AllCount = $AllCountData ['c'];
		}
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			if ("id" == $Sort) {
				$sql .= " ORDER BY id " . $Order;
			} else if ("name" == $Sort) {
				$sql .= " ORDER BY name " . $Order;
			} else if ("server" == $Sort) {
				$sql .= " ORDER BY server " . $Order;
			} else {
				$sql .= " ORDER BY id " . $Order;
			}
		} else {
			$sql .= " ORDER BY id " . $Order;
		}
		
		if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql .= " LIMIT " . $Start . "," . $Size;
		}
		$OutList = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", array ('Total' => $AllCount, 'Rows' => $OutList ) );
	
	}
	
	/**
	 * 获取配置信息
	 */
	public function actionInfo() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //配置id
		

		$data = SrsServer::model ()->findByPk ( $id );
		
		if (empty ( $data )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '数据获取失败', null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $data );
		return;
	}
	
	/**
	 * 编辑配置信息
	 */
	public function actionEdit() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //配置id
		$name = $this->GetDataParam ( $DataParam, 'name', "" ); //名字
		$server = $this->GetDataParam ( $DataParam, 'server', "" ); //服务器
		

		//校验数据
		if (is_null ( $name ) || $name == "" || strlen ( $name ) > 31) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_NAME_ERR, '服务器名称为空或太长', null );
			return;
		}
		if (is_null ( $server ) || $server == "") {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_ERR, '服务器地址不能为空', null );
			return;
		}
		$tmpArr = explode ( $server, ":" );
		$length = count ( $tmpArr );
		
		if ($length > 2) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_INVILID, '请输入有效的服务器地址', null );
			return;
		} else if ($length == 2) {
			$host = $server [0];
			$port = $server [1];
			
			if (ToolUtil::CheckTLD ( $host )) {
				echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_HOST_INVILID, '请输入有效的服务器域名', null );
				return;
			}
			if (! is_numeric ( $port ) || $port <= 0 || $port >= 65536) {
				echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_PORT_INVILID, '请输入有效的服务器端口', null );
				return;
			}
		} else if ($length == 1) {
			$host = $server [0];
			
			if (ToolUtil::CheckTLD ( $host )) {
				echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_HOST_INVILID, '请输入有效的服务器域名', null );
				return;
			}
		} else {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_INVILID, '请输入有效的服务器地址', null );
			return;
		}
		$data = SrsServer::model()->findByAttributes(array('server' => $server));

		if (!empty($data) && $data['id'] != $id) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_RTMP_SERVER_EXIST, '服务器地址已经存在了', null );
			return;
		}
		$data = SrsServer::model ()->findByPk ( $id );
		
		if (empty ( $data )) {
			$data = new SrsServer ();
		}
		$data->name = $name;
		$data->server = $server;
		
		if ($data->save ()) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '保存成功', null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '保存失败', null );
	}
	
	/**
	 * 删除配置 
	 */
	public function actionRemove() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$ids = $this->GetDataParam ( $DataParam, 'ids', null ); //配置id数组
		

		if (empty ( $ids ) || ! is_array ( $ids )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$sql = 'DELETE FROM SrsServer WHERE id IN(' . implode ( $ids, ',' ) . ')';
		DBMethodUtils::RunSql ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '删除成功', null );
	}
}