<?php
class SysTaskController extends WebAdminBaseController {
	
	////////////////////////////////////////////
	// 任务模板
	////////////////////////////////////////////
	/**
	 * 加载任务模板
	 */
	public function actionTaskTemplateList() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		$sql = "SELECT idTaskTemplate AS id, TemplateName AS Name, IF(ISNULL(c.InfoValue), 0, 1) AS Enabled, IF(ISNULL(TaskCount), 0, TaskCount) AS TaskCount FROM TaskTemplate a 
			LEFT JOIN (SELECT COUNT(*) AS TaskCount, Template FROM PlaySessions WHERE NOT ISNULL(Template) AND Template >= 0 AND (ISNULL(BrdMode) OR BrdMode <= 0) GROUP BY Template) b ON a.idTaskTemplate = b.Template
			LEFT JOIN BaseInfo c ON c.InfomationID = 0x101 AND c.InfoValue = a.idTaskTemplate";
		
		//获取总数
		$CountSql = "SELECT COUNT(*) c FROM (" . $sql . ") cc";
		$AllCount = 0;
		$AllCountData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $AllCountData ['c'] )) {
			$AllCount = $AllCountData ['c'];
		}
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			if ("id" == $Sort) {
				$sql .= " ORDER BY idTaskTemplate " . $Order;
			} else if ("Name" == $Sort) {
				$sql .= " ORDER BY TemplateName " . $Order;
			} else if ("TaskCount" == $Sort) {
				$sql .= " ORDER BY TaskCount " . $Order;
			} else {
				$sql .= " ORDER BY idTaskTemplate ASC";
			}
		} else {
			$sql .= " ORDER BY idTaskTemplate ASC";
		}
		
		if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql .= " LIMIT " . $Start . "," . $Size;
		}
		$OutList = DBMethodUtils::listData ( $sql );
		
		if (! empty ( $OutList )) {
			foreach ( $OutList as $key => $item ) {
				if ($item ['id'] == 0 && empty ( $item ['Name'] )) {
					$OutList [$key] ['Name'] = $this->getStr ( 'appcommon', 'default' );
				}
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", array ('Total' => $AllCount, 'Rows' => $OutList ) );
	}
	
	/**
	 * 编辑模板
	 */
	public function actionTaskTemplateEdit() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //模板id
		$Name = $this->GetDataParam ( $DataParam, 'Name', "" ); //模板名字
		

		$Template = TaskTemplate::model ()->findByPk ( $id );
		
		if (empty ( $Template )) {
			$Template = new TaskTemplate ();
		}
		$Template->TemplateName = $Name;
		
		if ($Template->save ()) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "失败", null );
	}
	
	/**
	 * 模板启用/停用
	 */
	public function actionTaskTemplateEnabled() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //模板id
		$Enabled = $this->GetDataParam ( $DataParam, 'Enabled', 0, true ); //启用/停用，1：启用；0：停用
		$Enabled = $Enabled == 1 ? 1 : 0;
		
		if ($Enabled != 1) {
			$id = - 1;
		}
		$ParamArr = array();
		$sql = "UPDATE BaseInfo SET InfoValue = :InfoValue WHERE InfomationID = 0x101";
		$ParamArr[':InfoValue'] = $id;
		DBMethodUtils::RunSql ( $sql, $ParamArr );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", null );
	}
	
	/**
	 * 模板删除
	 */
	public function actionTaskTemplateDelete() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		// 有任务的模板不能删除
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$ids = $this->GetDataParam ( $DataParam, 'ids', "" ); //模板id，多个格式：1，2，3
		

		if (empty ( $ids )) { //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "请选择需要删除的模板", null );
			return;
		}
		$arr = array ();
		$idArr = explode ( ',', $ids );
		
		foreach ( $idArr as $item ) {
			if (is_numeric ( $item )) {
				if ($item == 0) {
					echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "存在不能删除的模板", null );
					return;
				}
				$arr [] = $item;
			}
		}
		if (empty ( $arr )) { //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "请选择需要删除的模板", null );
			return;
		}
		//获取有任务的模板
		$sql = "SELECT * FROM TaskTemplate WHERE idTaskTemplate IN(SELECT Template FROM PlaySessions) AND idTaskTemplate IN(" . implode ( ",", $arr ) . ")";
		$Temp = DBMethodUtils::listData ( $sql );
		
		if (! empty ( $Temp )) { //存在还有任务的模板，不能删除 //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "存在还有任务的模板，不能删除", null );
			return;
		}
		$sql = "DELETE FROM TaskTemplate WHERE idTaskTemplate !='0' AND idTaskTemplate IN(" . implode ( ",", $arr ) . ")";
		DBMethodUtils::RunSql ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", null );
	}
	
	/**
	 * 模板拷贝
	 */
	public function actionTaskTemplateCopy() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //模板id

		$sql = "call sp_copy_template(:id);";
		$code = DBMethodUtils::RunSql ( $sql, array(':id' => $id) );
		
//		if ($code <= 0) { //TODO
//			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "拷贝失败", null );
//			return;
//		}

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", null );
	}
	
	////////////////////////////////////////////
	// 运行/备用模式
	////////////////////////////////////////////
	

	/**
	 * 获取运行模式
	 */
	public function actionModeEnabledList() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", ASysTaskUtil::ListMode ( 1, $Start, $Size, $Sort, $Order ) );
	
	}
	
	/**
	 * 获取备用模式
	 */
	public function actionModeDisabledList() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", ASysTaskUtil::ListMode ( 0, $Start, $Size, $Sort, $Order ) );
	}
	
	/**
	 * 获取模式详情 
	 */
	public function actionLoadModeInfo() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$ModeId = $this->GetDataParam ( $DataParam, 'ModeId', - 1, true ); //模式id
		

		//获取模式数据
		$Mode = BroadcastMode::model ()->findByPk ( $ModeId );
		
		if (empty ( $Mode )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Out = array ();
		$Out ['ModeId'] = $Mode->idBroadcastMode; //模式id
		$Out ['ModeName'] = $Mode->ModeName; //模式名字
		$Out ['Priority'] = $Mode->Priority; //优先级 0- 100
		//		$Out['Enabled'] = $Mode->Enabled; //
		$Out ['StartTime'] = date ( "H:i:s", strtotime ( $Mode->StartTime ) ); //开始时间
		$Out ['StopTime'] = date ( "H:i:s", strtotime ( $Mode->StopTime ) ); //结束时间
		$Out ['UseDate'] = date ( "Y-m-d", strtotime ( $Mode->StartTime ) ); //指定日期
		$Out ['TimeStyle'] = $Mode->TimeStyle; //日期模式，0：指定日期；其他按位处理，1：周一，2：周二，4：周三，8：周四，16：周五，32：周六；64：周日
		

		if ($Mode->TimeStyle == 0) { //指定日期
			$Out ['TimeStyle'] = 1;
		} else { //按周重复
			$Out ['TimeStyle'] = 2;
			$TimeStyleArr = array ();
			
			if (($Mode->TimeStyle & 1) > 0) {
				$TimeStyleArr [] = 0;
			}
			if (($Mode->TimeStyle & 2) > 0) {
				$TimeStyleArr [] = 1;
			}
			if (($Mode->TimeStyle & 4) > 0) {
				$TimeStyleArr [] = 2;
			}
			if (($Mode->TimeStyle & 8) > 0) {
				$TimeStyleArr [] = 3;
			}
			if (($Mode->TimeStyle & 16) > 0) {
				$TimeStyleArr [] = 4;
			}
			if (($Mode->TimeStyle & 32) > 0) {
				$TimeStyleArr [] = 5;
			}
			if (($Mode->TimeStyle & 64) > 0) {
				$TimeStyleArr [] = 6;
			}
			$Out ['UseDate'] = implode ( ",", $TimeStyleArr );
		}
		
//		$sql = 'SELECT CONCAT("DEV_CLS_", ClassID) AS id, Name, IF(ISNULL(Parent), "DEV_CLS_0", CONCAT("DEV_CLS_", Parent)) AS Parent, 0 AS State, 
//			0 AS IsDevice, false AS checked FROM DevClasses
//			UNION ALL(
//				SELECT DevID AS id, Dev_Name AS Name, IF(ISNULL(Parent), "DEV_CLS_0", CONCAT("DEV_CLS_", Parent)) AS Parent, IF(ISNULL(b.DeviceID), 0, 1) AS State, 
//				1 AS IsDevice, IF(ISNULL(b.BrdModeID) OR b.BrdModeID <= 0, false, true) AS checked FROM DeviceList a 
//				LEFT JOIN BrdModeMember b ON a.DevID = b.DeviceID AND b.BrdModeID = "' . $Mode->idBroadcastMode . '"
//			) ORDER BY Parent ASC, IsDevice ASC';
//		$Devices = DBMethodUtils::listData ( $sql );
//		
//		if (! empty ( $Devices )) {
//			foreach ( $Devices as $key => $item ) {
//				$Devices [$key] ['checked'] = ( bool ) $item ['checked'];
//			}
//		}
//		$TreeArr = new BuildTreeArray ( $Devices, 'id', 'Parent', 'DEV_CLS_0' );
		$Out ['Members'] = ASysTaskUtil::LoadModeDevice($Mode->idBroadcastMode, $UserID);
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	/**
	 * 添加/修改模式
	 */
	public function actionModeEdit() {
		
		/*
		 {
		 "idBroadcastMode":"广播模式ID",
		 "ModeName":"模式名",
		 "Priority":"优先级，默认是10",
		 "Enabled":"可用状态，默认是0不可用（备用模式），1可用（运行模式）。",
		 "StartTime":"开始时间,2015-10-28 18:00:00",
		 "StopTime":"结束时间,2015-11-28 18:00:00",
		 "TimeStyle":"时间类型，0的意思是通过开始时间和结束时间来代替一天的开始和结束（StartTime，StopTime使用年月日时分秒），另外的意思是周期性的，8位字节的低7位来代表一周7天，bit1星期一，bit2星期二，bit7表示星期天，以此类推（StartTime，StopTime仅使用时分秒）。默认是0仅一天",
		 "BrdModeMember":[
		 {
		 "DeviceID":"设备id（字符串）"
		 },
		 {
		 "DeviceID":"设备id（字符串）"
		 }
		 ]
		 }
		 */
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, "id", - 1, true ); //模式id，新建为空
		$Enabled = $this->GetDataParam ( $DataParam, "Enabled", 0, true ); //1：运行模式，0：备用模式
		$Name = $this->GetDataParam ( $DataParam, "Name", "" ); //模式名字
		$Priority = $this->GetDataParam ( $DataParam, "Priority", 0, true ); //优先级，0-100
		$StartTime = $this->GetDataParam ( $DataParam, "StartTime", "" ); //开始时间，格式：18:20:20
		$StopTime = $this->GetDataParam ( $DataParam, "StopTime", "" ); //结束时间，格式：18:20:20
		$TimeType = $this->GetDataParam ( $DataParam, "TimeType", 0, true ); //日期类型，1：指定日期，2：按周期重复
		$TimeDate = $this->GetDataParam ( $DataParam, "TimeDate", "" ); //日期/周期，日期格式：2017-01-20；周期：0-6星期一到星期日，中间“，”分割
		$ModeMember = $this->GetDataParam ( $DataParam, "ModeMember", null ); //模式成员，["设备id", "设备id"]
		

		//校验时间
		if (! preg_match ( "/^(\d|0\d|1\d|2[0-4]):([0-5]\d|\d):(\d|[0-5]\d)$/s", $StartTime )) { //开始时间不正确 //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "开始时间不正确", null );
			return;
		}
		if (! preg_match ( "/^(\d|0\d|1\d|2[0-4]):([0-5]\d|\d):(\d|[0-5]\d)$/s", $StopTime )) { //结束时间不正确 //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "结束时间不正确", null );
			return;
		}
		
		if ($TimeType == 1) { //按照指定日期
			//校验日期格式
			if (! preg_match ( "/^(19|20)\d{2}-(0?\d|1[012])-(0?\d|[12]\d|3[01])$/s", $TimeDate )) { //日期格式不对 //TODO
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "日期格式不对", null );
				return;
			}
			$TimeType = 0;
			$StartTime = $TimeDate . ' ' . $StartTime;
			$StopTime = $TimeDate . ' ' . $StopTime;
			
			if ($StopTime <= $StartTime) { //结束时间必须大于开始时间 //TODO
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "结束时间必须大于开始时间", null );
				return;
			}
		} else if ($TimeType == 2) { //按周期重复
			if (empty ( $TimeDate ) && $TimeDate != "0") { //请选择星期 //TODO
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "请选择星期", null );
				return;
			}
			$arr = explode ( ",", $TimeDate );
			$TimeType = 0;
			$StartTime = date ( 'Y-m-d' ) . ' ' . $StartTime;
			$StopTime = date ( 'Y-m-d' ) . ' ' . $StopTime;
			
			foreach ( $arr as $item ) {
				switch (intval ( $item )) {
					case 0 : //周一
						$TimeType += 1;
						break;
					case 1 : //周二
						$TimeType += 2;
						break;
					case 2 : //周三
						$TimeType += 4;
						break;
					case 3 : //周四
						$TimeType += 8;
						break;
					case 4 : //周五
						$TimeType += 16;
						break;
					case 5 : //周六
						$TimeType += 32;
						break;
					case 6 : //周日
						$TimeType += 64;
						break;
					default :
						break;
				}
			}
			if ($TimeType <= 0) { //请选择星期 //TODO
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "请选择星期", null );
				return;
			}
		} else {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "", null );
			return;
		}
		$Enabled = $Enabled == 1 ? 1 : $Enabled;
		$Priority = $Priority <= 0 ? 0 : $Priority;
		$Priority = $Priority >= 100 ? 100 : $Priority;
		
		if (is_numeric ( $id ) && $id > 0) {
			//修改模式
			$UpdateParam = array ();
			$UpdateParam ["ModeName"] = $Name; //模式名",
			$UpdateParam ["Priority"] = $Priority; //优先级，默认是10",
			$UpdateParam ["Enabled"] = $Enabled; //可用状态，默认是0不可用（备用模式），1可用（运行模式）。",
			$UpdateParam ["StartTime"] = $StartTime; //开始时间,2015-10-28 18:00:00",
			$UpdateParam ["StopTime"] = $StopTime; //结束时间,2015-11-28 18:00:00",
			$UpdateParam ["TimeStyle"] = $TimeType; //时间类型，0的意思是通过开始时间和结束时间来代替一天的开始和结束（StartTime，StopTime使用年月日时分秒），另外的意思是周期性的，8位字节的低7位来代表一周7天，bit1星期一，bit2星期二，bit7表示星期天，以此类推（StartTime，StopTime仅使用时分秒）。默认是0仅一天",
			

			BroadcastMode::model ()->updateByPk ( $id, $UpdateParam );
		} else {
			//新建模式
			$BroadcastMode = new BroadcastMode ();
			
			$BroadcastMode->ModeName = $Name; //模式名",
			$BroadcastMode->Priority = $Priority; //优先级，默认是10",
			$BroadcastMode->Enabled = $Enabled; //可用状态，默认是0不可用（备用模式），1可用（运行模式）。",
			$BroadcastMode->StartTime = $StartTime; //开始时间,2015-10-28 18:00:00",
			$BroadcastMode->StopTime = $StopTime; //结束时间,2015-11-28 18:00:00",
			$BroadcastMode->TimeStyle = $TimeType; //时间类型，0的意思是通过开始时间和结束时间来代替一天的开始和结束（StartTime，StopTime使用年月日时分秒），另外的意思是周期性的，8位字节的低7位来代表一周7天，bit1星期一，bit2星期二，bit7表示星期天，以此类推（StartTime，StopTime仅使用时分秒）。默认是0仅一天",
			

			if (! $BroadcastMode->save ()) {
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '新建模式失败', null );
				return;
			}
			$id = $BroadcastMode->idBroadcastMode;
		}
		//处理模式成员
		if (! empty ( $ModeMember )) {
			$sql = 'SELECT DevID, ActualSessionID FROM DeviceList a LEFT JOIN DeviceStatus b ON a.DevID = b.DeviceID WHERE DevID IN(' . implode ( ",", $ModeMember ) . ')';
			$Devices = DBMethodUtils::listData ( $sql );
			
			$UseDevIDs = "";
			$tempArr = array ();
			
			if (! empty ( $Devices )) {
				foreach ( $Devices as $item ) {
					if (! empty ( $item ['DevID'] )) {
						$tempArr [] = $item ['DevID'];
					}
				}
			}
			$UseDevIDs = implode ( ",", $tempArr );
			
			if (strlen ( $UseDevIDs ) > 0) {
				//删除不用的成员
				$sql = "DELETE FROM BrdModeMember WHERE BrdModeID=:BrdModeID AND DeviceID NOT IN(" . $UseDevIDs . ")";
				DBMethodUtils::RunSql ( $sql, array(':BrdModeID' => $id) );
			} else {
				$sql = "DELETE FROM BrdModeMember WHERE BrdModeID=:BrdModeID";
				DBMethodUtils::RunSql ( $sql, array(':BrdModeID' => $id)  );
			}
			$arr = array ();
			
			foreach ( $tempArr as $item ) {
				$sql = "Insert into BrdModeMember(DeviceID, BrdModeID) values (:DeviceID,:BrdModeID) on duplicate key update BrdModeID = values(BrdModeID);";
				$arr [] = $sql;
				DBMethodUtils::RunSql ( $sql, array(':DeviceID' => $item, ':BrdModeID' => $id)  );
			}
		} else {
			//删除模式的所有成员
			$sql = "DELETE FROM BrdModeMember WHERE BrdModeID=:BrdModeID";
			DBMethodUtils::RunSql ( $sql, array(':BrdModeID' => $id)  );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', null );
	
	}
	
	/**
	 * 删除模式
	 */
	public function actionModeDelete() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		// 有任务的模式不能删除
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$ids = $this->GetDataParam ( $DataParam, 'ids', "" ); //需要删除的模式id，格式：id，id
		

		if (empty ( $ids )) { //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '请选择需要删除的模式！', null );
			return;
		}
		$arr = array ();
		$idArr = explode ( ',', $ids );
		
		foreach ( $idArr as $item ) {
			if (is_numeric ( $item )) {
				$arr [] = $item;
			}
		}
		if (empty ( $arr )) { //TODO
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "请选择需要删除的模式", null );
			return;
		}
		
		$sql = "SELECT * FROM BroadcastMode WHERE idBroadcastMode IN(SELECT BrdMode FROM PlaySessions) AND idBroadcastMode IN(" . implode ( ",", $arr ) . ")";
		$Temp = DBMethodUtils::listData ( $sql );
		
		if (! empty ( $Temp )) { //TODO 存在还有任务的模式，不能删除
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '存在还有任务的模式，不能删除！', null );
			return;
		}
		//删除模式
		$sql = "DELETE FROM BroadcastMode WHERE idBroadcastMode IN(" . implode ( ",", $arr ) . ")";
		DBMethodUtils::RunSql ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", null );
	}
	
	/**
	 * 模式开启或停止 
	 */
	public function actionModeStartOrStop() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		// 只有运行模式才能开启停止
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //模式id
		$active = $this->GetDataParam ( $DataParam, 'active', 0, true ); //1:开始，0：停止
		$active = $active == 1 ? 1 : 0;
		$Mode = BroadcastMode::model ()->findByPk ( $id );
		
		if (empty ( $Mode ) || $Mode->Enabled != 1) { //模式不存在或则模式不是运行模式
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '模式不存在或则模式不是运行模式！', null );
			return;
		}
		$UpdateParam = array ();
		$UpdateParam ['Active'] = $active;
		
		BroadcastMode::model ()->updateByPk ( $id, $UpdateParam );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", null );
	}
	
	/**
	 * 模式启用或停用
	 */
	public function actionModeEnabledOrDisabled() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		$id = $this->GetDataParam ( $DataParam, 'id', "" ); //模式id
		$enabled = $this->GetDataParam ( $DataParam, 'enabled', 0, true ); //1:启用，0：停用
		$enabled = $enabled == 1 ? 1 : 0;
		
		if ($id == null) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
			return;
		}
		
		$tempArr = explode(",", $id);
		$Arr = array();
		
		foreach ($tempArr as $item) {
			if (is_numeric($item)) {
				$Arr[] = $item;
			}
		}
		if(empty($Arr)) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
			return;
		}
		
		$sql = "UPDATE BroadcastMode SET Enabled = '" . $enabled . "' WHERE idBroadcastMode IN(" . implode(",", $Arr) . ")";
		DBMethodUtils::RunSql($sql);
//		
//		$Mode = BroadcastMode::model ()->findByPk ( $id );
//		$UpdateParam = array ();
//		$UpdateParam ['Enabled'] = $enabled;
//		
//		BroadcastMode::model ()->updateByPk ( $id, $UpdateParam );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", null );
	}
	
	/**
	 * 模板拷贝
	 */
	public function actionModeCopy() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'id', - 1, true ); //模式id
		$Enable = $this->GetDataParam ( $DataParam, 'Enable', 0, true ); //是否是运行模式，1：是：0：否

		$sql = "call sp_copy_mode(:id," . ($Enable == 1 ? "true" : "false") . ");";
		$code = DBMethodUtils::RunSql ( $sql, array(":id" => $id) );
		
//		if ($code <= 0) { //TODO
//			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "拷贝失败", null );
//			return;
//		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", null );
	}
	
	////////////////////////////////////////////
	// 调课设置
	////////////////////////////////////////////
	/**
	 * 调课列表
	 */
	public function actionAdjustList() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		$sql = "SELECT SpecialDate AS CurrDate, AlteredScheduleDay AS WeekDay FROM AlternateDate";
		
		//获取总数
		$CountSql = "SELECT COUNT(*) c FROM (" . $sql . ") cc";
		$AllCount = 0;
		$AllCountData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $AllCountData ['c'] )) {
			$AllCount = $AllCountData ['c'];
		}
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			if ("CurrDate" == $Sort) {
				$sql .= " ORDER BY CurrDate " . $Order;
			} else if ("WeekDay" == $Sort) {
				$sql .= " ORDER BY WeekDay " . $Order;
			} else {
				$sql .= " ORDER BY SpecialDate ASC";
			}
		} else {
			$sql .= " ORDER BY SpecialDate ASC";
		}
		
		if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql .= " LIMIT " . $Start . "," . $Size;
		}
		$Rows = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", array ('Total' => $AllCount, 'Rows' => $Rows ) );
	}
	
	/**
	 * 编辑调课信息
	 */
	public function actionAdjustEdit() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$OldDate = $this->GetDataParam ( $DataParam, "OldDate", "" ); //日期，格式：2017-01-19
		$CurrDate = $this->GetDataParam ( $DataParam, "CurrDate", "" ); //日期，格式：2017-01-19
		$WeekDay = $this->GetDataParam ( $DataParam, "WeekDay", - 1, true ); //星期，0-6为周一到周日
		

		//校验日期
		if (! preg_match ( "/^(19|20)\d{2}-(0?\d|1[012])-(0?\d|[12]\d|3[01])$/s", $CurrDate )) { //请选择有效的日期//TODO
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_TASK_ADJUST_DATE_INVALID, "请选择有效的日期", null );
			return;
		}
		if ($CurrDate <= date ( "y-m-d" )) { //日期必须在今日之后 TODO
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_TASK_ADJUST_DATE_MUST_AFTER, "日期必须在今日之后", null );
			return;
		}
		if ($WeekDay < 0 || $WeekDay > 6) { //请选择星期 TODO
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_TASK_ADJUST_NEED_WEEK, "请选择星期", null );
			return;
		}
		//获取调课信息
		$sql = 'SELECT * FROM AlternateDate WHERE SpecialDate = :OldDate OR SpecialDate =:CurrDate';
		$Temp = DBMethodUtils::listData ( $sql, array(':OldDate' => $OldDate, ':CurrDate' => $CurrDate) );
		
		if (! empty ( $Temp )) { //更新
			$sql = "UPDATE AlternateDate SET AlteredScheduleDay = :AlteredScheduleDay, SpecialDate=:CurrDate WHERE SpecialDate = :OldDate OR SpecialDate = '" . $CurrDate . "'";
			DBMethodUtils::RunSql ( $sql, array(':AlteredScheduleDay' => $WeekDay, ':OldDate' => $OldDate, ':CurrDate' => $CurrDate) );
			
			if (! empty ( $OldDate ) && $OldDate != $CurrDate) {
				$sql = "DELETE FROM AlternateDate WHERE SpecialDate =:OldDate";
				DBMethodUtils::RunSql ( $sql, array(':OldDate' => $OldDate) );
			}
		} else { //新增
			$sql = "INSERT INTO AlternateDate(SpecialDate, AlteredScheduleDay)VALUES(:CurrDate, :AlteredScheduleDay)";
			DBMethodUtils::RunSql ( $sql, array(':AlteredScheduleDay' => $WeekDay, ':CurrDate' => $CurrDate) );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", null );
	}
	
	/**
	 * 删除调课数据
	 */
	public function actionAdjustDelete() {
		
		////////////////////////////////////////////////////////////////
		// 仅admin可以操作
		///////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$CurrDates = $this->GetDataParam ( $DataParam, "CurrDates", null ); //日期，格式：["2017-01-19", "2017-01-19"]
		

		if (empty ( $CurrDates )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '请选择需要删除的数据！', null );
			return;
		}
		$sql = "DELETE FROM AlternateDate WHERE SpecialDate IN('" . implode ( "','", $CurrDates ) . "')";
		DBMethodUtils::RunSql ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', null );
	}
}