<?php
class ATaskUtil {
	
	//菜单类型
	const MENU_TYPE_TASK_MANAGER = 1; //任务管理
	const MENU_TYPE_TASK_TEMPLATE = 2; //任务模板
	const MENU_TYPE_TASK_MODE_RUN = 3; //运行模式
	const MENU_TYPE_TASK_MODE_STOPED = 4; //备用模式
	const MENU_TYPE_TASK_SSCB = 5; //实时采播
	

	const MENU_SECONDE_TYPE_TIMED = 1; //定时任务、
	const MENU_SECONDE_TYPE_HADN = 2; //手动任务（仅admin）、
	const MENU_SECONDE_TYPE_USER = 3; //用户任务（仅admin）
	

	/**
	 * 获取用户管理任务
	 * @param  $UserID 当前登录用户id
	 * @param  $SelectStreamType 任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Owner 任务拥有用户
	 * @param  $WeekDay 星期
	 * @param  $SearchKey 搜索关键字
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	public static function taskMgrList($UserId, $SecondType, $SelectStreamType, $Owner, $WeekDay, $SearchKey, $Sort, $Order, $Start, $Size) {
		
		if ($SecondType == ATaskUtil::MENU_SECONDE_TYPE_TIMED) { //定时任务
			//////////////////////////////////////////////////
			// admin：查看系统创建的任务,且有模板的概念
			// 普通用户：查看自己创建的任务，没有模板概念
			//////////////////////////////////////////////////
			return ATaskUtil::ListTimedTask ( $UserId, $SelectStreamType, $Owner, $WeekDay, null, $SearchKey, $Sort, $Order, $Start, $Size );
		} else if ($SecondType == ATaskUtil::MENU_SECONDE_TYPE_HADN) { //手动任务（仅admin）
			if (is_null ( $UserId )) {
				return ATaskUtil::ListHandTask ( $UserId, $Sort, $Order, $Start, $Size );
			}
			
			return array ('Total' => 0, 'Rows' => array () );
		} else if ($SecondType == ATaskUtil::MENU_SECONDE_TYPE_USER) { //用户任务（仅admin）
			if (! is_null ( $UserId )) {
				return array ('Total' => 0, 'Rows' => array () );
			}
			if ($Owner > 0) { //获取用户定时任务
				return ATaskUtil::ListTimedTask ( $UserId, $SelectStreamType, $Owner, $WeekDay, null, $SearchKey, $Sort, $Order, $Start, $Size );
			} else {
				$sql = "SELECT * FROM Users WHERE User_ID > 0 AND NOT ISNULL(User_Name)";
				$ParamArr = array ();
				
				if (! empty ( $SearchKey )) {
					$sql .= " AND (User_Desc LIKE CONCAT('%', :searchKey, '%') OR User_Sn LIKE CONCAT('%', :searchKey1, '%') OR IcCard LIKE CONCAT('%', :searchKey2, '%'))";
					$ParamArr [':searchKey'] = $SearchKey;
					$ParamArr [':searchKey1'] = $SearchKey;
					$ParamArr [':searchKey2'] = $SearchKey;
				}
				
				//获取总数
				$Count = 0;
				$CountSql = 'SELECT COUNT(*) c FROM (' . $sql . ') CC';
				$TempData = DBMethodUtils::findData ( $CountSql, $ParamArr );
				
				if (! empty ( $TempData )) {
					$Count = $TempData ['c'];
				}
				//排序
				if (! empty ( $Sort ) && ! empty ( $Order )) {
					if ("id" == strtolower ( $Sort )) {
						$Sort = 'User_ID';
					}
					
					if ("text" == strtolower ( $Sort )) {
						$Sort = 'User_Name';
					}
					
					if (in_array ( strtolower ( $Order ), array ('asc', 'desc' ) )) {
						$sql .= " ORDER BY " . $Sort . " " . $Order;
					}
				}
				//分页数据
				if (isset ( $_POST ['page'] ) && isset ( $_POST ['rows'] ) && is_numeric ( $_POST ['page'] ) && is_numeric ( $_POST ['rows'] )) {
					$page = $_POST ['page'];
					$size = $_POST ['rows'];
					$start = ($page - 1) * $size;
					$sql = $sql . " LIMIT " . $start . "," . $size;
				} else if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
					$sql = $sql . " LIMIT " . $Start . "," . $Size;
				}
				$result = DBMethodUtils::listData ( $sql, $ParamArr );
				
				return array ('Total' => $Count, 'Rows' => $result );
			}
		}
		
		return array ('Total' => 0, 'Rows' => array () );
	}
	
	/**
	 * 获取任务模板任务
	 * @param  $UserID 当前登录用户id
	 * @param  $SelectStreamType 任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Template 任务模板id
	 * @param  $WeekDay 星期
	 * @param  $SearchKey 搜索关键字
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	public static function templateList($UserId, $SelectStreamType, $Template, $WeekDay, $SearchKey, $Sort, $Order, $Start, $Size) {
		
		if (! is_null ( $UserId )) {
			return array ('Total' => 0, 'Rows' => array () );
		}
		
		return ATaskUtil::ListTimedTask ( $UserId, $SelectStreamType, null, $WeekDay, $Template, $SearchKey, $Sort, $Order, $Start, $Size );
	}
	
	/**
	 * 获取运行模式任务列表
	 * @param  $UserId 当前用户id
	 * @param  $Mode 模式id
	 * @param  $SelectStreamType 任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	public static function enabledModeList($UserId, $Mode, $SelectStreamType, $Sort, $Order, $Start, $Size) {
		
		if (! is_null ( $UserId )) {
			return array ('Total' => 0, 'Rows' => array () );
		}
		
		return ATaskUtil::listModeTask ( $UserId, $Mode, $SelectStreamType, 1, $Sort, $Order, $Start, $Size );
	}
	
	/**
	 * 获取备用模式任务列表
	 * @param  $UserId 当前用户id
	 * @param  $Mode 模式id
	 * @param  $SelectStreamType 任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	public static function disableModeList($UserId, $Mode, $SelectStreamType, $Sort, $Order, $Start, $Size) {
		
		if (! is_null ( $UserId )) {
			return array ('Total' => 0, 'Rows' => array () );
		}
		
		return ATaskUtil::listModeTask ( $UserId, $Mode, $SelectStreamType, 0, $Sort, $Order, $Start, $Size );
	}
	
	/**
	 * 获取实时采播
	 * @param  $UserId 当前用户id
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	public static function realtimeList($UserId, $Sort, $Order, $Start, $Size) {
		
		///////////////////////////////////////////////
		//SessionID 任务id
		//SessionName 任务名字
		//Priority 优先级
		//Status 播出状态，0：停止，否则Pause = 0 播放，其他暂停
		//CircleLength 播放长度，单位：秒
		//Pause 1：暂停
		//IpAddress 非空为联机，否则为为联机
		//PlayerType 1:
		///////////////////////////////////////////////
		$sql = 'SELECT * FROM (SELECT  a.SessionID AS TempId,  a.SessionID, IF(ISNULL(e.User_Desc), a.SessionName, e.User_Desc) AS SessionName, 
				a.Priority, a.Status, a.CircleLength, b.Pause, 
				c.IpAddress, 
				d.PlayerType 
				FROM PlaySessions a 
				LEFT JOIN PlayingSessions b on  b.SessionID = a.SessionID 
				LEFT JOIN PlayerStatus c on c.PlayerID = a.PlayerID 
				LEFT JOIN Players d on d.PlayerID = a.PlayerID 
				LEFT JOIN Users e on a.Owner = e.User_ID 
				LEFT JOIN PlayListFiles f on f.SessionID = a.SessionID and f.SequenceID = 0 
				WHERE (a.Parent is null or (Parent = 0)) and (a.SessionType = 1 OR a.SessionType = 10)) aa';
		
		//获取总数
		$Count = 0;
		$CountSql = 'SELECT COUNT(*) c FROM (' . $sql . ') CC';
		$TempData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $TempData )) {
			$Count = $TempData ['c'];
		}
		//排序
		$SortFlag = false;
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			
			if ("SessionName" == $Sort) {
				$sql .= " ORDER BY SessionName " . $Order;
			} else if ("Priority" == $Sort) {
				$sql .= " ORDER BY Priority " . $Order;
			} else if ("Status" == $Sort) {
				$sql .= " ORDER BY Status " . $Order . ", Pause" . $Order;
			} else if ("CircleLength" == $Sort) {
				$sql .= " ORDER BY " . $Sort . " " . $Order;
			} else if ("IpAddress") {
				$sql .= " ORDER BY IpAddress " . $Order;
			} else {
				$sql .= " ORDER BY SessionID " . $Order;
			}
		} else {
			$sql .= " ORDER BY SessionID DESC";
		}
		//分页数据
		if (isset ( $_POST ['page'] ) && isset ( $_POST ['rows'] ) && is_numeric ( $_POST ['page'] ) && is_numeric ( $_POST ['rows'] )) {
			$page = $_POST ['page'];
			$size = $_POST ['rows'];
			$start = ($page - 1) * $size;
			$sql = $sql . " LIMIT " . $start . "," . $size;
		} else if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql = $sql . " LIMIT " . $Start . "," . $Size;
		}
		$result = DBMethodUtils::listData ( $sql );
		
		return array ('Count' => $Count, 'result' => $result );
	}
	
	/**
	 * 获取定时任务时间表
	 * @param $UserID
	 * @param $SelectStreamType
	 * @param $Owner
	 * @param $WeekDay
	 * @param $Template
	 * @param $SearchKey
	 */
	public static function ListTimedTaskTimeTable($UserID, $SelectStreamType, $Owner, $WeekDay, $Template, $SearchKey) {
		
		$Tempata = self::QueryTimeTask ( $UserID, $SelectStreamType, $Owner, $WeekDay, $Template, $SearchKey, true );
		$result = empty ( $Tempata ['result'] ) ? array () : $Tempata ['result'];
		$Count = (empty ( $Tempata ['Count'] ) || ! is_numeric ( $Tempata ['result'] )) ? 0 : $Tempata ['Count'];
		
		if (is_null ( $result ) || count ( $result ) <= 0) {
			array ();
		}
		//按照星期筛选
		$byweekday = false;
		
		if ($WeekDay >= 0) {
			if (is_numeric ( $WeekDay )) {
				$byweekday = true;
			}
		}
		
		if ($byweekday) {
			//筛选的是一周的某一天
			$newmodel = array ();
			$tempid = 1;
			
			foreach ( $result as $item ) {
				$newitem = array ();
				$newitem ["TempId"] = $item ["SessionID"] . '_' . $item ["ScheduleID"];
				$newitem ["SessionID"] = $item ["SessionID"]; //	默认为0，主键ID
				$newitem ["SessionName"] = $item ["SessionName"]; //任务名称
				//				$newitem ["SessionType"] = $item ["SessionType"]; //	0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
				//				$newitem ["Priority"] = $item ["Priority"]; //	优先级
				$newitem ["ScheduleID"] = $item ["ScheduleID"];
				$newitem ["PlayTime"] = $item ["PlayTime"]; //任务指定的播放时间，仅使用时分秒
				$newitem ['SteamTypeDown'] = $item ['StreamType'] - round ( $item ['StreamType'] / 128 ) * 128; //00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
				$newitem ["TempFlag"] = $item ["TempFlag"]; //是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录
				$newitem ["Pause"] = $item ["Pause"]; //播出状态（仅广播才有），1暂停，0正在播放,null:没有播出状态
				//				$newitem ["FileName"] = $item ["FileName"]; //正在播放的文件的名字
				//				$newitem ["PlayListCount"] = $item ["PlayListCount"]; //播放文件数目
				//				
				//
				//				if ($newitem ['SteamTypeDown'] == 0) {
				//					//控制任务需要获取设备状态
				//					//设备控制，系统启禁用状态，1启用，0禁用，仅控制任务才使用这个字段，null为没有控制
				//					$newitem ['SysEnabled'] = $item ['SysEnabled'];
				//					//扩展电源
				//					if (! is_null ( $item ['RfDevCtrl'] )) {
				//						//扩展设备信息
				//						$expandSource = ExpandUtil::LoadExpandDev ();
				//						//扩展设备模式
				//						$expandMode = ExpandUtil::LoadExpandMode ();
				//						
				//						$DeviceCtrl = DeviceUtil::DepackRfDevCtrl ( $expandSource, $item ['RfDevCtrl'], $expandMode );
				//						
				//						$newitem ['DeviceCtrl'] = $DeviceCtrl;
				//					}
				//				}
				$newmodel [count ( $newmodel )] = $newitem;
			}
			//获取总数
			//			$Out = array ('Total' => $Count, 'Rows' => $newmodel );
			

			$newmodel;
		} else { //查看的是一周的全部
			$newmodel = array ();
			$tempid = 1;
			
			foreach ( $result as $item ) {
				$newitem = array ();
				
				$newitem ["SessionID"] = $item ["SessionID"]; //	默认为0，主键ID
				$newitem ["SessionName"] = $item ["SessionName"]; //任务名称
				//				$newitem ["SessionType"] = $item ["SessionType"]; //	0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
				//				$newitem ["Priority"] = $item ["Priority"]; //	优先级
				$newitem ["PlayTime"] = $item ["PlayTime"]; //任务指定的播放时间，仅使用时分秒
				$newitem ['SteamTypeDown'] = $item ['StreamType'] - round ( $item ['StreamType'] / 128 ) * 128; //00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
				//				$newitem ["TempFlag"] = $item ["TempFlag"]; //是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录
				//				$newitem ["PlayListCount"] = $item ["PlayListCount"]; //播放文件数目
				

				//获取播放时间
				for($i = 0; $i <= 6; $i ++) {
					$newitem ['Player_Weekday_' . $i] = null;
				}
				$sql = "SELECT ScheduleID, SessionID,WeekDay,TempFlag, DATE_FORMAT(PlayTime,'%H:%i:%S') as PlayTime FROM PlaySessionTime
				WHERE SessionID='" . $item ['SessionID'] . "' AND DATE_FORMAT(PlayTime,'%H:%i:%S')='" . $item ["PlayTime"] . "'";
				$PlayTimes = DBMethodUtils::listData ( $sql );
				
				//新建的一行，key1：周数，value：
				$newarr = array ();
				
				if (! is_null ( $PlayTimes )) {
					foreach ( $PlayTimes as $PlayTimesItem ) {
						$PlayTimesArr = array ("ScheduleID" => $PlayTimesItem ['ScheduleID'], "WeekDay" => $PlayTimesItem ['WeekDay'], "TempFlag" => $PlayTimesItem ['TempFlag'] );
						
						if (! empty ( $newitem ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] )) {
							//说明这一天已经有任务了，需要复制一条数据添加
							$hasadd = false;
							
							for($i = 0; $i < count ( $newarr ); $i ++) {
								if (! isset ( $newarr [$i] ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] ) || is_null ( $newarr [$i] ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] )) {
									//直接添加
									$newarr [$i] ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] = $PlayTimesArr;
									$hasadd = true;
								}
							}
							if (! $hasadd) {
								//没有添加，需要复制一条记录
								$createitem = $newitem;
								
								for($i = 0; $i <= 6; $i ++) {
									$createitem ['Player_Weekday_' . $i] = null;
								}
								$createitem ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] = $PlayTimesArr;
								
								$newarr [count ( $newarr )] = $createitem;
							}
						} else {
							//这一天没有任务，可以添加
							$newitem ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] = $PlayTimesArr;
						}
					}
				}
				$TempArr = array ();
				
				for($i = 0; $i <= 6; $i ++) {
					if (! empty ( $newitem ['Player_Weekday_' . $i] )) {
						$TempArr [] = $newitem ['Player_Weekday_' . $i] ['ScheduleID'];
						$newitem ['Player_ScheduleID_Weekday_' . $i] = $newitem ['Player_Weekday_' . $i] ['ScheduleID'];
						$newitem ['Player_Weekday_' . $i] = $newitem ['Player_Weekday_' . $i] ['TempFlag'];
					} else {
						$TempArr [] = "";
						$newitem ['Player_ScheduleID_Weekday_' . $i] = "";
						$newitem ['Player_Weekday_' . $i] = '';
					}
				}
				$newitem ["TempId"] = $newitem ['SessionID'] . '_' . implode ( '_', $TempArr );
				$newmodel [count ( $newmodel )] = $newitem;
				
				if (count ( $newarr ) > 0) {
					foreach ( $newarr as $newarritem ) {
						$TempArr = array ();
						
						for($i = 0; $i <= 6; $i ++) {
							if (! empty ( $newarritem ['Player_Weekday_' . $i] )) {
								$TempArr [] = $newarritem ['Player_Weekday_' . $i] ['ScheduleID'];
								$newarritem ['Player_ScheduleID_Weekday_' . $i] = $newarritem ['Player_Weekday_' . $i] ['ScheduleID'];
								$newarritem ['Player_Weekday_' . $i] = $newarritem ['Player_Weekday_' . $i] ['TempFlag'];
							} else {
								$TempArr [] = "";
								$newarritem ['Player_ScheduleID_Weekday_' . $i] = "";
								$newarritem ['Player_Weekday_' . $i] = '';
							}
						}
						$newarritem ["TempId"] = $newarritem ['SessionID'] . '_' . implode ( '_', $TempArr );
						$newmodel [count ( $newmodel )] = $newarritem;
					}
				}
			}
			//获取总数
			//			$Out = array ('Total' => $Count, 'Rows' => $newmodel );
			

			return $newmodel;
		}
	}
	
	/***********************************************************************************************************/
	/**
	 * 判断用户任务操作权限
	 * @param  $UserId
	 * @param  $SessionType
	 */
	public static function JudgeTaskPermission($UserId, $SessionType) {
		
		if (! is_null ( $UserId ) && $UserId > 0) {
			$privilege = AUserUtil::getUserPrivilege ( $UserId );
			
			switch ($SessionType) {
				case 0 : //自动广播或控制任务；
					if (! PermissionManager::JudgeBroadcastPrivaliege ( $privilege ) && ! PermissionManager::JudgeDevCtrPrivaliege ( $privilege ) && ! PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege )) {
						return DataUtil::PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有音视广播权限理权限', null );
					}
					break;
				case 1 : //由PC呼叫台或者音频广播站创建的任务；
					//TODO
					break;
				case 2 : //2：手动广播任务
					if (! PermissionManager::JudgeBroadcastPrivaliege ( $privilege )) {
						return DataUtil::PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有音视广播权限理权限', null );
					}
					break;
				default :
					break;
			}
		}
		
		return DataUtil::PackResponseData ( ErrcodeUtil::$SUCCESS, '', null );
	}
	
	/**
	 * 组装任务基本信息修改数据
	 * @param $SessionModel
	 * @param $BaseInfo
	 */
	public static function packUpdateArr($SessionModel, $BaseInfo, &$ParamArr) {
		
		if (empty ( $SessionModel ) || empty ( $BaseInfo )) {
			return array ();
		}
		//强制接收标识(StreamType高4为来判断，最高位：1：强制，0：不强制)
		$SteamTypeUp = round ( $SessionModel->StreamType / 128 );
		//00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
		$SteamTypeDown = $SessionModel->StreamType - round ( $SessionModel->StreamType / 128 ) * 128;
		
		//任务存在，是修改任务
		$UpdateAttr = array ();
		
		//基本信息的修改
		if (isset ( $BaseInfo ['SessionName'] )) { //修改任务名字
			$ParamArr [':SessionName'] = $BaseInfo ['SessionName'];
			$UpdateAttr [] = 'SessionName=:SessionName';
		}
		if (isset ( $BaseInfo ['Priority'] ) && is_numeric ( $BaseInfo ['Priority'] )) { //修改优先级（整数）
			$ParamArr [':Priority'] = $BaseInfo ['Priority'];
			$UpdateAttr [] = 'Priority=:Priority';
		}
		if (isset ( $BaseInfo ['SteamTypeUp'] ) && is_numeric ( $BaseInfo ['SteamTypeUp'] )) { //1：强制，0：不强制
			$SteamTypeUp = $BaseInfo ['SteamTypeUp'];
			$SteamTypeUp = $SteamTypeUp == 1 ? 1 : 0;
		}
		
		if (isset ( $BaseInfo ['SteamTypeDown'] ) && is_numeric ( $BaseInfo ['SteamTypeDown'] )) { //0：控制，1：音频，2：视频（暂时不用），3：视频（视频用3）
			if ($SteamTypeDown == 0) {
				$SteamTypeUp = 0;
			} else {
				$SteamTypeDown = in_array ( $BaseInfo ['SteamTypeDown'], array (2, 3 ) ) ? 3 : 1;
			}
		}
		
		if (in_array ( $SessionModel->SessionType, array (0, 8 ) )) { //自动任务
			if (in_array ( $SteamTypeDown, array (2, 3 ) )) { //视频任务
				$UpdateAttr [] = 'SessionType = 8';
			} else {
				$UpdateAttr [] = 'SessionType = 0';
			}
		} else if (in_array ( $SessionModel->SessionType, array (2, 9 ) )) { //手动任务
			if (in_array ( $SteamTypeDown, array (2, 3 ) )) { //视频任务
				$UpdateAttr [] = 'SessionType = 9';
			} else {
				$UpdateAttr [] = 'SessionType = 2';
			}
		}
		
		$UpdateAttr [] = 'StreamType="' . ($SteamTypeUp * 128 + $SteamTypeDown) . '"';
		
		return $UpdateAttr;
	}
	
	/**
	 * 组装广播任务修改数据 
	 * @param  $Broadcast
	 * @param  $UpdateAttr
	 */
	public static function packBroadcastUpdateArr($Broadcast, $UpdateAttr, &$ParamArr) {
		
		if (empty ( $Broadcast )) {
			return $UpdateAttr;
		}
		if (isset ( $Broadcast ['AudioGain'] )) { //音频增益，单个任务的音量调节。
			$AudioGain = $Broadcast ['AudioGain'];
			
			if ($AudioGain != - 100) {
				$AudioGain = $AudioGain <= - 20 ? - 20 : $AudioGain;
				$AudioGain = $AudioGain >= 20 ? 20 : $AudioGain;
			}
			$ParamArr [':AudioGain'] = $AudioGain;
			$UpdateAttr [] = 'AudioGain=:AudioGain';
		}
		if (isset ( $Broadcast ['CircleLength'] )) { //默认为0，播放时长；秒
			$ParamArr [':CircleLength'] = $Broadcast ['CircleLength'];
			$UpdateAttr [] = 'CircleLength=:CircleLength';
		}
		if (isset ( $Broadcast ['PlayMode'] )) { //播放模式,媒体播放方式，0顺序播放，1随机播放，默认是0，广播任务才用
			$ParamArr [':PlayMode'] = $Broadcast ['PlayMode'];
			$UpdateAttr [] = 'PlayMode=:PlayMode';
		}
		
		return $UpdateAttr;
	}
	
	/**
	 * 组装控制任务修改数据 
	 * @param  $Broadcast
	 * @param  $UpdateAttr
	 */
	public static function packCtrlUpdateArr($UserId, $DeviceCtrl, $UpdateAttr, &$ParamArr) {
		
		if (empty ( $DeviceCtrl )) {
			return $UpdateAttr;
		}
		$privilege = AUserUtil::getUserPrivilege ( $UserId );
		
		if (PermissionManager::JudgeDevCtrPrivaliege ( $privilege )) { //有中控权限
			if (isset ( $DeviceCtrl ['SysEnabled'] ) && is_numeric ( $DeviceCtrl ['SysEnabled'] ) && in_array ( $DeviceCtrl ['SysEnabled'], array (0, 1, 2 ) )) { //设备控制，系统状态，0：关机，1：开机，2：禁用，仅控制任务才使用这个字段，null为没有控制
				$UpdateAttr [] = 'SysEnabled=' . $DeviceCtrl ['SysEnabled'];
			} else {
				$UpdateAttr [] = 'SysEnabled=NULL';
			}
		} else {
			$UpdateAttr [] = 'SysEnabled=NULL';
		}
		
		if (PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege )) { //有物联设备权限
			if (! empty ( $DeviceCtrl ['RfDevCtrl'] )) { //子设备状态
				$UpdateAttr [] = 'RfDevCtrl=' . TaskUtil::LoadRfDevCtrl ( $DeviceCtrl ['RfDevCtrl'] );
			} else {
				$UpdateAttr [] = 'RfDevCtrl=NULL';
			}
		} else {
			$UpdateAttr [] = 'RfDevCtrl=NULL';
		}
		
		return $UpdateAttr;
	}
	
	/**
	 * 组装模式数据
	 * @param  $Mode
	 * @param  $UpdateAttr
	 */
	public static function packModeUpdateArr($Mode, $UpdateAttr, &$ParamArr) {
		
		if (empty ( $Mode )) {
			return $UpdateAttr;
		}
		
		if (isset ( $Mode ['BrdMode'] ) && is_numeric ( $Mode ['BrdMode'] ) && $Mode ['BrdMode'] > 0) { //是否广播模式任务，>0广播模式ID 是模式任务，null表示非模式任务
			$ParamArr [':BrdMode'] = $Mode ['BrdMode'];
			$UpdateAttr [] = 'BrdMode=:BrdMode';
		}
		if (isset ( $Mode ['MemmberMode'] ) && in_array ( $Mode ['MemmberMode'], array ("0", "1" ) )) { //默认为0,是否使用模式成员，1使用模式成员，0不使用
			$ParamArr [':MemmberMode'] = $Mode ['MemmberMode'];
			$UpdateAttr [] = 'MemberMode=:MemmberMode';
		}
		
		return $UpdateAttr;
	}
	
	/**
	 * 组装新建任务model
	 * @param  $UserId
	 * @param  $BaseInfo
	 */
	public static function packNewModel($UserId, $BaseInfo) {
		
		if (empty ( $BaseInfo )) {
			return null;
		}
		
		//获取任务id
		$sql = "SELECT get_idle_sessionid(true) AS id";
		$idRes = DBMethodUtils::findData ( $sql );
		
		if (is_null ( $idRes ) || ! isset ( $idRes ['id'] )) {
			return null;
		}
		
		$Status = 0; //状态，暂时没用
		$SessionType = $BaseInfo ['SessionType']; //任务类型
		$SessionID = $idRes ['id'];
		$Template = null; //当前模板id
		

		if (is_null ( $UserId ) || $UserId == 0) {
			if (isset ( $BaseInfo ['Template'] ) && is_numeric ( $BaseInfo ['Template'] )) {
				$Template = $BaseInfo ['Template'];
			}
			if ($SessionType == 0 || $SessionType == 8) { //自动广播任务（0）和自定视频任务（8）需要使用任务模板
				if (is_null ( $Template )) {
					//获取当前使用的模板id
					$TemplateInfo = null;
					try {
						$sql = "SELECT * FROM  TaskTemplate WHERE idTaskTemplate=(SELECT InfoValue FROM BaseInfo WHERE InfomationID=257)";
						$TemplateInfo = DBMethodUtils::findData ( $sql );
					} catch ( Exception $e ) {
					
					}
					if (! is_null ( $TemplateInfo ) && isset ( $TemplateInfo ['idTaskTemplate'] )) {
						$Template = $TemplateInfo ['idTaskTemplate'];
					}
				}
			}
		}
		
		$SessionModel = new PlaySessions ();
		$SessionModel->SessionID = $SessionID;
		$SessionModel->SessionName = ""; //任务名字
		$SessionModel->SessionType = $SessionType; //修改任务类型，0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
		$SessionModel->Priority = 0; //优先级（整数）
		$SessionModel->Status = $Status;
		$SessionModel->CircleLength = 0;
		$SessionModel->BrdMode = null;
		$SessionModel->MemberMode = 0;
		$SessionModel->StreamType = - 1;
		$SessionModel->SysEnabled = null;
		$SessionModel->RfDevCtrl = null;
		if (! is_null ( $UserId ) && $UserId > 0) {
			$SessionModel->Owner = $UserId;
		}
		$SessionModel->PlayMode = 0;
		$SessionModel->AudioGain = 0;
		$SessionModel->Template = $Template;
		
		if (isset ( $BaseInfo ['SessionName'] )) { //任务名字
			$SessionModel->SessionName = $BaseInfo ['SessionName'];
		}
		if (isset ( $BaseInfo ['Priority'] ) && is_numeric ( $BaseInfo ['Priority'] )) { //优先级（整数）
			$SessionModel->Priority = $BaseInfo ['Priority'];
			
			if ($SessionModel->Priority > 100) {
				$SessionModel->Priority = 100;
			} else if ($SessionModel->Priority < 0) {
				$SessionModel->Priority = 0;
			}
		}
		
		$up = 0;
		$down = 0;
		
		if (isset ( $BaseInfo ['SteamTypeUp'] ) && is_numeric ( $BaseInfo ['SteamTypeUp'] )) {
			//强制接收，1：强制，0：不强制
			//0控制任务，1音频，2视屏，3音视频，一般用3来表示视频
			$up = $BaseInfo ['SteamTypeUp'];
			$up = $up <= 0 ? 0 : 1;
		}
		if (isset ( $BaseInfo ['SteamTypeDown'] ) && is_numeric ( $BaseInfo ['SteamTypeDown'] )) { //0控制任务，1音频，2视屏，3音视频，一般用3来表示视频
			$down = $BaseInfo ['SteamTypeDown'];
			$sql .= " Priority=FLOOR((StreamType / 128)) * 128 + " . $BaseInfo ['SteamTypeDown'];
			
			if (in_array ( $SessionModel->SessionType, array (0, 8 ) )) {
				if (in_array ( $BaseInfo ['SteamTypeDown'], array (2, 3 ) )) {
					$SessionModel->SessionType = 8;
				} else {
					$SessionModel->SessionType = 0;
				}
			} else if (in_array ( $SessionModel->SessionType, array (2, 9 ) )) {
				if (in_array ( $BaseInfo ['SteamTypeDown'], array (2, 3 ) )) {
					$SessionModel->SessionType = 9;
				} else {
					$SessionModel->SessionType = 2;
				}
			}
		}
		$SessionModel->StreamType = $up * 128 + $down;
		
		$SessionModel->AudioGain = 0;
		$SessionModel->CircleLength = 0;
		$SessionModel->PlayMode = 0;
		$SessionModel->SysEnabled = null;
		$RfDevCtrl = null;
		
		return $SessionModel;
	}
	
	/**
	 * 组装新建任务model
	 * @param  $UserId
	 * @param  $BaseInfo
	 */
	public static function packBroadcastNewModel($SessionModel, $Broadcast) {
		
		if (empty ( $SessionModel ) || empty ( $Broadcast )) {
			return $SessionModel;
		}
		
		if (isset ( $Broadcast ['AudioGain'] )) { //音频增益，单个任务的音量调节。
			$SessionModel->AudioGain = $Broadcast ['AudioGain'];
			
			if ($SessionModel->AudioGain != - 100) {
				if ($SessionModel->AudioGain < - 20) {
					$SessionModel->AudioGain = - 20;
				} else if ($SessionModel->AudioGain > 20) {
					$SessionModel->AudioGain = 20;
				}
			}
		}
		if (isset ( $Broadcast ['CircleLength'] )) { //默认为0，播放时长；秒
			$SessionModel->CircleLength = $Broadcast ['CircleLength'];
		}
		if (isset ( $Broadcast ['PlayMode'] )) { //播放模式,媒体播放方式，0顺序播放，1随机播放，默认是0，广播任务才用
			$SessionModel->PlayMode = $Broadcast ['PlayMode'];
		}
		
		return $SessionModel;
	}
	
	/**
	 * 组装控制任务新建数据
	 * @param  $UserId
	 * @param  $SessionModel
	 * @param  $DeviceCtrl
	 */
	public static function packCtrlNewModel($UserId, $SessionModel, $DeviceCtrl) {
		
		if (empty ( $SessionModel ) || empty ( $DeviceCtrl )) {
			return $SessionModel;
		}
		
		$privilege = AUserUtil::getUserPrivilege ( $UserId );
		
		if (PermissionManager::JudgeDevCtrPrivaliege ( $privilege )) { //有中控权限
			if (isset ( $DeviceCtrl ['SysEnabled'] ) && in_array ( $DeviceCtrl ['SysEnabled'], array (0, 1, 2 ) )) { //设备控制，系统状态，0：关机，1：开机，2：禁用，仅控制任务才使用这个字段，null为没有控制
				$SessionModel->SysEnabled = $DeviceCtrl ['SysEnabled'];
			}
		}
		
		if (PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege )) { //有物联权限
			if (! empty ( $DeviceCtrl ['RfDevCtrl'] )) { //子设备状态
				$SessionModel->RfDevCtrl = TaskUtil::LoadRfDevCtrlNew ( $DeviceCtrl ['RfDevCtrl'] );
			}
		}
		
		return $SessionModel;
	}
	
	/**
	 * 组装模式新建数据
	 * @param  $SessionModel
	 * @param  $Mode
	 */
	public static function packModeNewModel($SessionModel, $Mode) {
		
		if (empty ( $SessionModel ) || empty ( $Mode )) {
			return $SessionModel;
		}
		
		if (isset ( $Mode ['BrdMode'] )) { //是否广播模式任务，>0广播模式ID 是模式任务，null表示非模式任务
			$SessionModel->BrdMode = $Mode ['BrdMode'];
		}
		if (isset ( $Mode ['MemmberMode'] )) { //默认为0,是否使用模式成员，1使用模式成员，0不使用
			$SessionModel->MemberMode = $Mode ['MemmberMode'];
		}
		
		return $SessionModel;
	}
	
	/**
	 * 更新按键，返回按键主键
	 * @param  $PlayerID 
	 * @param  $Index
	 * @param  $KeyGId
	 * @param  $HadMap
	 */
	public static function upadteRealtimePlayerKey($PlayerID, $Index, $KeyGId, $HadMap) {
		
		if ($KeyGId <= 0) { //没有设置分组
			return - 1;
		}
		//判断分组是否存在
		$sql = "SELECT * FROM DevClasses WHERE ClassID = '" . $KeyGId . "'";
		$Temp = DBMethodUtils::findData ( $sql );
		
		if (empty ( $Temp )) { //分组不存在
			return - 1;
		}
		
		if (! empty ( $HadMap [$Index] )) { //已经存在了需要更新
			$sql = "UPDATE PlayerKeys SET GroupID = '" . $KeyGId . "' WHERE PlayerKeyId = '" . $HadMap [$Index] ['PlayerKeyId'] . "'";
			DBMethodUtils::RunSql ( $sql );
			
			return $HadMap [$Index] ['PlayerKeyId'];
		} else { //需要插入数据
			$PlayerKey = new PlayerKeys ();
			$PlayerKey->PlayerID = $PlayerID;
			$PlayerKey->Index = $Index;
			$PlayerKey->GroupDisable = 0;
			$PlayerKey->DevDisable = 0;
			$PlayerKey->GroupID = $KeyGId;
			
			if ($PlayerKey->save ()) {
				return $PlayerKey->PlayerKeyId;
			}
		}
		
		return - 1;
	}
	/***********************************************************************************************************/
	/**
	 * 组装按星期筛选的任务数据
	 * @param $Session
	 */
	public static function packTaskListByWeekday($Session) {
		
		if (empty ( $Session )) {
			return null;
		}
		//筛选的是一周的某一天
		$tempid = 1;
		
		$newitem = array ();
		$newitem ["TempId"] = $Session ["SessionID"] . '_' . $Session ["ScheduleID"];
		$newitem ["SessionID"] = $Session ["SessionID"]; //	默认为0，主键ID
		$newitem ["SessionName"] = $Session ["SessionName"]; //任务名称
		$newitem ["SessionType"] = $Session ["SessionType"]; //	0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
		$newitem ["Priority"] = $Session ["Priority"]; //	优先级
		$newitem ["ScheduleID"] = $Session ["ScheduleID"];
		$newitem ["PlayTime"] = $Session ["PlayTime"]; //任务指定的播放时间，仅使用时分秒
		$newitem ['SteamTypeDown'] = $Session ['StreamType'] - round ( $Session ['StreamType'] / 128 ) * 128; //00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
		$newitem ["TempFlag"] = $Session ["TempFlag"]; //是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录
		$newitem ["Pause"] = $Session ["Pause"]; //播出状态（仅广播才有），1暂停，0正在播放,null:没有播出状态
		$newitem ["FileName"] = $Session ["FileName"]; //正在播放的文件的名字
		$newitem ["PlayListCount"] = $Session ["PlayListCount"]; //播放文件数目
		$newitem ['SysEnabled'] = null;
		$newitem ['DeviceCtrl'] = array ();
		
		if ($newitem ['SteamTypeDown'] == 0) {
			//控制任务需要获取设备状态
			//设备控制，系统启禁用状态，1启用，0禁用，仅控制任务才使用这个字段，null为没有控制
			$newitem ['SysEnabled'] = $Session ['SysEnabled'];
			//扩展电源
			if (! is_null ( $Session ['RfDevCtrl'] )) {
				//扩展设备信息
				$expandSource = ExpandUtil::LoadExpandDev ();
				//扩展设备模式
				$expandMode = ExpandUtil::LoadExpandMode ();
				
				$DeviceCtrl = DeviceUtil::DepackRfDevCtrl ( $expandSource, $Session ['RfDevCtrl'], $expandMode );
				
				$newitem ['DeviceCtrl'] = $DeviceCtrl;
			}
		}
		
		return $newitem;
	}
	/***********************************************************************************************************/
	/**
	 * 查询数据库获取定时任务
	 * @param  $UserID 当前登录用户id
	 * @param  $SelectStreamType 任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Owner 任务拥有用户
	 * @param  $WeekDay 星期
	 * @param  $Template 任务模板
	 * @param  $SearchKey 搜索关键字
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	private static function QueryTimeTask($UserID, $SelectStreamType, $Owner, $WeekDay, $Template, $SearchKey, $Sort, $Order, $Start, $Size) {
		
		$sql = "SELECT CONCAT(a.SessionID, '_', a.ScheduleID) AS TempId, a.SessionID, a.ScheduleID, DATE_FORMAT(a.PlayTime,'%H:%i:%S') as PlayTime, b.CircleLength, a.TempFlag,
			IF(" . (is_null ( $UserID ) ? 0 : $UserID) . " <= 0, IF((ISNULL(uu.User_Name) OR LENGTH(uu.User_Name) < 1), b.SessionName, CONCAT(uu.User_Name, ':',b.SessionName)), b.SessionName) SessionName
			, b.SessionType, b.Priority, b.StreamType, b.SysEnabled, b.RfDevCtrl, dd.Pause,mf.FileName, IF(ISNULL(pl.PlayListCount), 0, pl.PlayListCount) AS PlayListCount 
			FROM PlaySessionTime a LEFT JOIN PlaySessions b ON a.SessionID=b.SessionID 
			LEFT JOIN PlayingSessions dd ON a.SessionID=dd.SessionID AND a.ScheduleID=dd.ScheduleID LEFT JOIN PlayingSessions ps ON a.SessionID=ps.SessionID 
			LEFT JOIN MediaFiles mf ON ps.PlayingFileID=mf.MediaID LEFT JOIN Users uu ON b.Owner=uu.User_ID
			LEFT JOIN (SELECT COUNT(*) AS PlayListCount, SessionID FROM PlayListFiles GROUP BY SessionID) pl ON a.SessionID=pl.SessionID
			WHERE SessionType IN (0,8) AND (ISNULL(b.BrdMode) OR b.BrdMode <= 0)";
		
		//任务类型筛选,0:控制任务，1：广播任务，2：都选，3：都不选
		if (in_array ( $SelectStreamType, array (0, 1, 2, 3 ) )) {
			switch ($SelectStreamType) {
				case 0 : //控制任务
					$sql = $sql . " AND b.StreamType&7 = 0";
					break;
				case 1 : //广播任务
					$sql = $sql . " AND b.StreamType&7 != 0";
					break;
				case 2 : //所有任务
					break;
				case 3 : //都不选
					$sql = $sql . " AND b.StreamType&7 = -1";
					break;
				default :
					break;
			}
		}
		$OwnerWhere = array ();
		
		if (is_null ( $UserID ) || $UserID == 0) { //最高权限的管理员
			if (! empty ( $Owner ) && $Owner > 0) { //获取的某个用户的任务
				$OwnerWhere [] = " b.Owner = '" . $Owner . "'";
			} else { //获取的系统的任务
				$OwnerWhere [] = " ISNULL(b.Owner)";
			}
		} else { //普通用户
			$OwnerWhere [] = " b.Owner = '" . $UserID . "'";
		}
		if (! empty ( $OwnerWhere )) {
			$sql .= ' AND (' . implode ( ' OR ', $OwnerWhere ) . ')';
		}
		//按照星期筛选
		$byweekday = false;
		
		if (is_numeric ( $WeekDay ) && $WeekDay >= 0 && $WeekDay <= 6) {
			$sql = $sql . " AND WeekDay = '" . $WeekDay . "'";
			$byweekday = true;
		}
		//模板，只有admin用户才具有的功能
		if (is_null ( $UserID ) && (empty ( $Owner ) || $Owner <= 0)) { //需要考虑是否需要模板
			//按照模板筛选(定时任务不需要传递这个值)
			if ($Template != null && $Template >= 0) {
				$sql .= " and Template='" . $Template . "'";
			} else {
				$sql .= " and Template=(SELECT InfoValue FROM BaseInfo WHERE InfomationID=257)";
			}
		}
		//获取总数
		$Count = 0;
		$ParamArr = array ();
		//搜索关键字,按照名字搜索
		if (! empty ( $SearchKey )) {
			$sql .= " AND SessionName like CONCAT('%', :SearchKey, '%')";
			$ParamArr [':SearchKey'] = $SearchKey;
		}
		$sql = $sql . " GROUP BY a.SessionID,DATE_FORMAT(a.PlayTime,'%H:%i:%S')";
		$CountSql = 'SELECT COUNT(*) c FROM (' . $sql . ') CC';
		$TempData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $TempData )) {
			$Count = $TempData ['c'];
		}
		
		//排序
		$SortFlag = false;
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			//可排序的字段
			$SortCol = array ("PlayTime", "SessionName", "Priority", "SysEnabled" );
			
			if (! in_array ( $Sort, $SortCol )) {
				$Sssql = "SELECT * FROM PwrDisplaySet WHERE Name='" . $Sort . "'";
				$tempdata = DBMethodUtils::findData ( $Sssql );
				
				if (! empty ( $tempdata )) {
					$Sort = "RfDevCtrl";
				}
			}
			$SortCol [] = "RfDevCtrl";
			
			if (in_array ( strtolower ( $Order ), array ('asc', 'desc' ) ) && in_array ( $Sort, $SortCol )) {
				$sql .= " ORDER BY " . $Sort . " " . $Order;
				$SortFlag = true;
			}
		}
		
		if (! $SortFlag) {
			$sql .= " ORDER BY PlayTime ASC";
		}
		//分页数据
		if (isset ( $_POST ['page'] ) && isset ( $_POST ['rows'] ) && is_numeric ( $_POST ['page'] ) && is_numeric ( $_POST ['rows'] )) {
			$page = $_POST ['page'];
			$size = $_POST ['rows'];
			$start = ($page - 1) * $size;
			$sql = $sql . " LIMIT " . $start . "," . $size;
		} else if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql = $sql . " LIMIT " . $Start . "," . $Size;
		}
		$result = DBMethodUtils::listData ( $sql );
		
		return array ('Count' => $Count, 'result' => $result );
	}
	
	/**
	 * 获取定时任务
	 * @param  $UserID 当前登录用户id
	 * @param  $SelectStreamType 任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Owner 任务拥有用户
	 * @param  $WeekDay 星期
	 * @param  $Template 任务模板
	 * @param  $SearchKey 搜索关键字
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	private static function ListTimedTask($UserID, $SelectStreamType, $Owner, $WeekDay, $Template, $SearchKey, $Sort, $Order, $Start, $Size) {
		
		$Tempata = ATaskUtil::QueryTimeTask ( $UserID, $SelectStreamType, $Owner, $WeekDay, $Template, $SearchKey, $Sort, $Order, $Start, $Size );
		
		$result = empty ( $Tempata ['result'] ) ? array () : $Tempata ['result'];
		$Count = (empty ( $Tempata ['Count'] ) || ! is_numeric ( $Tempata ['Count'] )) ? 0 : $Tempata ['Count'];
		
		if (is_null ( $result ) || count ( $result ) <= 0) {
			return array ('Total' => 0, 'Rows' => array () );
		}
		//按照星期筛选
		$byweekday = false;
		
		if ($WeekDay >= 0) {
			if (is_numeric ( $WeekDay )) {
				$byweekday = true;
			}
		}
		
		if ($byweekday) {
			//筛选的是一周的某一天
			$newmodel = array ();
			$tempid = 1;
			
			foreach ( $result as $item ) {
				$newitem = ATaskUtil::packTaskListByWeekday ( $item );
				
				if (empty ( $newitem )) {
					continue;
				}
				$newmodel [count ( $newmodel )] = $newitem;
			}
			//获取总数
			$Out = array ('Total' => $Count, 'Rows' => $newmodel );
			
			return $Out;
		} else { //查看的是一周的全部
			$newmodel = array ();
			$tempid = 1;
			
			foreach ( $result as $item ) {
				$newitem = array ();
				
				$newitem ["SessionID"] = $item ["SessionID"]; //	默认为0，主键ID
				$newitem ["SessionName"] = $item ["SessionName"]; //任务名称
				$newitem ["SessionType"] = $item ["SessionType"]; //	0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
				$newitem ["Priority"] = $item ["Priority"]; //	优先级
				$newitem ["PlayTime"] = $item ["PlayTime"]; //任务指定的播放时间，仅使用时分秒
				$newitem ['SteamTypeDown'] = $item ['StreamType'] - round ( $item ['StreamType'] / 128 ) * 128; //00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
				//				$newitem ["TempFlag"] = $item ["TempFlag"]; //是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录
				$newitem ["PlayListCount"] = $item ["PlayListCount"]; //播放文件数目
				

				//获取播放时间
				for($i = 0; $i <= 6; $i ++) {
					$newitem ['Player_Weekday_' . $i] = null;
				}
				$sql = "SELECT ScheduleID, SessionID,WeekDay,TempFlag, DATE_FORMAT(PlayTime,'%H:%i:%S') as PlayTime FROM PlaySessionTime
				WHERE SessionID='" . $item ['SessionID'] . "' AND DATE_FORMAT(PlayTime,'%H:%i:%S')='" . $item ["PlayTime"] . "'";
				$PlayTimes = DBMethodUtils::listData ( $sql );
				
				//新建的一行，key1：周数，value：
				$newarr = array ();
				
				if (! is_null ( $PlayTimes )) {
					foreach ( $PlayTimes as $PlayTimesItem ) {
						$PlayTimesArr = array ("ScheduleID" => $PlayTimesItem ['ScheduleID'], "WeekDay" => $PlayTimesItem ['WeekDay'], "TempFlag" => $PlayTimesItem ['TempFlag'] );
						
						if (! empty ( $newitem ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] )) {
							//说明这一天已经有任务了，需要复制一条数据添加
							$hasadd = false;
							
							for($i = 0; $i < count ( $newarr ); $i ++) {
								if (! isset ( $newarr [$i] ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] ) || is_null ( $newarr [$i] ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] )) {
									//直接添加
									$newarr [$i] ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] = $PlayTimesArr;
									$hasadd = true;
								}
							}
							if (! $hasadd) {
								//没有添加，需要复制一条记录
								$createitem = $newitem;
								
								for($i = 0; $i <= 6; $i ++) {
									$createitem ['Player_Weekday_' . $i] = null;
								}
								$createitem ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] = $PlayTimesArr;
								
								$newarr [count ( $newarr )] = $createitem;
							}
						} else {
							//这一天没有任务，可以添加
							$newitem ['Player_Weekday_' . $PlayTimesItem ['WeekDay']] = $PlayTimesArr;
						}
					}
				}
				$TempArr = array ();
				
				for($i = 0; $i <= 6; $i ++) {
					if (! empty ( $newitem ['Player_Weekday_' . $i] )) {
						$TempArr [] = $newitem ['Player_Weekday_' . $i] ['ScheduleID'];
					} else {
						$TempArr [] = "";
					}
				}
				$newitem ["TempId"] = $newitem ['SessionID'] . '_' . implode ( '_', $TempArr );
				$newmodel [count ( $newmodel )] = $newitem;
				
				if (count ( $newarr ) > 0) {
					foreach ( $newarr as $newarritem ) {
						$TempArr = array ();
						
						for($i = 0; $i <= 6; $i ++) {
							if (! empty ( $newarritem ['Player_Weekday_' . $i] )) {
								$TempArr [] = $newarritem ['Player_Weekday_' . $i] ['ScheduleID'];
							} else {
								$TempArr [] = "";
							}
						}
						$newarritem ["TempId"] = $newarritem ['SessionID'] . '_' . implode ( '_', $TempArr );
						$newmodel [count ( $newmodel )] = $newarritem;
					}
				}
			}
			//获取总数
			$Out = array ('Total' => $Count, 'Rows' => $newmodel );
			
			return $Out;
		}
	}
	
	/**
	 * 获取手动任务
	 * @param $UserID
	 */
	private static function ListHandTask($UserID, $Sort, $Order, $Start, $Size) {
		
		$sql = "SELECT a.SessionID AS TempId, a.SessionID, a.SessionName, a.SessionType, a.Priority, a.CircleLength, a.StreamType, c.FileName, 
				b.CurrFileProgress, b.CurrTotalProgress, dd.Pause, IF(ISNULL(pl.PlayListCount), 0, pl.PlayListCount) AS PlayListCount
		      FROM PlaySessions a LEFT JOIN PlayingSessions b ON a.SessionID=b.SessionID LEFT JOIN MediaFiles c ON b.PlayingFileID=c.MediaID
			 LEFT JOIN PlayingSessions dd ON a.SessionID=dd.SessionID 
			 LEFT JOIN (SELECT COUNT(*) AS PlayListCount, SessionID FROM PlayListFiles GROUP BY SessionID) pl ON a.SessionID=pl.SessionID WHERE a.SessionType IN(2,9)";
		//获取总数
		$Count = 0;
		$CountSql = 'SELECT COUNT(*) c FROM (' . $sql . ') CC';
		$TempData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $TempData )) {
			$Count = $TempData ['c'];
		}
		//排序
		$SortFlag = false;
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			//可排序的字段
			$SortCol = array ("PlayTime", "SessionName", "Priority", "SysEnabled" );
			
			if (! in_array ( $Sort, $SortCol )) {
				$Sssql = "SELECT * FROM PwrDisplaySet WHERE Name='" . $Sort . "'";
				$tempdata = DBMethodUtils::findData ( $Sssql );
				
				if (! empty ( $tempdata )) {
					$Sort = "RfDevCtrl";
				}
			}
			$SortCol [] = "RfDevCtrl";
			
			if (in_array ( strtolower ( $Order ), array ('asc', 'desc' ) ) && in_array ( $Sort, $SortCol )) {
				$sql .= " ORDER BY " . $Sort . " " . $Order;
			}
		}
		//分页数据
		if (isset ( $_POST ['page'] ) && isset ( $_POST ['rows'] ) && is_numeric ( $_POST ['page'] ) && is_numeric ( $_POST ['rows'] )) {
			$page = $_POST ['page'];
			$size = $_POST ['rows'];
			$start = ($page - 1) * $size;
			$sql = $sql . " LIMIT " . $start . "," . $size;
		} else if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql = $sql . " LIMIT " . $Start . "," . $Size;
		}
		$result = DBMethodUtils::listData ( $sql );
		$out = array ();
		
		if (! empty ( $result )) {
			foreach ( $result as $item ) {
				$item ['SteamTypeDown'] = $item ['StreamType'] - round ( $item ['StreamType'] / 128 ) * 128; //00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
				$out [] = $item;
			}
		}
		
		return array ('Total' => $Count, 'Rows' => $out );
	}
	
	/**
	 * 获取模式下的任务
	 * @param  $UserId 当前用户id
	 * @param  $ModeID 模式id
	 * @param  $SelectStreamType  任务类型，0:控制任务，1：广播任务，2：都选，3：都不选
	 * @param  $Enabled 1：运行模式，0：备用模式
	 * @param  $Sort 排序字段
	 * @param  $Order 排序方式
	 * @param  $Start 起始位置
	 * @param  $Size 获取条数
	 */
	private static function listModeTask($UserId, $ModeID, $SelectStreamType, $Enabled, $Sort, $Order, $Start, $Size) {
		
		if (! is_null ( $UserId )) {
			return array ('Total' => 0, 'Rows' => array () );
		}
		$sql = "SELECT a.SessionID, '' AS FileName, IF(ISNULL(e.PlayListCount), 0, e.PlayListCount) AS PlayListCount,  a.ScheduleID, DATE_FORMAT(a.PlayTime,'%H:%i:%S') as PlayTime, a.TempFlag, 
					b.SessionName, b.SessionType, b.Priority, b.CircleLength, b.BrdMode, b.StreamType,
			 		b.SysEnabled, b.RfDevCtrl, dd.Pause 
			 	FROM PlaySessionTime a 
			 	LEFT JOIN PlaySessions b on a.SessionID=b.SessionID 
			 	LEFT JOIN PlayingSessions dd ON a.SessionID=dd.SessionID AND a.ScheduleID=dd.ScheduleID 
			 	LEFT JOIN (SELECT SessionID, COUNT(*) AS PlayListCount FROM PlayListFiles GROUP BY SessionID) e ON e.SessionID = a.SessionID
			 	WHERE b.BrdMode IN(SELECT idBroadcastMode FROM BroadcastMode WHERE Enabled = '" . $Enabled . "' AND idBroadcastMode='" . $ModeID . "') ";
		
		//任务类型筛选,0:控制任务，1：广播任务，2：都选，3：都不选
		if (is_numeric ( $SelectStreamType )) {
			switch ($SelectStreamType) {
				case 0 : //控制任务
					$sql = $sql . " AND b.StreamType&7 = 0";
					break;
				case 1 : //广播任务
					$sql = $sql . " AND b.StreamType&7 != 0";
					break;
				case 2 : //所有任务
					break;
				case 3 : //都不选
					$sql = $sql . " AND b.StreamType&7 = -1";
					break;
				default :
					break;
			}
		}
		//获取总数
		$Count = 0;
		$CountSql = 'SELECT COUNT(*) c FROM (' . $sql . ') CC';
		$TempData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $TempData )) {
			$Count = $TempData ['c'];
		}
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ('SessionName' == $Sort) { //任务名字
				$Sort = 'SessionName';
			} else if ('Priority' == $Sort) { //优先级
				$Sort = 'Priority';
			} else if ('PlayTime' == $Sort) { //执行时间
				$Sort = 'PlayTime';
			} else if ('SysEnabled' == $Sort) { //设备控制
				$Sort = 'SysEnabled';
			} else if ('RfDevCtrl' == $Sort) { //扩展设备状态
				$Sort = 'RfDevCtrl';
			} else if ('CircleLength' == $Sort) { //播出时长
				$Sort = 'CircleLength';
			} else {
				$Sort = 'PlayTime';
			}
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			
			$sql .= " ORDER BY " . $Sort . " " . $Order;
		} else {
			$sql .= " ORDER BY PlayTime ASC";
		}
		
		if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql .= " LIMIT " . $Start . "," . $Size;
		}
		$result = DBMethodUtils::listData ( $sql );
		
		if (! is_null ( $result ) && count ( $result ) > 0) {
			$arr = array ();
			
			//扩展设备信息
			$expandSource = null;
			//子设备模式
			$expandMode = null;
			$hasloadExpandMode = false;
			
			foreach ( $result as $item ) {
				$newitem = ATaskUtil::packTaskListByWeekday ( $item );
				
				if (empty ( $newitem )) {
					continue;
				}
				$arr [count ( $arr )] = $newitem;
			}
			
			return array ('Total' => $Count, 'Rows' => $arr );
		}
		
		return array ('Total' => 0, 'Rows' => array () );
	}
	
	//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	

	/**
	 * 加载设备
	 * @param $UserID
	 * @param $ModeId
	 * @param $Parent
	 */
	public static function LoadDevices($UserID, $ModeId, $Parent) {
		
		$sql = 'SELECT a.DevID AS id, a.Dev_Name AS text, a.Parent AS Parent, 1 AS IsDevice, "closed" AS state, 
					IF(ISNULL(b.BrdModeID), 0, 1) AS checked 
				FROM DeviceList a 
				LEFT JOIN (SELECT * FROM BrdModeMember WHERE BrdModeID=' . $ModeId . ') AS b ON a.DevID = b.DeviceID ';
		
		if (empty ( $Parent )) {
			$sql .= ' WHERE ISNULL(a.Parent)';
		} else {
			$sql .= ' WHERE a.Parent = ' . $Parent;
		}
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DevID", $UserID );
		}
		$sql .= ' ORDER by a.DevID';
		$Res = DBMethodUtils::listData ( $sql );
		
		return $Res;
	}
	
	/**
	 * 加载分区
	 * @param  $UserID
	 * @param  $ModeId
	 * @param  $Parent
	 */
	public static function LoadDevClass($UserID, $ModeId, $Parent) {
		
		$sql = 'SELECT ClassID AS id,Name as text, Parent AS Parent, 0 AS IsDevice, "closed" AS state, 0 AS checked FROM DevClasses';
		
		if (empty ( $Parent )) {
			$sql .= ' WHERE ISNULL(Parent)';
		} else {
			$sql .= ' WHERE Parent = ' . $Parent;
		}
		$Out = DBMethodUtils::listData ( $sql );
		
		if (! empty ( $Out )) {
			foreach ( $Out as $key => $item ) {
				//加载子节点分类成员
				$Children = ATaskUtil::LoadDevClass ( $UserID, $ModeId, $item ['id'] );
				//加载子节点设备
				$Devs = ATaskUtil::LoadDevices ( $UserID, $ModeId, $item ['id'] );
				
				if (! empty ( $Devs )) {
					if (empty ( $Children )) {
						$Children = $Devs;
					} else {
						$Children = array_merge ( $Children, $Devs );
					}
				}
				$Out [$key] ['children'] = $Children;
			}
		}
		
		return $Out;
	}
	
	/**
	 * 加载模式成员
	 * @param $ModeId
	 * @param $UserID
	 */
	public static function LoadModeDevice($ModeId, $UserID) {
		
		$DeviceClassArr = ATaskUtil::LoadDevClass ( $UserID, $ModeId, null );
		
		$Devs = ATaskUtil::LoadDevices ( $UserID, $ModeId, null );
		$DeviceClassArr = empty ( $DeviceClassArr ) ? array () : $DeviceClassArr;
		
		if (! empty ( $Devs )) {
			$DeviceClassArr = array_merge ( $DeviceClassArr, $Devs );
		}
		$selectAll = 0;
		
		return ATaskUtil::dealDeviceTree ( $DeviceClassArr, $selectAll );
	}
	
	/**
	 * 处理设备树形结构
	 * @param $TreeData
	 * @param $selectAll 0 : 不选中，1：选中，2：半选
	 */
	public static function dealDeviceTree($TreeData, &$selectAll) {
		
		if (empty ( $TreeData )) {
			return $TreeData;
		}
		$out = array ();
		$SelectNum = 0;
		$HasHalf = false;
		
		foreach ( $TreeData as $key => $item ) {
			$item ['id'] = str_replace ( 'DC_', "", $item ['id'] );
			$item ['Parent'] = str_replace ( 'DC_', "", $item ['Parent'] );
			$item ['name'] = $item ['text'];
			$item ['checked'] = intval ( $item ['checked'] );
			$item ['open'] = false;
			
			if ($item ['Parent'] == "") {
				$item ['Parent'] = null;
			}
			if ($item ['IsDevice'] != 0) { //是设备
				$out [] = $item;
				
				if ($item ['checked'] == 1) {
					$SelectNum ++;
				} else {
					$HasHalf = true;
				}
				continue;
			}
			
			//是分类
			if (empty ( $item ['children'] )) {
			} else {
				$TempAll = 1;
				$children = ATaskUtil::dealDeviceTree ( $item ['children'], $TempAll );
				
				if (! empty ( $children )) {
					$item ['checked'] = $TempAll == 1 || $TempAll == 2 ? 1 : 0;
					$item ['halfCheck'] = $TempAll == 2 ? 1 : 0;
					$item ['children'] = $children;
					$out [] = $item;
				}
				
				if ($TempAll == 1) {
					$SelectNum ++;
				} else if ($TempAll == 2) {
					$HasHalf = true;
				}
			}
		}
		$selectAll = $SelectNum <= 0 ? 0 : ($HasHalf ? 2 : 1);
		
		return $out;
	}
	
	//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	/**
	 * 获取手动任务
	 * @param  $id 任务id
	 */
	public static function getHandTask($id) {
		
		$task = PlaySessions::model ()->findByPk ( $id );
		
		if (empty ( $task ) || ! in_array ( $task->SessionType, array (2, 9 ) )) {
			return null;
		}
		
		return $task;
	}
}