<?php
class DeviceUtil {
	
	/*********************************************************/
	//设备类型
	const DEV_TYPE_UNKNOWN = 0;
	const DEV_TYPE_CENTRAL_NON_BRD = 1;
	const DEV_TYPE_CENTRAL_BRD = 2;
	const DEV_TYPE_BRD_DECODER = 3;
	const DEV_TYPE_PC_CALLER = 4;
	const DEV_TYPE_EMBEDED_CALLER = 5;
	const DEV_TYPE_BRD_CABINET = 6;
	const DEV_TYPE_GROUP = 7;
	/*********************************************************/
	
	/**
	 * 获取设备类型
	 * @param $DevID 设备ID
	 */
	public static function GetDevType($DevID) {
		
		if ($DevID == null || strlen ( $DevID ) < 1) {
			return DeviceUtil::DEV_TYPE_UNKNOWN;
		}
		switch (substr ( $DevID, 0, 1 )) {
			case "0" :
				return DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD;
			case "2" :
				return DeviceUtil::DEV_TYPE_CENTRAL_BRD;
			case "4" :
				if (strlen ( $DevID ) >= 2 && substr ( $DevID, 0, 2 ) == "49") {
					return DeviceUtil::DEV_TYPE_BRD_CABINET;
				} else {
					return DeviceUtil::DEV_TYPE_BRD_DECODER;
				}
			case "3" :
				return DeviceUtil::DEV_TYPE_EMBEDED_CALLER;
			case "5" :
				return DeviceUtil::DEV_TYPE_PC_CALLER;
			default :
				return DeviceUtil::DEV_TYPE_UNKNOWN;
		}
	}
	
	/**
	 * 加载设备分类ID；通过父节点找到与之相关的子节点
	 * @param $Parent 父节点id
	 */
	public static function LoadClassesId($Parent) {
		
		$result = array ($Parent );
		
		$sql = "select ClassID from DevClasses where Parent in (" . $Parent . ")";
		$res = DBMethodUtils::listData ( $sql );
		
		if (! is_null ( $res )) {
			foreach ( $res as $item ) {
				$result [count ( $result )] = $item ['ClassID'];
				$itemarr = DeviceUtil::LoadClassesId ( $item ['ClassID'] );
				
				if (! is_null ( $itemarr ) && count ( $itemarr ) > 0) {
					foreach ( $itemarr as $i ) {
						if (! in_array ( $i, $result )) {
							$result [count ( $result )] = $i;
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	/**
	 * 组装设备信息
	 * @param $item 原始数据
	 * @param $expandSource 扩展电源信息
	 * @param $expandMode 扩展电源模式
	 */
	public static function PackDevice($item, $expandSource, $expandMode, $islist = false, $CtrlPer = true, $ExpandPer = true) {
		
		if (is_null ( $item )) {
			return null;
		}
		$newitem = array ();
		$TempType = DeviceUtil::GetDevType ( $item ['DevID'] );
		
		$newitem ["DevID"] = $item ["DevID"]; //设备id
		$newitem ["Dev_Type"] = $TempType;
		$newitem ["Dev_Name"] = $item ["Dev_Name"]; //设备名字
		$newitem ["Parent"] = $item ["Parent"]; //父节点id
		$newitem ["Dev_Description"] = empty ( $item ["Dev_Description"] ) ? $item ["DevID"] : ToolUtil::charsetToUTF8 ( $item ["Dev_Description"] ); //物理位置
		$newitem ["IpAddress"] = empty ( $item ["IpAddress"] ) ? '' : $item ["IpAddress"]; //设备的ip地址
		$newitem ["State_Online"] = empty ( $item ["DeviceStatus"] ) ? 0 : 1; //设备是否联机，0：灭有联机，1：联机
		$newitem ["State_Pc"] = isset($item["State_Pc"]) ? $item["State_Pc"] : ""; //电脑状态，1：开机，0：关机

		$newitem ["State_SysPower"] = $item ["State_SysPower"]; //设备的状态：0 为关机， 1 为开机，2 为禁用，NULL 表示设备不在线
		$newitem ["User_Desc"] = empty ( $item ["User_Desc"] ) ? "" : $item ["User_Desc"];
		$newitem ["ActualSessionID"] = $item ["ActualSessionID"]; //实际的sessionID，及播放任务
		

		if ($CtrlPer) { //具有中控设备的管理权限，需要显示"任务模式"， "状态", "投影机", "广播"
			$newitem ["ModeName"] = isset ( $item ["ModeName"] ) ? $item ["ModeName"] : ''; //任务模式
			$newitem ["SessionName"] = $item ["SessionName"]; //实际播放的任务名字
			$newitem ["State_ProjectorStatus"] = $item ["State_ProjectorStatus"]; //投影机状态：0 为关机，1 为开机，2 为正在开机过程中，3 为正在关机过程中，NULL 表示设备不在线
			$newitem ["State_ProjectorLampStatus"] = $item ["State_ProjectorLampStatus"]; //投影仪灯泡的状态，0关闭，1开启
			

			if ($islist == false) {
				$newitem ["State_CurrProjectorSrc"] = $item ["State_CurrProjectorSrc"]; //当前投影仪播放内容的来源方式：1计算机，2笔记本，3数字展台，4视屏，6关闭状态
			}
			$newitem ["State_CurrAudio"] = $item ["State_CurrAudio"]; //当前音频来源方式：1计算机，2笔记本，3数字站台，4广播，5关闭,0当作5来处理
			$newitem ["State_FaultStatus"] = $item ["State_FaultStatus"]; //0投影机没故障，1投影机有故障
		}
		
		$newitem ["State_ExDevice1Status"] = $item ["State_ExDevice1Status"]; //扩展电源1
		$newitem ["State_ExDevice2Status"] = $item ["State_ExDevice2Status"]; //扩展电源2
		

		if ($islist == false) {
			$newitem ["State_CurrAudioVolume"] = $item ["State_CurrAudioVolume"]; //当前音频的音量
			$newitem ["State_CurrMicVolume"] = $item ["State_CurrMicVolume"]; //当前麦克风的音量
			$newitem ["State_MicState"] = $item ["State_MicState"]; //麦克风的状态：0关闭，1开启
			$newitem ["State_Mute"] = $item ["State_Mute"]; //静音状态：0不静音，1静音
			$newitem ["State_CentralUsedTime"] = $item ["State_CentralUsedTime"]; //设备总的使用时间，单位秒
			$newitem ["State_ProjectorUsedTime"] = $item ["State_ProjectorUsedTime"]; //投影仪总的使用时间，单位秒
			$newitem ["State_LightUsedTime"] = $item ["State_LightUsedTime"]; //投影仪灯总的使用时间，单位秒
			$newitem ["Cfg_System"] = ToolUtil::charsetToUTF8 ( $item ["Cfg_System"] ); //配置中系统的启用状态：1启用，0禁用
			$newitem ["Cfg_Remark"] = $item ["Cfg_Remark"]; //物理位置
		}
		//$newitem ["RfDevStatus"] = $item ["RfDevStatus"]; //16个字节，下标2,3分别表示空调一，二。Bit7表示空调压缩机开启来没的（页面空调图标），每个字节的低4bit为空调状态，1000： 空调关闭；1001～1100 ： 对应运行模式1～4。
		

		//广播是否可以控制
		$newitem ['BrdCtrl'] = 0;
		
		if ($newitem ["ActualSessionID"] > 0 && DeviceUtil::IsSessionCtrlValid ( $newitem ['State_Online'], $newitem ["Dev_Type"] ) && $CtrlPer) { //广播可以控制
			$newitem ['BrdCtrl'] = 1;
		}
		
		if ($ExpandPer) { //有物联设备管理权限
			//扩展设备信息
			$newitem ['RfDevStatus'] = DeviceUtil::DepackRfDevCtrl ( $expandSource, $item ['RfDevStatus'], $expandMode );
		}
		$SteamTypeUp = round ( $item ['StreamType'] / 128 );
		$newitem ['SteamTypeUp'] = $SteamTypeUp == 1 ? 1 : 0;
		$newitem ['IsCtrl'] = 1;
		
		switch ($TempType) {
			case DeviceUtil::DEV_TYPE_GROUP :
				break;
			case DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD :
			case DeviceUtil::DEV_TYPE_CENTRAL_BRD :
				$newitem ['IsCtrl'] = 1;
				break;
			case DeviceUtil::DEV_TYPE_BRD_DECODER :
			case DeviceUtil::DEV_TYPE_BRD_CABINET :
				$newitem ['IsCtrl'] = 2;
				break;
			case DeviceUtil::DEV_TYPE_EMBEDED_CALLER :
			case DeviceUtil::DEV_TYPE_PC_CALLER :
				break;
		}
//		
//		if (($TempType != DeviceUtil::DEV_TYPE_CENTRAL_BRD) && ($TempType != DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD)) { //节点
//			$newitem ['IsCtrl'] = 0;
//		} else if (($TempType != DeviceUtil::DEV_TYPE_BRD_DECODER) && ($TempType != DeviceUtil::DEV_TYPE_BRD_CABINET)) { //中控
//			$newitem ['IsCtrl'] = 1;
//		}
		$newitem ['id'] = $item ['DevID'];
		$newitem ['text'] = $item ['Dev_Name'];
		$newitem ['isDevice'] = 1;
		
		return $newitem;
	}
	
	/**
	 * 设备广播是否可以控制
	 * 
	 * @param $Online 是否在线
	 * @param $DevType 设备类型
	 */
	public static function IsSessionCtrlValid($Online, $DevType) {
		
		if ($Online == 0) {
			return false;
		}
		
		if ($DevType != DeviceUtil::DEV_TYPE_CENTRAL_BRD && $DevType != DeviceUtil::DEV_TYPE_BRD_DECODER && $DevType != DeviceUtil::DEV_TYPE_BRD_CABINET) {
			return false;
		}
		
		return true;
	}
	
	/**
	 * 组装设备信息
	 * @param $item 原始数据
	 * @param $expandSource 扩展电源信息
	 * @param $expandMode 扩展电源模式
	 */
	public static function PackDeviceForWeb($item, $expandSource, $expandMode, $islist = false) {
		
		if (is_null ( $item )) {
			return null;
		}
		$newitem = array ();
		$newitem ["DevID"] = $item ["DevID"]; //设备id
		$newitem ["Dev_Type"] = DeviceUtil::GetDevType ( $item ['DevID'] );
		$newitem ["Dev_Name"] = $item ["Dev_Name"]; //设备名字
		$newitem ["Parent"] = $item ["Parent"]; //父节点id
		$newitem ["Dev_Description"] = ToolUtil::charsetToUTF8 ( $item ["Dev_Description"] ); //物理位置
		$newitem ["IpAddress"] = $item ["IpAddress"]; //设备的ip地址
		

		//		if ($islist == false) {
		//		$newitem ["Dev_Configuration"] = ToolUtil::charsetToUTF8 ( $item ["Dev_Configuration"] ); 
		//		$newitem ["DeviceID"] = $item ["DeviceID"];
		//		$newitem ["DeviceType"] = $item ["DeviceType"];
		//		$newitem ["DeviceStatus"] = $item ["DeviceStatus"];
		//		$newitem ["ShouldSessionID"] = $item ["ShouldSessionID"];
		//		}
		$newitem ["ModeName"] = isset ( $item ["ModeName"] ) ? $item ["ModeName"] : ''; //任务模式
		$newitem ["ActualSessionID"] = $item ["ActualSessionID"]; //实际的sessionID，及播放任务
		$newitem ["SessionName"] = $item ["SessionName"]; //实际播放的任务名字
		$newitem ["State_Online"] = empty ( $item ["DeviceStatus"] ) ? 0 : 1; //设备是否联机，0：灭有联机，1：联机
		$newitem ["State_SysPower"] = $item ["State_SysPower"]; //设备的状态：0 为关机， 1 为开机，2 为禁用，NULL 表示设备不在线
		$newitem ["State_ProjectorStatus"] = $item ["State_ProjectorStatus"]; //投影机状态：0 为关机，1 为开机，2 为正在开机过程中，3 为正在关机过程中，NULL 表示设备不在线
		$newitem ["State_ProjectorLampStatus"] = $item ["State_ProjectorLampStatus"]; //投影仪灯泡的状态，0关闭，1开启
		$newitem ["State_ExDevice1Status"] = $item ["State_ExDevice1Status"]; //扩展电源1
		$newitem ["State_ExDevice2Status"] = $item ["State_ExDevice2Status"]; //扩展电源2
		$newitem ['RfDevStatus'] = $item ['RfDevStatus'];
		
		if ($islist == false) {
			$newitem ["State_CurrProjectorSrc"] = $item ["State_CurrProjectorSrc"]; //当前投影仪播放内容的来源方式：1计算机，2笔记本，3数字展台，4视屏，6关闭状态
		}
		$newitem ["State_CurrAudio"] = $item ["State_CurrAudio"]; //当前音频来源方式：1计算机，2笔记本，3数字站台，4广播，5关闭,0当作5来处理
		

		if ($islist == false) {
			$newitem ["State_CurrAudioVolume"] = $item ["State_CurrAudioVolume"]; //当前音频的音量
			$newitem ["State_CurrMicVolume"] = $item ["State_CurrMicVolume"]; //当前麦克风的音量
			$newitem ["State_FaultStatus"] = $item ["State_FaultStatus"]; //0投影机没故障，1投影机有故障
			$newitem ["State_MicState"] = $item ["State_MicState"]; //麦克风的状态：0关闭，1开启
			$newitem ["State_Mute"] = $item ["State_Mute"]; //静音状态：0不静音，1静音
			$newitem ["State_CentralUsedTime"] = $item ["State_CentralUsedTime"]; //设备总的使用时间，单位秒
			$newitem ["State_ProjectorUsedTime"] = $item ["State_ProjectorUsedTime"]; //投影仪总的使用时间，单位秒
			$newitem ["State_LightUsedTime"] = $item ["State_LightUsedTime"]; //投影仪灯总的使用时间，单位秒
			$newitem ["Cfg_System"] = ToolUtil::charsetToUTF8 ( $item ["Cfg_System"] ); //配置中系统的启用状态：1启用，0禁用
			$newitem ["Cfg_Remark"] = $item ["Cfg_Remark"]; //物理位置
		}
		
		//广播是否可以控制
		//		$newitem['BrdCtrl'] = 0;
		//		
		//		if ($newitem ["ActualSessionID"] > 0 && DeviceUtil::IsSessionCtrlValid($newitem['State_Online'], $newitem ["Dev_Type"]) && $CtrlPer) {//广播可以控制
		//			$newitem['BrdCtrl'] = 1;
		//		}
		

		//扩展设备信息
		$TempData = DeviceUtil::DepackRfDevCtrl ( $expandSource, $item ['RfDevStatus'], $expandMode );
		
		if (! empty ( $TempData )) {
			foreach ( $TempData as $value ) {
				$newitem ['PwrID_' . $value ['PwrID']] = $value;
			}
		}
		
		return $newitem;
	}
	
	/**
	 * 拆分获得扩展设备状态 
	 * @param $expandSource 扩展设备信息
	 * @param $RfDevStatus 扩展设备状态信息,数据库读取出来的数据
	 * @param $expandMode 扩展设备模式信息
	 * @return 
	 */
	public static function DepackRfDevCtrl($expandSource, $RfDevStatus, $expandMode) {
		
		if (is_null ( $expandSource ) || count ( $expandSource ) <= 0) {
			return null;
		}
		//扩展设备信息
		$newexpandSource = array ();
		//状态模式列表
		$RfDevModeArr = array ();
		//
		$RfDevOnlieArr = array ();
		
		if (! is_null ( $RfDevStatus )) { //把状态拆分成16分
			$temp = bin2hex ( $RfDevStatus );
			$pos = 0;
			$onliepos = 0;
			for($i = 0; $i < strlen ( $temp ) - 1; $i = $i + 2) {
				$RfDevModeArr [$pos ++] = hexdec ( substr ( $temp, $i, 2 ) ) & 0x0F;
				$RfDevOnlieArr [$onliepos ++] = (hexdec ( substr ( $temp, $i, 2 ) ) & 0x80) / 0x80;
			}
		}
		
		foreach ( $expandSource as $item ) {
			$newexpanditem = array ();
			$newexpanditem ['PwrID'] = $item ['PwrID']; //电源id
			$newexpanditem ['Name'] = $item ['Name']; //电源名字
			$newexpanditem ['Type'] = $item ['Type']; //电源类型
			$newexpanditem ['Mode'] = null; //模式ID
			$newexpanditem ['Mode_Desc'] = ''; //模式描述
			$newexpanditem ['Online'] = 0; //是否在线，1：在，0：离线
			
			if (! is_null ( $RfDevStatus )) { //有状态
				//获取设备运行状态
				$model = $RfDevModeArr [$newexpanditem ['PwrID']] - 8;
				
				if (! is_null ( $expandMode ) && isset ( $expandMode [$newexpanditem ['Type']] ) && isset ( $expandMode [$newexpanditem ['Type']] [$model] )) {
					$newexpanditem ['Mode'] = $model;
					$newexpanditem ['Mode_Desc'] = $expandMode [$newexpanditem ['Type']] [$model];
					$newexpanditem ['Online'] = isset ( $RfDevOnlieArr [$newexpanditem ['PwrID']] ) ? $RfDevOnlieArr [$newexpanditem ['PwrID']] : 0;
				}
			} else { //没有状态
			

			}
			$newexpandSource [count ( $newexpandSource )] = $newexpanditem;
		}
		
		return $newexpandSource;
	}
	
	/**
	 * 组装设备树结构
	 * @param $DeviceClassArr 设备分类树形结构
	 * @param $HasParentDev 拥有父节点的设备，key：父节点ID
	 */
	public static function PackDeviceTree($DeviceClassArr, $HasParentDev) {
		
		$result = array ();
		
		foreach ( $DeviceClassArr as $item ) {
			$newitem = $item;
			
			if (isset ( $newitem ['children'] ) && ! is_null ( $newitem ['children'] ) && count ( $newitem ['children'] ) > 0) {
				//有子节点,需要下一级继续
				$children = $newitem ['children'];
				//获取自己点信息
				$children = DeviceUtil::PackDeviceTree ( $children, $HasParentDev );
				
				if (is_null ( $children )) {
					$children = array ();
				}
				if (isset ( $HasParentDev [$item ['id']] ) && ! is_null ( $HasParentDev [$item ['id']] )) {
					foreach ( $HasParentDev [$item ['id']] as $a ) {
						$children [count ( $children )] = $a;
					}
				}
				$newitem ['children'] = $children;
				
				if (! empty ( $children )) {
					$newitem ['state'] = "closed";
				}
			} else {
				//没有子节点
				if (isset ( $HasParentDev [$item ['id']] )) {
					$newitem ['children'] = $HasParentDev [$item ['id']];
					
					if (! empty ( $newitem ['children'] )) {
						$newitem ['state'] = "closed";
					}
				}
			}
			$result [count ( $result )] = $newitem;
		}
		
		return $result;
	}
	
	/**
	 * 获取角色控制的设备字符串
	 * @param unknown_type $owner
	 */
	public static function GetUserCtrDevSql($conditional, $owner) {
		
		//这里只包括管理设备

        $User = Users::model ()->findByPk ( $owner );
        if (! is_null ( $owner ) && $owner > 0 && $User['Mgr_Privilege'] != 1) {
			return $conditional . ' IN (SELECT DevID FROM UserDevices WHERE UserID="' . $owner . '" AND Pri & ' . SystemUtil::getUserDevMask ( "1" ) . ' > 0)';
		}
		
		return "";
	}
	
	/**
	 * 获取设备分组父节点
	 * @param $Parent
	 */
	public static function LoadDevClassParentId($Id) {
		
		if (is_null ( $Id )) {
			return array ();
		}
		
		$result = array ($Id );
		
		$sql = "SELECT Parent from DevClasses WHERE ClassID IN (" . $Id . ")";
		$res = DBMethodUtils::listData ( $sql );
		
		if (! is_null ( $res )) {
			foreach ( $res as $item ) {
				if (empty ( $item ['Parent'] ) || $item ['Parent'] <= 0) {
					continue;
				}
				$result [count ( $result )] = $item ['Parent'];
				$itemarr = DeviceUtil::LoadClassesId ( $item ['Parent'] );
				
				if (! is_null ( $itemarr ) && count ( $itemarr ) > 0) {
					foreach ( $itemarr as $i ) {
						if (! in_array ( $i, $result )) {
							$result [count ( $result )] = $i;
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	/**
	 * 获取设备分组父节点
	 * @param $Parent
	 */
	public static function LoadDevClassParentIdOnly($Id) {
		
		$result = array ($Id );
		
		$sql = "SELECT Parent from DevClasses WHERE ClassID IN (" . $Id . ")";
		$res = DBMethodUtils::listData ( $sql );
		
		if (! is_null ( $res )) {
			foreach ( $res as $item ) {
				if (empty ( $item ['Parent'] ) || $item ['Parent'] <= 0) {
					continue;
				}
				$result [count ( $result )] = $item ['Parent'];
				$itemarr = DeviceUtil::LoadDevClassParentIdOnly ( $item ['Parent'] );
				
				if (! is_null ( $itemarr ) && count ( $itemarr ) > 0) {
					foreach ( $itemarr as $i ) {
						if (! in_array ( $i, $result )) {
							$result [count ( $result )] = $i;
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	/**
	 * 获取设备分类
	 * @param $ID
	 */
	public static function LoadDevClass($ID) {
		
		$data = DBMethodUtils::findData ( 'SELECT * FROM DevClasses WHERE ClassID=:ClassID"', array(':ClassID' => $ID) );
		
		return $data;
	}
	
	/**
	 * 处理设备树形结构
	 * @param $TreeData
	 */
	public static function dealDeviceTree($TreeData) {
		
		if (empty ( $TreeData )) {
			return $TreeData;
		}
		$out = array ();
		
		foreach ( $TreeData as $key => $item ) {
			if ($item ['IsDevice'] != 0) { //是设备
				$out [] = $item;
				continue;
			}
			//是分类
			if (empty ( $item ['children'] )) {
			} else {
				$children = DeviceUtil::dealDeviceTree ( $item ['children'] );
				
				if (! empty ( $children )) {
					$item ['children'] = $children;
					$out [] = $item;
				}
			}
		}
		
		return $out;
	}
	
	/**
	 * 处理设备分类树形结构
	 * @param unknown_type $TreeData
	 */
	public static function dealDeviceClassTree($TreeData) {
		
		if (empty ( $TreeData )) {
			return $TreeData;
		}
		$out = array ();
		
		foreach ( $TreeData as $key => $item ) {
			//是分类
			if (empty ( $item ['children'] )) {
				if ($item ['DeviceCount'] > 0) {
					$out [] = $item;
				}
			} else {
				$children = DeviceUtil::dealDeviceClassTree ( $item ['children'] );
				
				if (! empty ( $children ) || $item ['DeviceCount'] > 0) {
					$item ['children'] = $children;
					$out [] = $item;
				}
			}
		}
		
		return $out;
	}
}