<?php
class SystemUtil {
	
	const USER_DEVICE_USE_PRI_MASK = 1; //使用权限mask
	const USER_DEVICE_MGR_PRI_MASK = 2; //管理权限mask
	

	/**
	 * 获取用户设备权限掩码
	 * @param $Type 0:使用权限，1：管理权限
	 */
	public static function getUserDevMask($Type) {
		
		//pri位含义：0位、使用权限；1位、管理权限
		$mask = 0;
		
		if ($Type == "0") { //使用权限
			$mask = SystemUtil::USER_DEVICE_USE_PRI_MASK;
		
		} else if ($Type == "1") { //管理权限
			$mask = SystemUtil::USER_DEVICE_MGR_PRI_MASK;
		}
		
		return $mask;
	}
	
	/**
	 * 获取网络配置数据
	 * @param  $Start 开始数据
	 * @param  $Arr 命令获取的数组
	 */
	public static function LoadNetData($Start, $Arr) {
		
		foreach ( $Arr as $Item ) {
			$Item = strtolower ( $Item );
			
			if (strlen ( $Item ) <= strlen ( $Start )) {
				continue;
			}
			$Begin = substr ( $Item, 0, strlen ( $Start ) );
			
			if ($Begin == $Start) {
				return trim ( str_replace ( $Start, '', $Item ) );
			}
		}
		
		return '';
	}
	
	/**
	 * 获取用户设备列表 
	 * @param $UserID 用户id
	 * @param $type 设备类型，1：管理设备，0：使用设备
	 */
	public static function LoadUserDeviceTree($UserID, $MemberId, $Type, $AllDev = false) {
		
		$mask = SystemUtil::getUserDevMask ( $Type );
		
		$DeviceClassArr = SystemUtil::LoadDevClass ( $UserID, $MemberId, $mask, null, $AllDev );
		
		$Devs = SystemUtil::LoadDevices ( $UserID, $MemberId, $mask, null, $AllDev );

		if (! empty ( $Devs )) {
			if (empty ( $DeviceClassArr )) {
				$DeviceClassArr = $Devs;
			} else {
				$DeviceClassArr = array_merge ( $DeviceClassArr, $Devs );
			}
		}
		$selectAll = false;
		
		return SystemUtil::dealDeviceTree ( $DeviceClassArr, $selectAll );
	}
	
	/**
	 * 加载设备
	 * @param unknown_type $UserID
	 * @param unknown_type $mask
	 * @param unknown_type $Parent
	 */
	public static function LoadDevices($UserID, $MemberId, $mask, $Parent, $AllDev = false) {
        $sql = "Select Dev_Privilege , Mgr_Privilege from Users where User_ID='$MemberId';";
        $ret = DBMethodUtils::findData($sql);
        if(is_null($ret))
            return null;
        if(($mask == SystemUtil::USER_DEVICE_USE_PRI_MASK && $ret['Dev_Privilege'] === 1)
               || ($mask == SystemUtil::USER_DEVICE_MGR_PRI_MASK && $ret['Mgr_Privilege'] === 1)){
            $sql = 'SELECT a.DevID AS id, a.Dev_Name AS text,a.Parent AS Parent, 1 AS IsDevice, 
      			"closed" AS state, 1 AS checked FROM DeviceList a';
        }
        else{
            $sql = 'SELECT a.DevID AS id, a.Dev_Name AS text,a.Parent AS Parent, 1 AS IsDevice, 
      			"closed" AS state, IF(ISNULL(b.DevID), 0, 1) AS checked FROM DeviceList a';
            $sql .= ' LEFT JOIN UserDevices b ON a.DevID = b.DevID AND UserID = "' . $MemberId . '" AND Pri & ' . $mask . '  > 0';
        }

		if (empty ( $Parent )) {
			$sql .= ' WHERE ISNULL(a.Parent)';
		} else {
			$sql .= ' WHERE a.Parent = ' . $Parent;
		}

		if ((! is_null ( $UserID ) && $UserID > 0) && !$AllDev) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND a.DevID", $UserID );
		}
		$sql .= ' ORDER by a.DevID';

		return DBMethodUtils::listData ( $sql );
	}
	
	/**
	 * 加载分区
	 * @param unknown_type $UserID
	 * @param unknown_type $mask
	 * @param unknown_type $Parent
	 */
	public static function LoadDevClass($UserID, $MemberId, $mask, $Parent, $AllDev = false) {
		
		$sql = 'SELECT ClassID AS id,Name as text, Parent AS Parent, 0 AS IsDevice, "closed" AS state, false AS checked FROM DevClasses';
		
		if (empty ( $Parent )) {
			$sql .= ' WHERE ISNULL(Parent)';
		} else {
			$sql .= ' WHERE Parent = ' . $Parent;
		}
		$Out = DBMethodUtils::listData ( $sql );
		
		if (! empty ( $Out )) {
			foreach ( $Out as $key => $item ) {
				//加载子节点分类成员
				$Children = SystemUtil::LoadDevClass ( $UserID, $MemberId, $mask, $item ['id'] , $AllDev);
				//加载子节点设备
				$Devs = SystemUtil::LoadDevices ( $UserID, $MemberId, $mask, $item ['id'] , $AllDev);
				
				if (! empty ( $Devs )) {
					if (empty ( $Children )) {
						$Children = $Devs;
					} else {
						$Children = array_merge ( $Children, $Devs );
					}
				}
				$Out [$key] ['children'] = $Children;
			}
		}
		
		return $Out;
	}
	
	/**
	 * 处理设备树形结构
	 * @param $TreeData
	 */
	public static function dealDeviceTree($TreeData, &$selectAll) {
		
		//		if (empty ( $TreeData )) {
		//			return $TreeData;
		//		}
		//		$out = array ();
		//		$All = true;
		//		
		//		foreach ( $TreeData as $key => $item ) {
		//			$item ['id'] = str_replace ( 'DC_', "", $item ['id'] );
		//			$item ['Parent'] = str_replace ( 'DC_', "", $item ['Parent'] );
		//			
		//			if ($item ['Parent'] == "") {
		//				$item ['Parent'] = null;
		//			}
		//			if ($item ['IsDevice'] != 0) { //是设备
		//				$out [] = $item;
		//				
		//				if ($All && $item ['checked'] != 1) {
		//					$All = false;
		//				}
		//				continue;
		//			}
		//			
		//			//是分类
		//			if (empty ( $item ['children'] )) {
		//			} else {
		//				$TempAll = true;
		//				$children = TaskUtil::dealDeviceTree ( $item ['children'], $TempAll );
		//				
		//				if (! empty ( $children )) {
		//					$item ['checked'] = $TempAll ? 1 : 0;
		//					$item ['children'] = $children;
		//					$out [] = $item;
		//				}
		//				
		//				if ($All && ! $TempAll) {
		//					$All = false;
		//				}
		//			}
		//		}
		//		$selectAll = $All;
		//		
		//		return $out;
		

		if (empty ( $TreeData )) {
			return $TreeData;
		}
		$out = array ();
		$SelectNum = 0;
		$HasHalf = false;
		
		foreach ( $TreeData as $key => $item ) {
			$item ['id'] = str_replace ( 'DC_', "", $item ['id'] );
			$item ['Parent'] = str_replace ( 'DC_', "", $item ['Parent'] );
			$item ['name'] = $item ['text'];
			$item ['checked'] = intval ( $item ['checked'] );
			$item ['open'] = false;
			
			if ($item ['Parent'] == "") {
				$item ['Parent'] = null;
			}
			if ($item ['IsDevice'] != 0) { //是设备
				$out [] = $item;
				
				if ($item ['checked'] == 1) {
					$SelectNum ++;
				} else {
					$HasHalf = true;
				}
				continue;
			}
			
			//是分类
			if (empty ( $item ['children'] )) {
			} else {
				$TempAll = 1;
				$children = SystemUtil::dealDeviceTree ( $item ['children'], $TempAll );
				
				if (! empty ( $children )) {
					$item ['checked'] = $TempAll == 1 || $TempAll == 2  ? 1 : 0;
					$item ['halfCheck'] = $TempAll == 2 ? 1 : 0;
					$item ['children'] = $children;
					$out [] = $item;
				}
				
				if ($TempAll == 1) {
					$SelectNum ++;
				} else if ($TempAll == 2) {
					$HasHalf = true;
				}
			}
		}
		$selectAll = $SelectNum <= 0 ? 0 : ($HasHalf ? 2 : 1);
		
		return $out;
	}
	
	/**
	 * 更新用户登录信息（账号密码）
	 * @param  $MemberId
	 * @param  $UserName
	 * @param  $PassWord
	 */
	public static function updateUserLoginInfo($MemberId, $UserName, $PassWord) {
		
		$ParamArr = array ();
		
		if (empty ( $UserName ) && empty ( $PassWord )) {
			$sql = 'UPDATE Users SET User_Name = NULL, Pass_Word = NULL WHERE User_ID = :User_ID';
			$ParamArr [':User_ID'] = $MemberId;
		} else if (empty ( $PassWord )) {
			$sql = 'UPDATE Users SET User_Name = :User_Name WHERE User_ID = :User_ID';
			$ParamArr [':User_ID'] = $MemberId;
			$ParamArr [':User_Name'] = $UserName;
		} else {
			$sql = 'UPDATE Users SET User_Name = :User_Name, Pass_Word = PASSWORD(:PassWord) WHERE User_ID = :User_ID';
			$ParamArr [':User_ID'] = $MemberId;
			$ParamArr [':User_Name'] = $UserName;
			$ParamArr [':PassWord'] = $PassWord;
		}
		DBMethodUtils::RunSql ( $sql, $ParamArr );
		
		return Users::model ()->findByPk ( $MemberId );
	}
	
	/**
	 * 更新用户设备
	 * @param unknown_type $MemberId
	 * @param unknown_type $DevIdList
	 * @param unknown_type $Type
	 */
	public static function updateUserDevice($MemberId, $DevIdList, $Type) {
		
		//pri位含义：0位、使用权限；1位、管理权限
		$mask = SystemUtil::getUserDevMask ( $Type );
		$unmask = 255 - $mask;
		$tempIdArr = array ();
		
		if (! empty ( $DevIdList )) { //没有可以使用的
			$tempArr = explode ( ",", $DevIdList );
			
			foreach ( $tempArr as $item ) {
				if (! empty ( $item )) {
					$tempIdArr [] = $item;
				}
			}
		}
		//删除不用的
		$sql = 'DELETE FROM UserDevices WHERE UserID = "' . $MemberId . '" AND Pri <= 0';
		DBMethodUtils::RunSql ( $sql );
		
		if (! empty ( $tempIdArr )) {
			//更新设备权限(设备有权限)
			$sql = 'UPDATE UserDevices SET Pri = Pri | ' . $mask . ' WHERE UserID = "' . $MemberId . '" AND DevID IN(' . implode ( ",", $tempIdArr ) . ')';
			DBMethodUtils::RunSql ( $sql );
			
			//更新设备权限(设备没有权限)
			$sql = 'UPDATE UserDevices SET Pri = Pri & ' . $unmask . ' WHERE UserID = "' . $MemberId . '" AND DevID  NOT IN(' . implode ( ",", $tempIdArr ) . ')';
			DBMethodUtils::RunSql ( $sql );
			
			//新增设备权限
			$sql = "INSERT IGNORE INTO UserDevices(UserID,DevID,Pri)VALUES";
			$vals = null;
			
			foreach ( $tempIdArr as $item ) {
				if (empty ( $vals )) {
					$vals = "('" . $MemberId . "','" . $item . "','" . $mask . "')";
				} else {
					$vals .= ",('" . $MemberId . "','" . $item . "','" . $mask . "')";
				}
			}
			if (! empty ( $vals )) {
				DBMethodUtils::RunSql ( $sql . $vals );
			}
		
		} else { //全部没有权限
			//更新设备权限(设备没有权限)
			$sql = 'UPDATE UserDevices SET Pri = Pri & ' . $unmask . ' WHERE UserID = "' . $MemberId . '"';
			DBMethodUtils::RunSql ( $sql );
		}
	}
}