<?php
class TaskUtil {
	
	/**
	 * 组装任务管理树父节点数据
	 * @param  $id 节点id
	 * @param  $text 节点描述
	 * @param  $action 节点访问的action
	 * @param  $children 子节点数组
	 */
	public static function PackTaskTreeParent($id, $text, $action, $children) {
		
		$arr = array ();
		$arr ['id'] = $id;
		$arr ['text'] = $text;
		$arr ['action'] = $action;
		$arr ['Parent'] = null;
		$arr ['children'] = $children;
		
		return $arr;
	}
	
	/**
	 * 加载运行模式
	 * @param $enabled 模式类型，0：备用模式，1：运行模式
	 */
	public static function LoadBrodcastModes($enabled, $parent) {
		
		$sql = "SELECT idBroadcastMode AS id, ModeName AS text, " . $parent . " AS Parent FROM BroadcastMode WHERE Enabled='" . $enabled . "'";
		$result = DBMethodUtils::listData ( $sql );
		
		return $result;
	}
	
	/**
	 * 获取模式任务
	 * @param  $enabled 模式类型，0：备用模式，1：运行模式
	 * @param $ModeID 模式ID
	 * @param $page 分页信息，格式：limit 1,2
	 * @param $UserID 用户id
	 * @param $StreamType 任务类型
	 */
	public static function LoadModeTask($enabled, $ModeID, $page, $UserID, $StreamType, $SortName, $SortOrder) {
		
		$sql = "SELECT a.SessionID, DATE_FORMAT(a.PlayTime,'%H:%i:%S') as PlayTime, a.TempFlag, b.SessionName, b.SessionType, b.Priority, b.CircleLength, b.BrdMode, b.StreamType,
			 b.SysEnabled, b.RfDevCtrl, dd.Pause FROM PlaySessionTime a LEFT JOIN PlaySessions b on a.SessionID=b.SessionID LEFT JOIN PlayingSessions dd 
			 ON a.SessionID=dd.SessionID AND a.ScheduleID=dd.ScheduleID WHERE b.BrdMode IN(SELECT idBroadcastMode 
			 FROM BroadcastMode WHERE Enabled = '" . $enabled . "' AND idBroadcastMode='" . $ModeID . "') ";
		
		//任务类型筛选,0:控制任务，1：广播任务，2：都选，3：都不选
		if (is_numeric ( $StreamType )) {
			switch ($StreamType) {
				case 0 : //控制任务
					$sql = $sql . " AND b.StreamType&7 = 0";
					break;
				case 1 : //广播任务
					$sql = $sql . " AND b.StreamType&7 != 0";
					break;
				case 2 : //所有任务
					break;
				case 3 : //都不选
					$sql = $sql . " AND b.StreamType&7 = -1";
					break;
				default :
					break;
			}
		}
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= " AND Owner=" . $UserID;
		}
		if (! empty ( $SortName ) && ! empty ( $SortOrder )) {
			$sql .= " ORDER BY " . $SortName . " " . $SortOrder;
		} else {
			$sql .= " ORDER BY PlayTime ASC";
		}
		
		$sql .= " " . $page;
		$result = DBMethodUtils::listData ( $sql );
		
		if (! is_null ( $result ) && count ( $result ) > 0) {
			$arr = array ();
			
			//扩展设备信息
			$expandSource = null;
			//子设备模式
			$expandMode = null;
			$hasloadExpandMode = false;
			
			foreach ( $result as $item ) {
				$newitem = array ();
				$newitem ['SessionID'] = $item ['SessionID']; //任务id
				$newitem ['PlayTime'] = $item ['PlayTime']; //播出时间
				$newitem ['TempFlag'] = $item ['TempFlag']; //是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录
				$newitem ['SessionName'] = $item ['SessionName']; //任务名称
				$newitem ['SessionType'] = $item ['SessionType']; //0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
				$newitem ['Priority'] = $item ['Priority']; //优先级
				$newitem ['SteamTypeDown'] = $item ['StreamType'] - round ( $item ['StreamType'] / 128 ) * 128; //00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
				$newitem ["Pause"] = $item ["Pause"]; //播出状态（仅广播才有），1暂停，0正在播放,null:没有播出状态
				

				if ($newitem ['SteamTypeDown'] == 0) { //控制任务
					$newitem ['SysEnabled'] = $item ['SysEnabled']; //系统启禁用状态，1启用，0禁用，仅控制任务才使用这个字段
					//$newitem ['RfDevCtrl'] = $item ['RfDevCtrl']; //16个字节，下标2,3分别表示空调一，二。每个字节的低4bit为空调状态，1000： 空调关闭；1001～1100 ： 对应运行模式1～4
					if (is_null ( $expandSource )) {
						//加载扩展设备信息
						$expandSource = ExpandUtil::LoadExpandDev ();
					}
					
					//扩展设备信息
					if (! is_null ( $expandSource ) && count ( $expandSource ) > 0) {
						
						if (! $hasloadExpandMode) {
							//加载扩展设备模式
							$expandMode = ExpandUtil::LoadExpandMode ();
							$hasloadExpandMode = true;
						}
						//说明有扩展电源
						$newexpandSource = DeviceUtil::DepackRfDevCtrl ( $expandSource, $item ['RfDevCtrl'], $expandMode );
						$newitem ['DeviceCtrl'] = $newexpandSource;
					}
				}
				$arr [count ( $arr )] = $newitem;
			}
			
			return $arr;
		} else {
			return array ();
		}
	}
	
	/**
	 * 添加广播的播放列表
	 * @param $SessionID 任务ID
	 * @param $PlayFileList 最终的播放列表数据(JSON数组解析后的数据),JSON数组格式：[{'FileID' : 12}]
	 */
	public static function DealBroadcastPlayFileList($SessionID, $PlayFileList) {
		
		//删除原来的播放列表
		$sql = "DELETE FROM PlayListFiles WHERE SessionID='" . $SessionID . "'";
		DBMethodUtils::RunSql ( $sql );
		
		//添加新的播放列表
		$InsertArr = array ();
		$i = 0;
		
		if (! empty ( $PlayFileList )) {
			foreach ( $PlayFileList as $item ) {
				if (empty ( $item ['FileID'] )) {
					continue;
				}
				$InsertArr [] = '("' . $item ['FileID'] . '", "' . ($i ++) . '", "' . $SessionID . '", 0)';
			}
			$sql = 'INSERT INTO PlayListFiles(FileID, SequenceID, SessionID, Duration)VALUES' . implode ( ',', $InsertArr );
			DBMethodUtils::RunSql ( $sql );
		}
	}
	
	/**
	 * 处理接收成员数据
	 * @param  $SessionID 任务ID
	 * @param  $SessionDevice 接收成员数组（JSON数组解析后的数据），格式:[{'DeviceID' : '21321333'}]
	 */
	public static function DealSessionDevice($SessionID, $SessionDevice) {
		
		if (is_null ( $SessionDevice )) {
			return;
		}
		//接收成员的ID
		$TempArr = array ();
		
		foreach ( $SessionDevice as $item ) {
			$TempArr [] = $item ['DeviceID'];
		}
		
		if (! empty ( $TempArr )) {
			//删除不用的数据
			$sql = "DELETE FROM SessionDevice WHERE SessionID='" . $SessionID . "' AND DeviceID NOT IN(" . implode ( ",", $TempArr ) . ")";
			DBMethodUtils::RunSql ( $sql );
		} else {
			$sql = "DELETE FROM SessionDevice WHERE SessionID='" . $SessionID . "'";
			DBMethodUtils::RunSql ( $sql );
			
			return;
		}
		$sql = 'INSERT IGNORE INTO SessionDevice(DeviceID, SessionID, KeyIndex, DevDisabled)VALUES';
		$Values = array ();
		
		foreach ( $SessionDevice as $item ) {
			//添加接收成员
			$Values [] = '("' . $item ['DeviceID'] . '", "' . $SessionID . '", "0", "0")';
		}
		
		if (! empty ( $Values )) {
			$sql .= implode ( ',', $Values );
			ToolUtil::writeLog("====>" . $sql);
			DBMethodUtils::RunSql ( $sql );
		}
	}
	
	/**
	 * 处理播出时间数据
	 * @param $SessionID 任务ID
	 * @param $PlayTime 播出时间数据（JSON数组解析后的数据），JSON数组格式：
	 * [
	 * {
	 * "ScheduleID":"执行时间ID（整数）",
	 * "WeekDay":"星期编号，0：星期一，6：星期天",
	 * "PlayTime":"播出时间，仅时分秒，如：12:10:00",
	 * "TempFlag":"是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录"
	 * }
	 * ]
	 */
	public static function DealPlayTime($SessionID, $PlayTime) {
		
		if (is_null ( $PlayTime ) || count ( $PlayTime ) <= 0) {
			return;
		}
		//使用的数据id
		$useIDs = array ();
		
		foreach ( $PlayTime as $item ) {
			if (! isset ( $item ['WeekDay'] ) || ! is_numeric ( $item ['WeekDay'] ) || $item ['WeekDay'] > 6 || $item ['WeekDay'] < 0 || ! ToolUtil::JudgeTimeFormat ( $item ['PlayTime'] )) {
				continue;
			}
			if (isset ( $item ['ScheduleID'] ) && ! is_null ( $item ['ScheduleID'] ) && "" != trim ( $item ['ScheduleID'] ) && is_numeric ( $item ['ScheduleID'] ) && $item ['ScheduleID'] > 0) {
				$useIDs [] = $item ['ScheduleID'];
			}
		}
		//删除无用的
		$sql = "DELETE FROM PlaySessionTime WHERE SessionID=:SessionID";
		
		if (! empty ( $useIDs )) {
			$sql .= " AND ScheduleID NOT IN(" . implode ( ',', $useIDs ) . ")";
		}
		DBMethodUtils::RunSql ( $sql, array (":SessionID" => $SessionID ) );
		
		foreach ( $PlayTime as $item ) {
			if (! isset ( $item ['WeekDay'] ) || ! is_numeric ( $item ['WeekDay'] ) || $item ['WeekDay'] > 6 || $item ['WeekDay'] < 0 || ! ToolUtil::JudgeTimeFormat ( $item ['PlayTime'] )) {
				continue;
			}
			if (isset ( $item ['ScheduleID'] ) && ! is_null ( $item ['ScheduleID'] ) && "" != trim ( $item ['ScheduleID'] ) && is_numeric ( $item ['ScheduleID'] ) && $item ['ScheduleID'] > 0) {
				//需要更新的数据
				$Sql = 'UPDATE PlaySessionTime SET SessionID = :SessionID ,WeekDay = :WeekDay ,
					PlayTime = :PlayTime,TempFlag = :TempFlag WHERE ScheduleID = :ScheduleID';
				DBMethodUtils::RunSql ( $Sql, array (":SessionID" => $SessionID, ":WeekDay" => $item ['WeekDay'], ":PlayTime" => ("2012-03-03 " . $item ['PlayTime']), ":TempFlag" => $item ['TempFlag'], ":ScheduleID" => $item ['ScheduleID'] ) );
			} else {
				//需要添加的数据
				$Sql = 'INSERT INTO PlaySessionTime (SessionID, WeekDay,PlayTime,TempFlag) values (:SessionID, :WeekDay,:PlayTime, :TempFlag) on duplicate key update TempFlag = values(TempFlag)';
				DBMethodUtils::RunSql ( $Sql, array (":SessionID" => $SessionID, ":WeekDay" => $item ['WeekDay'], ":PlayTime" => ("2012-03-03 " . $item ['PlayTime']), ":TempFlag" => $item ['TempFlag'] ) );
			}
		}
		DBMethodUtils::RunSql ( 'call sp_session_clean_up()' );
	}
	
	/**
	 * 任务控制
	 * @param $SessionID
	 * @param $ScheduleID
	 * @param $status
	 */
	public static function SessionCtrl($SessionID, $ScheduleID, $status) {
		
		if (is_null ( $ScheduleID )) {
			$ScheduleID = 'null';
		}
		
		if ($status == 1) { //播放
			$sql = "select sp_session_start(SessionID, :ScheduleID, 0, StreamType, BrdMode, MemberMode,SysEnabled,  RfDevCtrl) from  PlaySessions where  SessionID =:SessionID;";
			DBMethodUtils::RunSql ( $sql, array (":ScheduleID" => $ScheduleID, ":SessionID" => $SessionID ) );
		
		} else if ($status == 0 || $status == 2) { //停止，暂停
			$sql = "call nccs.sp_session_ctrl(:SessionID,:status, :ScheduleID);";
			DBMethodUtils::RunSql ( $sql, array (":ScheduleID" => $ScheduleID, ":SessionID" => $SessionID, ':status' => $status ) );
		}
	}
	
	/**
	 * 组装保存的子设备状态信息
	 * @param $OldRfDevCtrl 数据库存储的子设备状态，二进制数据
	 * @param  子设备状态数据（JSON数组解析后的数据），JSON数组格式：
	 * [
	 * {
	 * "PwrID":"扩展设备ID",
	 * "Mode":"模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式"
	 * }
	 * ]
	 * @param $SessionIDs 任务ID，格式：1，2，3
	 */
	public static function DealRfDevCtrl($OldRfDevCtrl, $RfDevCtrl, $SessionIDs) {
		
		//状态模式列表
		$RfDevModeArr = array ();
		
		if (! is_null ( $OldRfDevCtrl )) { //把状态拆分成16分
			$temp = bin2hex ( $OldRfDevCtrl );
			$pos = 0;
			
			for($i = 0; $i < strlen ( $temp ) - 1; $i = $i + 2) {
				$RfDevModeArr [$pos ++] = hexdec ( substr ( $temp, $i, 2 ) ) & 0x0F;
			}
		}
		
		foreach ( $RfDevCtrl as $item1 ) {
			if (! isset ( $item1 ["PwrID"] ) || ! is_numeric ( $item1 ["PwrID"] )) {
				continue;
			}
			$Mode = - 1;
			if (isset ( $item1 ["Run_Mode"] ) && is_numeric ( $item1 ["Run_Mode"] )) {
				$Mode = $item1 ["Run_Mode"];
			} else if (isset ( $item1 ["Mode"] ) && is_numeric ( $item1 ["Mode"] )) {
				$Mode = $item1 ["Mode"];
			}
			
			if ($Mode < 0) {
				continue;
			}
			$PwrID = $item1 ["PwrID"]; //扩展设备ID
			$Mode = $Mode <= 0 ? 0 : ($Mode >= 4 ? 4 : $Mode);
			$Mode = $Mode + 8; //模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式
			$Mode = str_pad ( dechex ( $Mode ), 2, "0", STR_PAD_LEFT ); //不足一个字节长度，自动前面补充0
			$RfDevModeArr [$PwrID] = $Mode;
		}
		$res = "";
		
		for($i = 0; $i < 16; $i ++) {
			if (isset ( $RfDevModeArr [$i] )) {
				$res .= str_pad ( $RfDevModeArr [$i], 2, '0', STR_PAD_LEFT );
			} else {
				$res .= str_pad ( '0', 2, '0', STR_PAD_LEFT );
			}
		}
		$sql = 'UPDATE PlaySessions SET RfDevCtrl=0x' . $res . ' WHERE SessionID IN (' . $SessionIDs . ')';
		
		return DBMethodUtils::RunSql ( $sql );
	}
	
	/**
	 * 组装保存的子设备状态信息
	 * @param $OldRfDevCtrl 数据库存储的子设备状态，二进制数据
	 * @param  子设备状态数据（JSON数组解析后的数据），JSON数组格式：
	 * [
	 * {
	 * "PwrID":"扩展设备ID",
	 * "Mode":"模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式"
	 * }
	 * ]
	 * @param $SessionIDs 任务ID，格式：1，2，3
	 */
	public static function LoadRfDevCtrl($RfDevCtrl) {
		
		if (empty ( $RfDevCtrl )) {
			return null;
		}
		
		//状态模式列表
		$RfDevModeArr = array ();
		
		for($i = 0; $i < 16; $i ++) {
			$RfDevModeArr [] = 0;
		}
		
		foreach ( $RfDevCtrl as $item ) {
			if (! isset ( $item ["PwrID"] ) || ! is_numeric ( $item ["PwrID"] )) {
				continue;
			}
			$Mode = - 1;
			
			if (isset ( $item ["Run_Mode"] ) && is_numeric ( $item ["Run_Mode"] )) {
				$Mode = $item ["Run_Mode"];
			} else if (isset ( $item ["Mode"] ) && is_numeric ( $item ["Mode"] )) {
				$Mode = $item ["Mode"];
			}
			
			if ($Mode < 0) {
				continue;
			}
			
			$PwrID = $item ["PwrID"]; //扩展设备ID
			$Mode = $Mode <= 0 ? 0 : ($Mode >= 4 ? 4 : $Mode);
			$Mode = $Mode + 8; //模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式
			$Mode = str_pad ( dechex ( $Mode ), 2, "0", STR_PAD_LEFT ); //不足一个字节长度，自动前面补充0
			$RfDevModeArr [$PwrID] = $Mode;
		}
		$res = "";
		
		for($i = 0; $i < 16; $i ++) {
			if (isset ( $RfDevModeArr [$i] )) {
				$res .= str_pad ( $RfDevModeArr [$i], 2, '0', STR_PAD_LEFT );
			} else {
				$res .= str_pad ( '0', 2, '0', STR_PAD_LEFT );
			}
		}
		
		return '0x' . $res;
	}
	
	/**
	 * 组装保存的子设备状态信息
	 * @param $OldRfDevCtrl 数据库存储的子设备状态，二进制数据
	 * @param  子设备状态数据（JSON数组解析后的数据），JSON数组格式：
	 * [
	 * {
	 * "PwrID":"扩展设备ID",
	 * "Mode":"模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式"
	 * }
	 * ]
	 * @param $SessionIDs 任务ID，格式：1，2，3
	 */
	public static function LoadRfDevCtrlNew($RfDevCtrl) {
		
		if (empty ( $RfDevCtrl )) {
			return null;
		}
		
		//状态模式列表
		$RfDevModeArr = array ();
		
		for($i = 0; $i < 16; $i ++) {
			$RfDevModeArr [] = 0;
		}
		
		foreach ( $RfDevCtrl as $item ) {
			if (! isset ( $item ["PwrID"] ) || ! is_numeric ( $item ["PwrID"] )) {
				continue;
			}
			$Mode = - 1;
			
			if (isset ( $item ["Run_Mode"] ) && is_numeric ( $item ["Run_Mode"] )) {
				$Mode = $item ["Run_Mode"];
			} else if (isset ( $item ["Mode"] ) && is_numeric ( $item ["Mode"] )) {
				$Mode = $item ["Mode"];
			}
			
			if ($Mode < 0) {
				continue;
			}
			
			$PwrID = $item ["PwrID"]; //扩展设备ID
			$Mode = $Mode <= 0 ? 0 : ($Mode >= 4 ? 4 : $Mode);
			$Mode = $Mode + 8; //模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式
			$Mode = dechex ( $Mode ); //不足一个字节长度，自动前面补充0
			$RfDevModeArr [$PwrID] = $Mode;
		}
		$res = "";
		
		for($i = 0; $i < 16; $i ++) {
			if (isset ( $RfDevModeArr [$i] )) {
				$res .= $RfDevModeArr [$i];
			} else {
				$res .= '0';
			}
		}
		return $res;
	}
	
	/**
	 * 通过任务ID删除任务
	 * @param $SessionIDs 格式：1，2，3
	 */
	public static function DeleteSessionByIDs($SessionIDs) {
		//删除播出时间
		$sql = "DELETE FROM PlaySessionTime WHERE SessionID IN(" . $SessionIDs . ")";
		DBMethodUtils::RunSql ( $sql );
		//删除播放列表
		$sql = "DELETE FROM PlayListFiles WHERE SessionID IN(" . $SessionIDs . ")";
		DBMethodUtils::RunSql ( $sql );
		//删除接收成员
		$sql = "DELETE FROM SessionDevice WHERE SessionID IN(" . $SessionIDs . ")";
		DBMethodUtils::RunSql ( $sql );
		//删除任务
		$sql = "DELETE FROM PlaySessions WHERE SessionID IN(" . $SessionIDs . ")";
		DBMethodUtils::RunSql ( $sql );
	
		//清除无效的任务
	//		DBMethodUtils::RunSql ( $sql );
	}
	
	/**
	 * 任务控制
	 * @param $UserID 用户id
	 * @param $DataParam 控制数据 [{"SessionID":"任务ID","ScheduleID":"播出时间ID,不传或为空表示没有时间限制"}]
	 * @param $status 状态 0 :停止, 1:播放，2：暂停
	 */
	public static function CtrSession($UserID, $DataParam, $status) {
		
		//		if (! is_null ( $UserID ) && $UserID > 0) { //非管理人员需要判断权限
		//			$SessionIDs = array ();
		//			$ScheduleIDs = array ();
		//			$NoWeekDaySessionIDs = "";
		//			
		//			//获取角色的任务数据
		//			foreach ( $DataParam as $item ) {
		//				if (! isset ( $item ["SessionID"] ) || ! is_numeric ( $item ["SessionID"] ) || $item ["SessionID"] <= 0) {
		//					//没有时间限制
		//				} else { //有时间限制
		//					$SessionIDs [] = $item ["SessionID"];
		//					
		//					if (is_numeric ( $item ["ScheduleID"] )) {
		//						$ScheduleIDs [] = $item ["ScheduleID"];
		//					}
		//				}
		//			}
		//			//有时间限制的任务
		//			if (! empty ( $SessionIDs )) {
		//				if (! empty ( $ScheduleIDs )) {
		//					$sql = "SELECT * FROM PlaySessionTime WHERE ScheduleID IN(" . implode ( $ScheduleIDs, "," ) . ") AND SessionID IN(" . implode ( $SessionIDs, "," ) . ")";
		//					$sql .= " AND SessionID IN(SELECT SessionID FROM PlaySessions WHERE Owner = '" . $UserID . "')";
		//					$PlaySessionTimes = DBMethodUtils::listData ( $sql );
		//					
		//					if (! is_null ( $PlaySessionTimes )) {
		//						foreach ( $PlaySessionTimes as $item ) {
		//							TaskUtil::SessionCtrl ( $item ['SessionID'], $item ['ScheduleID'], $status );
		//						}
		//					}
		//				} else {
		//					//没有时间限制的任务
		//					$sql = "SELECT * FROM PlaySessions WHERE Owner = '" . $UserID . "' AND SessionID IN(" . implode ( $SessionIDs, "," ) . ")";
		//					$PlaySessions = DBMethodUtils::listData ( $sql );
		//					
		//					if (! is_null ( $PlaySessions )) {
		//						foreach ( $PlaySessions as $item ) {
		//							TaskUtil::SessionCtrl ( $item ['SessionID'], null, $status );
		//						}
		//					}
		//				}
		//			}
		//		} else {
		foreach ( $DataParam as $item ) {
			if (isset ( $item ['ScheduleID'] ) && is_numeric ( $item ['ScheduleID'] )) { //有播出周限制
				TaskUtil::SessionCtrl ( $item ['SessionID'], $item ['ScheduleID'], $status );
			} else if (is_numeric ( $item ['SessionID'] )) { //没有限制
				TaskUtil::SessionCtrl ( $item ['SessionID'], null, $status );
			}
		}
	
		//		}
	}
	
	/**
	 * 加载设备
	 * @param unknown_type $UserID
	 * @param unknown_type $SessionID
	 * @param unknown_type $Parent
	 */
	public static function LoadDevices($UserID, $SessionID, $Parent) {
		
		$sql = 'SELECT a.DevID AS id, a.Dev_Name AS text, a.Parent AS Parent, 1 AS IsDevice, "closed" AS state, 
					IF(ISNULL(b.SessionID), 0, 1) AS checked 
				FROM DeviceList a 
				LEFT JOIN (SELECT * FROM SessionDevice WHERE SessionID=' . $SessionID . ') AS b ON a.DevID = b.DeviceID ';
		
		if (empty ( $Parent )) {
			$sql .= ' WHERE ISNULL(a.Parent)';
		} else {
			$sql .= ' WHERE a.Parent = ' . $Parent;
		}
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DevID", $UserID );
		}
		$sql .= ' ORDER by a.DevID';
		
		return DBMethodUtils::listData ( $sql );
	}
	
	/**
	 * 加载分区
	 * @param unknown_type $UserID
	 * @param unknown_type $SessionID
	 * @param unknown_type $Parent
	 */
	public static function LoadDevClass($UserID, $SessionID, $Parent) {
		
		$sql = 'SELECT ClassID AS id,Name as text, Parent AS Parent, 0 AS IsDevice, "closed" AS state, 0 AS checked FROM DevClasses';
		
		if (empty ( $Parent )) {
			$sql .= ' WHERE ISNULL(Parent)';
		} else {
			$sql .= ' WHERE Parent = ' . $Parent;
		}
		$Out = DBMethodUtils::listData ( $sql );
		
		if (! empty ( $Out )) {
			foreach ( $Out as $key => $item ) {
				//加载子节点分类成员
				$Children = TaskUtil::LoadDevClass ( $UserID, $SessionID, $item ['id'] );
				//加载子节点设备
				$Devs = TaskUtil::LoadDevices ( $UserID, $SessionID, $item ['id'] );
				
				if (! empty ( $Devs )) {
					if (empty ( $Children )) {
						$Children = $Devs;
					} else {
						$Children = array_merge ( $Children, $Devs );
					}
				}
				$Out [$key] ['children'] = $Children;
			}
		}
		
		return $Out;
	}
	
	/**
	 * 加载接收成员
	 * @param $SessionID
	 * @param $UserID
	 */
	public static function LoadSessionDevice($SessionID, $UserID) {
		
		//		$sql = 'SELECT ClassID AS id,Name as name, IF(ISNULL(Parent), 0, Parent) AS pId, 0 AS IsDevice, false AS open
		//				FROM DevClasses ORDER BY Parent ASC, ClassID ASC';
		//		$Out = DBMethodUtils::listData ( $sql );
		//		
		//		$sql = 'SELECT a.DevID AS id, a.Dev_Name AS name, IF(ISNULL(a.Parent), 0, a.Parent) AS pId, 1 AS IsDevice, false AS open, 
		//					IF(ISNULL(b.SessionID), 0, 1) AS checked 
		//				FROM DeviceList a 
		//				LEFT JOIN (SELECT * FROM SessionDevice WHERE SessionID=' . $SessionID . ') AS b ON a.DevID = b.DeviceID ';
		//		
		//		if (! is_null ( $UserID ) && $UserID > 0) {
		//			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DevID", $UserID );
		//		}
		//		$sql .= ' ORDER by a.DevID';
		//		$Devs = DBMethodUtils::listData($sql);
		//		
		//		$Out = empty($Out) ? array() : $Out;
		//		
		//		if (!empty($Devs)) {
		//			$Out = array_merge($Out, $Devs);
		//		}
		//		$temp = array();
		//		
		//		foreach ($Out as $item) {
		//			if (isset($item['checked'])) {
		//				$item['checked'] = $item['checked'] == 1 ? true : false;
		//			}
		//			$item['halfCheck'] = true;
		//			$temp[] = $item;
		//		}
		//		
		//		return $temp;
		

		$DeviceClassArr = TaskUtil::LoadDevClass ( $UserID, $SessionID, null );
		
		$Devs = TaskUtil::LoadDevices ( $UserID, $SessionID, null );
		$DeviceClassArr = empty ( $DeviceClassArr ) ? array () : $DeviceClassArr;
		
		if (! empty ( $Devs )) {
			$DeviceClassArr = array_merge ( $DeviceClassArr, $Devs );
		}
		$selectAll = 0;
		
		return TaskUtil::dealDeviceTree ( $DeviceClassArr, $selectAll );
	}
	
	/**
	 * 处理设备树形结构
	 * @param $TreeData
	 * @param $selectAll 0 : 不选中，1：选中，2：半选
	 */
	public static function dealDeviceTree($TreeData, &$selectAll) {
		
		if (empty ( $TreeData )) {
			return $TreeData;
		}
		$out = array ();
		$SelectNum = 0;
		$HasHalf = false;
		
		foreach ( $TreeData as $key => $item ) {
			$item ['id'] = str_replace ( 'DC_', "", $item ['id'] );
			$item ['Parent'] = str_replace ( 'DC_', "", $item ['Parent'] );
			$item ['name'] = $item ['text'];
			$item ['checked'] = intval ( $item ['checked'] );
			$item ['open'] = false;
			
			if ($item ['Parent'] == "") {
				$item ['Parent'] = null;
			}
			if ($item ['IsDevice'] != 0) { //是设备
				$out [] = $item;
				
				if ($item ['checked'] == 1) {
					$SelectNum ++;
				} else {
					$HasHalf = true;
				}
				continue;
			}
			
			//是分类
			if (empty ( $item ['children'] )) {
			} else {
				$TempAll = 1;
				$children = TaskUtil::dealDeviceTree ( $item ['children'], $TempAll );
				
				if (! empty ( $children )) {
					$item ['checked'] = $TempAll == 1 || $TempAll == 2 ? 1 : 0;
					$item ['halfCheck'] = $TempAll == 2 ? 1 : 0;
					$item ['children'] = $children;
					$out [] = $item;
				}
				
				if ($TempAll == 1) {
					$SelectNum ++;
				} else if ($TempAll == 2) {
					$HasHalf = true;
				}
			}
		}
		$selectAll = $SelectNum <= 0 ? 0 : ($HasHalf ? 2 : 1);
		
		return $out;
	}
	
	/**
	 * 编辑任务
	 * @param unknown_type $ForApp
	 */
	public static function EditSessions($UserID, $ForApp = false) {
		
		/*
		 {
		 "BaseInfo":{
		 "SessionID":"任务ID,如果是新建则为空字符串，任务批量格式为：1,2,3",
		 "SessionName":"任务名字",
		 "SessionType":"0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务",
		 "Priority":"优先级（整数）",
		 "SteamTypeUp":"强制接收，1：强制，0：不强制",
		 "SteamTypeDown":"0控制任务，1音频，2视屏，3音视频，一般用3来表示视频"
		 },
		 "Mode":{
		 "BrdMode":"是否广播模式任务，>0广播模式ID 是模式任务，null表示非模式任务",
		 "MemmberMode":"默认为0,是否使用模式成员，1使用模式成员，0不使用"
		 },
		 "Brodcast":{
		 "AudioGain":"音频增益，单个任务的音量调节。",
		 "CircleLength":"默认为0，播放时长；秒",
		 "PlayMode":"播放模式,媒体播放方式，0顺序播放，1随机播放，默认是0，广播任务才用",
		 "PlayFileList":[
		 {
		 "FileID":"文件ID（整数）"
		 },
		 {
		 "FileID":"文件ID（整数）"
		 }
		 ]
		 },
		 "DeviceCtrl":{
		 "SysEnabled":"设备控制，系统启禁用状态，1启用，0禁用，仅控制任务才使用这个字段，null为没有控制",
		 "RfDevCtrl":[
		 {
		 "PwrID":"扩展设备ID",
		 "Mode":"模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式"
		 }
		 ]
		 },
		 "SessionDevice":[
		 {
		 "DeviceID":"设备id（字符串）"
		 },
		 {
		 "DeviceID":"设备id（字符串）"
		 }
		 ],
		 "PlayTime":[
		 {
		 "ScheduleID":"执行时间ID（整数）",
		 "WeekDay":"星期编号，0：星期一，6：星期天",
		 "PlayTime":"播出时间，仅时分秒，如：12:10:00",
		 "TempFlag":"是否临时任务，1临时任务，0非临时任务，2暂停，临时任务按照指定的时间执行一次完就删除这条记录"
		 }
		 ]
		 }
		 */
		$param = null;
		
		if (isset ( $_POST ['DataParam'] )) {
			$param = CJSON::decode ( $_POST ['DataParam'] );
		}
		
		if (is_null ( $param )) {
			return DataUtil::PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
		}
		
		//基本信息
		if (! isset ( $param ['BaseInfo'] ) || ! isset ( $param ['BaseInfo'] ['SessionID'] )) {
			//基本信息不存在，不能继续操作
			return DataUtil::PackResponseData ( ErrcodeUtil::$SESSION_BASEINFO_ERR, '请输入正确的任务信息！', null );
		}
		$BaseInfo = $param ['BaseInfo'];
		//任务ID
		$SessionID = $BaseInfo ['SessionID'];
		//查找任务
		$SessionModel = PlaySessions::model ()->findByPk ( $SessionID );
		
		$tempsessiontype = - 1;
		
		if (! is_null ( $SessionModel )) {
			$tempsessiontype = $SessionModel->SessionType;
		}
		
		if (! isset ( $BaseInfo ['SessionType'] )) {
			$tempsessiontype = $BaseInfo ['SessionType'];
		}
		//是否是控制任务
		$isCtrlSession = false;
		
		if (isset ( $BaseInfo ['SteamTypeDown'] ) && $BaseInfo ['SteamTypeDown'] == 0) { //控制任务
			$isCtrlSession = true;
		}
		$TempUserId = $UserID;
		if (is_null ( $UserID )) {
			$TempUserId = 0;
		}
		$User = Users::model ()->findByPk ( $TempUserId );
		
		$privilege = 0;
		
		if (isset ( $User ['privilege'] )) {
			$privilege = $User ['privilege'];
		}
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			switch ($tempsessiontype) {
				case 0 : //自动广播或控制任务；
					if ($isCtrlSession && ! PermissionManager::JudgeBroadcastPrivaliege ( $privilege ) && ! PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege )) {
						return DataUtil::PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有中控设备管理权限', null );
					}
					if (! $isCtrlSession && ! PermissionManager::JudgeBroadcastPrivaliege ( $privilege )) {
						return DataUtil::PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有音视广播权限理权限', null );
					}
					break;
				case 1 : //由PC呼叫台或者音频广播站创建的任务；
					//TODO
					break;
				case 2 : //2：手动广播任务
					if (! $isCtrlSession && ! PermissionManager::JudgeBroadcastPrivaliege ( $privilege )) {
						return DataUtil::PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有音视广播权限理权限', null );
					}
					break;
				default :
					break;
			}
		}
		
		if (! is_null ( $SessionModel )) {
			//强制接收标识(StreamType高4为来判断，最高位：1：强制，0：不强制)
			$SteamTypeUp = round ( $SessionModel->StreamType / 128 );
			//00控制任务，01音频，10视屏，11音视频，一般用11来表示视频。(StreamType低4为来判断)
			$SteamTypeDown = $SessionModel->StreamType - round ( $SessionModel->StreamType / 128 ) * 128;
			
			if ($SteamTypeDown == 0) { //控制任务
				$isCtrlSession = true;
			}
			
			//任务存在，是修改任务
			$UpdateAttr = array ();
			
			//基本信息的修改
			if (isset ( $BaseInfo ['SessionName'] )) { //修改任务名字
				$UpdateAttr [] = 'SessionName="' . $BaseInfo ['SessionName'] . '"';
			}
			//			if (isset ( $BaseInfo ['SessionType'] )) { //修改任务类型，0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
			//			//				$UpdateAttr ["SessionType"] = $BaseInfo ['SessionType'];
			//			}
			if (isset ( $BaseInfo ['Priority'] ) && is_numeric ( $BaseInfo ['Priority'] )) { //修改优先级（整数）
				$UpdateAttr [] = 'Priority="' . $BaseInfo ['Priority'] . '"';
			}
			if (isset ( $BaseInfo ['SteamTypeUp'] ) && is_numeric ( $BaseInfo ['SteamTypeUp'] )) { //1：强制，0：不强制
				$SteamTypeUp = $BaseInfo ['SteamTypeUp'];
				$SteamTypeUp = $SteamTypeUp == 1 ? 1 : 0;
			}
			
			if (isset ( $BaseInfo ['SteamTypeDown'] ) && is_numeric ( $BaseInfo ['SteamTypeDown'] )) { //0：控制，1：音频，2：视频（暂时不用），3：视频（视频用3）
				if ($SteamTypeDown == 0) {
					$SteamTypeUp = 0;
				} else {
					$SteamTypeDown = in_array ( $BaseInfo ['SteamTypeDown'], array (2, 3 ) ) ? 3 : 1;
				}
			}
			
			if (in_array ( $SessionModel->SessionType, array (0, 8 ) )) { //自动任务
				if (in_array ( $SteamTypeDown, array (2, 3 ) )) { //视频任务
					$UpdateAttr [] = 'SessionType = 8';
				} else {
					$UpdateAttr [] = 'SessionType = 0';
				}
			} else if (in_array ( $SessionModel->SessionType, array (2, 9 ) )) { //手动任务
				if (in_array ( $SteamTypeDown, array (2, 3 ) )) { //视频任务
					$UpdateAttr [] = 'SessionType = 9';
				} else {
					$UpdateAttr [] = 'SessionType = 2';
				}
			}
			
			$UpdateAttr [] = 'StreamType="' . ($SteamTypeUp * 128 + $SteamTypeDown) . '"';
			
			if (isset ( $param ['Mode'] ) && ! is_null ( $param ['Mode'] )) {
				//模式任务信息
				$Mode = $param ['Mode'];
				
				if (isset ( $Mode ['BrdMode'] )) { //是否广播模式任务，>0广播模式ID 是模式任务，null表示非模式任务
					$UpdateAttr [] = 'BrdMode="' . $Mode ['BrdMode'] . '"';
				}
				if (isset ( $Mode ['MemmberMode'] )) { //默认为0,是否使用模式成员，1使用模式成员，0不使用
					$UpdateAttr [] = 'MemmberMode="' . $Mode ['MemmberMode'] . '"';
				}
			}
			if (isset ( $param ['Brodcast'] ) && ! is_null ( $param ['Brodcast'] )) {
				//广播任务
				$Brodcast = $param ['Brodcast'];
				
				if (isset ( $Brodcast ['AudioGain'] )) { //音频增益，单个任务的音量调节。
					$AudioGain = $Brodcast ['AudioGain'];
					
					if ($AudioGain != - 100) {
						$AudioGain = $AudioGain <= - 20 ? - 20 : $AudioGain;
						$AudioGain = $AudioGain >= 20 ? 20 : $AudioGain;
					}
					$UpdateAttr [] = 'AudioGain="' . $AudioGain . '"';
				}
				if (isset ( $Brodcast ['CircleLength'] )) { //默认为0，播放时长；秒
					$UpdateAttr [] = 'CircleLength="' . $Brodcast ['CircleLength'] . '"';
				}
				if (isset ( $Brodcast ['PlayMode'] )) { //播放模式,媒体播放方式，0顺序播放，1随机播放，默认是0，广播任务才用
					$UpdateAttr [] = 'PlayMode="' . $Brodcast ['PlayMode'] . '"';
				}
			}
			if (isset ( $param ['DeviceCtrl'] ) && ! is_null ( $param ['DeviceCtrl'] )) {
				//控制任务		
				$DeviceCtrl = $param ['DeviceCtrl'];
				
				if (PermissionManager::JudgeDevCtrPrivaliege ( $privilege )) { //有中控权限
					$SysEnabled = null;
					
					if (isset ( $DeviceCtrl ['SysEnabledNew'] ) && in_array ( $DeviceCtrl ['SysEnabledNew'], array (0, 1, 2 ) )) { //设备控制，新的（版本5及以上），0：关机，1：开机，2：禁用
						$SysEnabled = $DeviceCtrl ['SysEnabledNew'];
					} else if (isset ( $DeviceCtrl ['SysEnabled'] ) && in_array ( $DeviceCtrl ['SysEnabled'], array (0, 1 ) )) { //版本5以下，0：禁用，1：启用
						$SysEnabled = $DeviceCtrl ['SysEnabled'];
					}
					if (! is_null ( $SysEnabled )) { //设备控制
						$UpdateAttr [] = 'SysEnabled="' . $SysEnabled . '"';
					} else {
						$UpdateAttr [] = 'SysEnabled=NULL';
					}
				} else {
					$UpdateAttr [] = 'SysEnabled=NULL';
				}
				
				if (PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege )) { //有物联设备权限
					if (! empty ( $DeviceCtrl ['RfDevCtrl'] )) { //子设备状态
						$UpdateAttr [] = 'RfDevCtrl=' . TaskUtil::LoadRfDevCtrl ( $DeviceCtrl ['RfDevCtrl'] ) . '';
					} else {
						$UpdateAttr [] = 'RfDevCtrl=NULL';
					}
				} else {
					$UpdateAttr [] = 'RfDevCtrl=NULL';
				}
			}
			if (! empty ( $UpdateAttr )) {
				$sql = 'UPDATE PlaySessions SET ' . implode ( ',', $UpdateAttr ) . ' WHERE SessionID IN(' . $SessionID . ')';
				ToolUtil::writeLog ( $sql );
				DBMethodUtils::RunSql ( $sql );
			}
		} else {
			//新建任务
			if (! isset ( $BaseInfo ['SessionType'] )) {
				return DataUtil::PackResponseData ( ErrcodeUtil::$SESSION_NEED_SESSIONTYPE, '请确定任务类型！', null );
			}
			$SessionType = $BaseInfo ['SessionType'];
			
			if ($SessionType == 1) {
				//实时采播，不能新建
				return DataUtil::PackResponseData ( ErrcodeUtil::$SESSION_SESSIONTYPE_ERR, '实时采播任务不能够手动添加', null );
				return;
			}
			//定时任务、模式任务必须要有执行时间；手动广播不需要执行时间
			if ($SessionType != 2 && $SessionType != 9) {
				//非手动任务必须要有执行时间
				if (! isset ( $param ['PlayTime'] ) || is_null ( $param ['PlayTime'] ) || count ( $param ['PlayTime'] ) <= 0) {
					return DataUtil::PackResponseData ( ErrcodeUtil::$SESSION_NEED_PLAYTIME, '请设置播出时间', null );
				}
			}
			//状态，暂时没用
			$Status = 0;
			//成员模式
			$MemberMode = 0;
			//模板id
			$Template = null;
			
			//获取任务id
			$sql = "SELECT get_idle_sessionid(true) AS id";
			$idRes = DBMethodUtils::findData ( $sql );
			
			if (is_null ( $idRes ) || ! isset ( $idRes ['id'] )) {
				return DataUtil::PackResponseData ( ErrcodeUtil::$FAILED, '新建任务失败', null );
				return;
			}
			
			$SessionID = $idRes ['id'];
			
			if ($SessionType == 0 || $SessionType == 8) { //自动广播任务（0）和自定视频任务（8）需要使用任务模板
				//获取当前使用的模板id
				$TemplateInfo = null;
				try {
					$sql = "SELECT * FROM  TaskTemplate WHERE idTaskTemplate=(SELECT InfoValue FROM BaseInfo WHERE InfomationID=257)";
					$TemplateInfo = DBMethodUtils::findData ( $sql );
				} catch ( Exception $e ) {
				
				}
				if (! is_null ( $TemplateInfo ) && isset ( $TemplateInfo ['idTaskTemplate'] )) {
					$Template = $TemplateInfo ['idTaskTemplate'];
				} else {
					//没有模板，定时任务不能创建
					return DataUtil::PackResponseData ( ErrcodeUtil::$SESSION_NO_TEMPLATE, '请设置当前模板后再新建任务', null );
				}
			}
			$SessionModel = new PlaySessions ();
			$SessionModel->SessionID = $SessionID;
			$SessionModel->SessionName = ""; //任务名字
			$SessionModel->SessionType = $SessionType; //修改任务类型，0: 自动广播或控制任务；1：由PC呼叫台或者音频广播站创建的任务；2：手动广播任务
			$SessionModel->Priority = 0; //优先级（整数）
			$SessionModel->Status = $Status;
			$SessionModel->CircleLength = 0;
			$SessionModel->BrdMode = null;
			$SessionModel->MemberMode = 0;
			$SessionModel->StreamType = - 1;
			$SessionModel->SysEnabled = null;
			$SessionModel->RfDevCtrl = null;
			if (! is_null ( $UserID ) && $UserID > 0) {
				$SessionModel->Owner = $UserID;
			}
			$SessionModel->PlayMode = 0;
			$SessionModel->AudioGain = 0;
			$SessionModel->Template = $Template;
			
			if (isset ( $BaseInfo ['SessionName'] )) { //任务名字
				$SessionModel->SessionName = $BaseInfo ['SessionName'];
			}
			if (isset ( $BaseInfo ['Priority'] ) && is_numeric ( $BaseInfo ['Priority'] )) { //优先级（整数）
				$SessionModel->Priority = $BaseInfo ['Priority'];
				
				if ($SessionModel->Priority > 100) {
					$SessionModel->Priority = 100;
				} else if ($SessionModel->Priority < 0) {
					$SessionModel->Priority = 0;
				}
			}
			
			$up = 0;
			$down = 0;
			
			if (isset ( $BaseInfo ['SteamTypeUp'] ) && is_numeric ( $BaseInfo ['SteamTypeUp'] )) {
				//强制接收，1：强制，0：不强制
				//0控制任务，1音频，2视屏，3音视频，一般用3来表示视频
				$up = $BaseInfo ['SteamTypeUp'];
				$up = $up <= 0 ? 0 : 1;
			}
			if (isset ( $BaseInfo ['SteamTypeDown'] ) && is_numeric ( $BaseInfo ['SteamTypeDown'] )) { //0控制任务，1音频，2视屏，3音视频，一般用3来表示视频
				$down = $BaseInfo ['SteamTypeDown'];
				$sql .= " Priority=FLOOR((StreamType / 128)) * 128 + " . $BaseInfo ['SteamTypeDown'];
				
				if (in_array ( $SessionModel->SessionType, array (0, 8 ) )) {
					if (in_array ( $BaseInfo ['SteamTypeDown'], array (2, 3 ) )) {
						$SessionModel->SessionType = 8;
					} else {
						$SessionModel->SessionType = 0;
					}
				} else if (in_array ( $SessionModel->SessionType, array (2, 9 ) )) {
					if (in_array ( $BaseInfo ['SteamTypeDown'], array (2, 3 ) )) {
						$SessionModel->SessionType = 9;
					} else {
						$SessionModel->SessionType = 2;
					}
				}
			}
			$SessionModel->StreamType = $up * 128 + $down;
			
			if (isset ( $param ['Mode'] ) && ! is_null ( $param ['Mode'] )) {
				//模式任务信息
				$Mode = $param ['Mode'];
				
				if (isset ( $Mode ['BrdMode'] )) { //是否广播模式任务，>0广播模式ID 是模式任务，null表示非模式任务
					$SessionModel->BrdMode = $Mode ['BrdMode'];
				}
				if (isset ( $Mode ['MemmberMode'] )) { //默认为0,是否使用模式成员，1使用模式成员，0不使用
					$SessionModel->MemberMode = $Mode ['MemmberMode'];
				}
			}
			$SessionModel->AudioGain = 0;
			$SessionModel->CircleLength = 0;
			$SessionModel->PlayMode = 0;
			$SessionModel->SysEnabled = null;
			$RfDevCtrl = null;
			
			if (! $isCtrlSession) { //不是控制任务
				if (isset ( $param ['Brodcast'] ) && ! is_null ( $param ['Brodcast'] )) {
					//广播任务
					$Brodcast = $param ['Brodcast'];
					
					if (isset ( $Brodcast ['AudioGain'] )) { //音频增益，单个任务的音量调节。
						$SessionModel->AudioGain = $Brodcast ['AudioGain'];
						
						if ($SessionModel->AudioGain != - 100) {
							if ($SessionModel->AudioGain < - 20) {
								$SessionModel->AudioGain = - 20;
							} else if ($SessionModel->AudioGain > 20) {
								$SessionModel->AudioGain = 20;
							}
						}
					}
					if (isset ( $Brodcast ['CircleLength'] )) { //默认为0，播放时长；秒
						$SessionModel->CircleLength = $Brodcast ['CircleLength'];
					}
					if (isset ( $Brodcast ['PlayMode'] )) { //播放模式,媒体播放方式，0顺序播放，1随机播放，默认是0，广播任务才用
						$SessionModel->PlayMode = $Brodcast ['PlayMode'];
					}
				}
			} else {
				if (isset ( $param ['DeviceCtrl'] ) && ! is_null ( $param ['DeviceCtrl'] )) {
					//控制任务
					$DeviceCtrl = $param ['DeviceCtrl'];
					
					if (PermissionManager::JudgeDevCtrPrivaliege ( $privilege )) { //有中控权限
						$SysEnabled = null;
						
						if (isset ( $DeviceCtrl ['SysEnabledNew'] ) && in_array ( $DeviceCtrl ['SysEnabledNew'], array (0, 1, 2 ) )) { //设备控制，新的（版本5及以上），0：关机，1：开机，2：禁用
							$SysEnabled = $DeviceCtrl ['SysEnabledNew'];
						} else if (isset ( $DeviceCtrl ['SysEnabled'] ) && in_array ( $DeviceCtrl ['SysEnabled'], array (0, 1 ) )) { //版本5以下，0：禁用，1：启用
							$SysEnabled = $DeviceCtrl ['SysEnabled'];
						}
						
						if (! is_null ( $SysEnabled )) { //设备控制
							$SessionModel->SysEnabled = $SysEnabled;
						}
					}
					
					if (PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege )) { //有物联权限
						if (isset ( $DeviceCtrl ['RfDevCtrl'] ) && ! is_null ( $DeviceCtrl ['RfDevCtrl'] )) { //子设备状态
							$RfDevCtrl = $DeviceCtrl ['RfDevCtrl'];
						}
					}
				}
			}
			if (! $SessionModel->save ()) {
				return DataUtil::PackResponseData ( ErrcodeUtil::$FAILED, '新建任务失败', null );
			} else {
				if (! is_null ( $RfDevCtrl )) {
					TaskUtil::DealRfDevCtrl ( $SessionModel->RfDevCtrl, $DeviceCtrl ['RfDevCtrl'], $SessionModel->SessionID );
				}
			}
		}
		/*******************************************************************************/
		if (! $isCtrlSession) { //不是控制任务
			if (isset ( $param ['Brodcast'] ) && ! is_null ( $param ['Brodcast'] )) {
				//广播任务,处理播放列表
				if (isset ( $param ['Brodcast'] ['PlayFileList'] )) { //有播放列表
					$PlayFileList = $param ['Brodcast'] ['PlayFileList'];
					TaskUtil::DealBroadcastPlayFileList ( $SessionID, $PlayFileList );
				}
			}
		}
		if (isset ( $param ['SessionDevice'] ) && ! is_null ( $param ['SessionDevice'] )) {
			//接收成员
			$SessionDevice = $param ['SessionDevice'];
			TaskUtil::DealSessionDevice ( $SessionID, $SessionDevice );
		}
		
		if ($ForApp) {
			if (isset ( $param ['PlayTime'] ) && ! is_null ( $param ['PlayTime'] ) && count ( $param ['PlayTime'] ) > 0) {
				//播出时间
				$PlayTime = $param ['PlayTime'];
				
				foreach ( $PlayTime as $item ) {
					if (! isset ( $item ['WeekDay'] ) || ! is_numeric ( $item ['WeekDay'] ) || $item ['WeekDay'] > 6 || $item ['WeekDay'] < 0 || ! ToolUtil::JudgeTimeFormat ( $item ['PlayTime'] )) {
						continue;
					}
					
					if (! empty ( $item ['ScheduleID'] ) && $item ['ScheduleID'] > 0) {
						$sql = "UPDATE PlaySessionTime SET WeekDay='" . $item ['WeekDay'] . "', PlayTime='" . "2012-03-03 " . $item ['PlayTime'] . "', TempFlag='" . $item ['TempFlag'] . "' WHERE SessionID='" . $SessionID . "' AND ScheduleID='" . $item ['ScheduleID'] . "'";
						DBMethodUtils::RunSql ( $sql );
						
						//0 :停止, 1:播放，2：暂停
						$Pasue = 0;
						
						if (isset ( $item ['Pause'] ) && is_numeric ( $item ['Pause'] )) {
							if ($item ['Pause'] == 0) { //播放
								$Pasue = 1;
							} else if ($item ['Pause'] == 1) { //暂停
								$Pasue = 2;
							}
						
						}
						TaskUtil::SessionCtrl ( $SessionID, $item ['ScheduleID'], $Pasue );
					} else {
						//添加执行时间
						$PlaySessionTimeModel = new PlaySessionTime ();
						$PlaySessionTimeModel->SessionID = $SessionID;
						$PlaySessionTimeModel->WeekDay = $item ['WeekDay'];
						$PlaySessionTimeModel->PlayTime = "2012-03-03 " . $item ['PlayTime'];
						$PlaySessionTimeModel->TempFlag = $item ['TempFlag'];
						
						$sql = 'INSERT INTO PlaySessionTime (SessionID, WeekDay, PlayTime, TempFlag)VALUES("' . $SessionID . '", "' . $item ['WeekDay'] . '", "' . ("2012-03-03 " . $item ['PlayTime']) . '", "' . $item ['TempFlag'] . '")';
						DBMethodUtils::RunSql ( $sql );
					}
				}
			}
		} else {
			if (isset ( $param ['PlayTime'] ) && ! is_null ( $param ['PlayTime'] )) {
				//播出时间
				$PlayTime = $param ['PlayTime'];
				TaskUtil::DealPlayTime ( $SessionID, $PlayTime );
			}
		}
		DBMethodUtils::RunSql ( 'call sp_session_clean_up()' );
		
		return DataUtil::PackResponseData ( ErrcodeUtil::$SUCCESS, '新建任务成功', null );
	}

}