SET character_set_client = utf8;

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

CREATE SCHEMA IF NOT EXISTS `nccs` DEFAULT CHARACTER SET utf8 ;
USE `nccs` ;
USE `nccs` ;

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_DeviceModes`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_DeviceModes` (`DeviceID` INT, `BrdModeID` INT, `Priority` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_Session_Files`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_Session_Files` (`SessionID` INT, `FileID` INT, `SequenceID` INT, `FileName` INT, `TotalTime` INT, `PlayTime` INT, `Gain` INT, `FileFmt` INT, `FilePath` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_active_mode_members`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_active_mode_members` (`DeviceID` INT, `BrdModeID` INT, `Priority` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_session_info`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_session_info` (`SessionID` INT, `SessionName` INT, `SessionType` INT, `Priority` INT, `Status` INT, `CircleLength` INT, `ClassID` INT, `PlayerID` INT, `Parent` INT, `PlayingFileID` INT, `MultiPort` INT, `CurrFileProgress` INT, `CurrTotalProgress` INT, `Pause` INT, `ScheduleID` INT, `MemberMode` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_session_schedules`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_session_schedules` (`ScheduleID` INT, `TempFlag` INT, `PlayTime` INT, `WeekDay` INT, `SessionID` INT, `SessionName` INT, `Pause` INT, `BrdMode` INT, `SessionType` INT, `SysEnabled` INT, `RfDevCtrl` INT, `StreamType` INT);

-- -----------------------------------------------------
-- Placeholder table for view `nccs`.`v_stream_trans_table`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`v_stream_trans_table` (`NetworkID` INT, `proxy` INT, `IpAddress` INT, `MultiPort` INT, `SessionID` INT);

-- -----------------------------------------------------
-- procedure delete_task
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`delete_task`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `delete_task`(taskid int)
begin
declare ses_id smallint default null;
select  SessionID into ses_id from PlaySessionTime where ScheduleID = taskid;

if (ses_id is not null) then
    call sp_session_ctrl(ses_id, 0, taskid);
end if;

Delete from PlaySessionTime where ScheduleID = taskid;

end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_dev_stream
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_dev_stream`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_dev_stream`( 
                                    dev_id varchar(50),
                                    stream_type int) RETURNS tinyint(1)
begin

if (ASCII(dev_id) = 0x30) then
     return false;
end if;    

if ((stream_type & 0x02)  <> 0) then
    if (ASCII(right(dev_id, 9)) <> 0x38) then
         return false;
     end if;    
end if;

return true;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_mode_daytime
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_mode_daytime`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_mode_daytime`( 
          weekday tinyint, 
          checked_time datetime,
          last_time datetime,
          cur_time datetime
         ) RETURNS tinyint(1)
begin
declare cur_weekday tinyint default null;
declare checked_date date;

-- check whether time is matched
if (last_time >= cur_time) then
    return false;
end if;    

-- time is matched, check date
if  (weekday = 0) then
-- compare special day
    if (checked_time  > last_time) and (checked_time <= cur_time) then 
        return true;
    end if;    
else
    -- for repeated weekly
     if (time(last_time) > time(cur_time)) then
         -- current date change to next day
         if (time(checked_time) > time(last_time) ) then
              set checked_date = date(last_time);
         else 
              if (time(checked_time) <= time(cur_time)) then
                    set checked_date = date(cur_time);
              else
                    return false;
               end if ;    
          end if;
      else
          -- current date is same as last date
          if (time(checked_time) <= time(last_time) )  or 
              (time(checked_time) > time(cur_time))  then
              -- time is not mached
              return false;
           end if;   
           
           set checked_date = date(cur_time);
      end if;
      
       -- Get alternated week          
      select AlteredScheduleDay into cur_weekday from AlternateDate where SpecialDate = checked_date;

      if cur_weekday is null then 
           set cur_weekday = weekday(checked_date);
       end if;
     
    if (weekday & (0x01 << cur_weekday)  <> 0 ) then 
        -- date is matched
        return true;
   end if;    
end if;

return false;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_mode_enabled
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_mode_enabled`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_mode_enabled`( modeid int , 
      PlayTime time,
      PlayDate date) RETURNS tinyint(1)
begin
declare cur_weekday tinyint default null;
declare checked_date date;
declare modeactive boolean default false;
declare modeenable boolean default false;
declare modestarttime datetime  default null;
declare modestoptime datetime  default null;
declare modetimestype tinyint default null;
declare matched boolean default false;

select Active, Enabled, StartTime, StopTime,TimeStyle into modeactive, modeenable, modestarttime, modestoptime, modetimestype 
            from BroadcastMode where idBroadcastMode = modeid limit 1;
   
  if (modeenable = false) then
     return false;
  end if;   
 -- check day matched        
 if (modetimestype = 0) then
     if (PlayDate = date(modestarttime) ) then
         set matched = true;
      end if;
 else
     select AlteredScheduleDay into cur_weekday from AlternateDate where SpecialDate = PlayDate;
      if cur_weekday is null then 
           set cur_weekday = weekday(PlayDate);
       end if;       
       if (modetimestype & (0x01 << cur_weekday)  <> 0 ) then 
        -- date is matched
        set matched = true;
        end if;
   end if;    
    
if (matched = false) then 
    -- mode state will not change in today
    if  (modeactive = false) then
        return false;
    end if;
 end if;
 
 if  (modeactive = false)  and (PlayTime < time(modestarttime)) then
     return false;
 end if;    

if (PlayTime <  time(modestoptime)) then
    return true;
end if;    
return false;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_check_session_daytime
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_check_session_daytime`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_check_session_daytime`(
          brdmode int,
          weekday tinyint, 
          checked_time datetime,
          last_time datetime,
          cur_time datetime
         ) RETURNS tinyint(1)
begin

declare cur_weekday tinyint default null;
declare checked_date date;
declare activemode boolean default false;

-- check whether time is matched
if (last_time >= cur_time) then
    return false;
end if;    

if (brdmode > 0) then
     select Active into activemode from BroadcastMode where idBroadcastMode = brdmode limit 1;
     if  not (activemode = true) then
        return false;
     end if;
end if;     

-- time is matched, check date
if  (weekday > 6) then
-- compare special day
    if (checked_time  > last_time) and (checked_time <= cur_time) then 
        return true;
    end if;    
else
    -- for repeated weekly
     if (time(last_time) > time(cur_time)) then
         -- current date change to next day
         if (time(checked_time) > time(last_time) ) then
              set checked_date = date(last_time);
         else 
              if (time(checked_time) <= time(cur_time)) then
                    set checked_date = date(cur_time);
              else
                    return false;
               end if ;    
          end if;
      else
          -- current date is same as last date
          if (time(checked_time) <= time(last_time) )  or 
              (time(checked_time) > time(cur_time))  then
              -- time is not mached
              return false;
           end if;   
           
           set checked_date = date(cur_time);
      end if;
      
       -- Get alternated week          
      select AlteredScheduleDay into cur_weekday from AlternateDate where SpecialDate = checked_date;

      if cur_weekday is null then 
           set cur_weekday = weekday(checked_date);
       end if;
     
    if (brdmode > 0) or (weekday = cur_weekday)  then 
        -- date is matched
        return true;
   end if;    
end if;

return false;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_get_dev_mode
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_get_dev_mode`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_get_dev_mode`( 
                                    dev_id varchar(50),
                                    checked_daytime datetime) RETURNS int(11)
begin
   declare checkday date;
   declare checktime time;
   declare checkweek int;
   declare ret int default null;
   
   set checkday = date(checked_daytime);
   set checktime = time(checked_daytime);
   
   select AlteredScheduleDay into checkweek from AlternateDate where SpecialDate = checkday;
    if checkweek is null then 
           set checkweek = weekday(checkday);
    end if;       

   
   select  BroadcastMode.idBroadcastMode into ret from BroadcastMode, BrdModeMember 
                  where (BrdModeMember.DeviceID =  dev_id) and
                        (BrdModeMember.BrdModeID = BroadcastMode.idBroadcastMode) and
                        (BroadcastMode.Enabled = true) and
                        (    (  (  (  (BroadcastMode.TimeStyle = 0 and checkday = date(BroadcastMode.StartTime)) or
                                      (BroadcastMode.TimeStyle & (0x01 << checkweek)  <> 0) 
								   ) and  (checktime >= time(BroadcastMode.StartTime))
                                ) or (BroadcastMode.Active = true)
						     ) 
                            and   
                            (   (BroadcastMode.TimeStyle = 0 and checkday <> date(BroadcastMode.StartTime)) or  
							    ( (BroadcastMode.TimeStyle <> 0) and (BroadcastMode.TimeStyle & (0x01 << checkweek)  = 0)) or
                                (checktime < time(BroadcastMode.StopTime))
							)
                        )
      order by BroadcastMode.Priority limit 1;
  
  return ret;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_keepalive_transmit
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_keepalive_transmit`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` FUNCTION `func_keepalive_transmit`( 
          net_id int, proxy varchar(50),dst_ip varchar(50)
         ) RETURNS varchar(50) CHARSET gb2312
begin
if  (dst_ip is null)  and (proxy = '0.0.0.0') then
    return 0;
end if;    
select Description into @ver from BaseInfo where InfomationID=0x200;
if (net_id = 0)  then     
    return srv_send_keepalive(proxy, 7805, 32, @ver) ;
 else 
    if  (dst_ip is null)  then
        return srv_send_keepalive(proxy, 7805, 40, @ver) ;
     else    
        return srv_send_keepalive(dst_ip, 7805, 40, @ver) ;
     end if;    
end if;

end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_dev_mode
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_dev_mode`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_dev_mode`(dev_id varchar(50)) RETURNS int(11)
begin
 declare ret int default 0;
 
 select BrdModeMember.BrdModeID into ret from BrdModeMember
                left join BroadcastMode on BroadcastMode.idBroadcastMode = BrdModeMember.BrdModeID
                where (BrdModeMember.DeviceID = dev_id) and (BroadcastMode.Active = true) 
                 order by    BroadcastMode. Priority LIMIT 1;       
                 
 return ret;                
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_dev_session
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_dev_session`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_dev_session`(dev_id varchar(50), sessionId smallint unsigned, 
                                                                                       playerid varchar(50), SesMode int) RETURNS tinyint(1)
begin
 declare modeid int default 0;
 declare sespriority int default null;
 declare modepriority int default null;
 declare modemembertype boolean default false;
 
 set modeid = get_dev_mode(dev_id) ;
 
 select Priority into modepriority from BroadcastMode where idBroadcastMode = modeid LIMIT 0, 1;
 select Priority , MemberMode into sespriority, modemembertype from
                               PlaySessions where PlaySessions.SessionID = sessionId LIMIT 0, 1;
 
  
 if (modeid = SesMode and  modemembertype = true) then
 -- device in mode, and session is in same mode, and sesstion use mode members
     return true;
  end if;
  
 if not (modeid > 0 and  SesMode <> modeid and sespriority >= modepriority) then
    if exists (select DeviceID from SessionDevice 
                 where (SessionDevice.DeviceID = dev_id) and (SessionDevice.SessionID = sessionId) and (not DevDisabled = 1)) then
                 -- for automatic session or manual session
                 return true;
      else
                return exists (select DeviceList .DevID from DeviceList , PlayerKeys 
                            where DeviceList .DevID =  dev_id and PlayerKeys.PlayerID = playerid and
                            PlayerKeys.GroupDisable = 0 and 
                            ((PlayerKeys.GroupID <> 0) and sp_dev_belong_group(DeviceList.DevID, PlayerKeys.GroupID)));

    end if;  
 end if;

  
  return false;                                
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_idle_port
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_idle_port`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_idle_port`() RETURNS int(10) unsigned
begin

declare idle_port int unsigned;

set idle_port = 7000;

emp_loop: loop   
if not exists(select * from PlayerStatus where PlayPort = idle_port) then   
leave emp_loop;
end if;
set idle_port = idle_port + 2;
end loop;

return  idle_port;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_idle_sessionid
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_idle_sessionid`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_idle_sessionid`(video boolean) RETURNS smallint(5) unsigned
begin

declare ses_id smallint unsigned default 1;

 emp_loop: loop   
if not exists(select SessionID from PlaySessions where SessionID = ses_id) then   
leave emp_loop;
end if;
set ses_id = ses_id + 1;
end loop;

return  ses_id;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function get_network
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_network`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_network`(ipaddr varchar(50)) RETURNS int(10) unsigned
BEGIN

declare src_ip int unsigned;
declare mask int unsigned;
declare proxy int unsigned;
declare netid int unsigned;
declare ret int default 0;

DECLARE done INT DEFAULT 0;   
DECLARE cur1 CURSOR FOR SELECT 
    idSubNetwork, inet_aton(NetMask), inet_aton(IpAddress) 
    FROM SubNetwork;   
DECLARE CONTINUE HANDLER FOR NOT FOUND SET done=1;   

set src_ip = inet_aton(ipaddr);
OPEN cur1;   

emp_loop: LOOP   

FETCH cur1 INTO netid, mask, proxy;   

if ((src_ip & mask) = (proxy & mask))  and (mask <> 0) then
set ret = netid;
set done = 1;
-- else
-- set done = 1;
end if;

IF done=1 THEN   
LEAVE emp_loop;   
END IF;   
END LOOP emp_loop;   
CLOSE cur1;   

return  ret;
END$$

DELIMITER ;


-- -----------------------------------------------------
-- function get_rtmp_url
-- -----------------------------------------------------
USE `nccs`;
DROP function IF EXISTS `get_rtmp_url`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` 
FUNCTION `get_rtmp_url`(dev_id varchar(50)) 
RETURNS varchar(256) CHARSET utf8
BEGIN
	declare srsSrv varchar(128) default null;
    declare a int default 0;
    declare b varchar(128) default null;
    declare flag boolean default true;
	declare cur_tmp CURSOR FOR select `id`,`server` from `SrsServer` order by id asc;
	declare continue handler for NOT FOUND set flag=false;
	
	OPEN cur_tmp;
	fetchLoop:loop
		fetch cur_tmp into a,b;
		if(flag=false) then
			leave fetchLoop;
		end if;
        insert into SrsServerStatus values(a, b, 0) 
			on duplicate key update 
				id=values(id), `server`=values(`server`);
	end loop;
	close cur_tmp;

    select `server` into srsSrv from SrsServerStatus order by count asc limit 1;
    if(srsSrv is null) then
		insert into SrsServer (`name`, `server`) values('localhost', inet_ntoa(get_srv_ip())) 
			on duplicate key update `server`=values(`server`);
        set srsSrv = inet_ntoa(get_srv_ip());
    end if;
    update MediaFiles, PlayListFiles, PlaySessions 
        set MediaFiles.FilePath=concat(concat(concat('rtmp://', srsSrv), '/bw803/') , dev_id) 
        where PlayListFiles.FileID=MediaFiles.MediaID
            and PlayListFiles.SessionID = PlaySessions.SessionID
            and PlaySessions.PlayerID=dev_id;
    return concat(concat(concat('rtmp://', srsSrv), '/bw803/') , dev_id);
END$$
DELIMITER ;



-- -----------------------------------------------------
-- procedure sp_add_media_blcok
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_add_media_blcok`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_add_media_blcok`(in media_id int,
        in dat varbinary(8192),
        out ret int)
BEGIN
         set ret = add_media_block(CONCAT(@@datadir, 'media/', media_id) , dat);                      
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_check_group
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_check_group`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `sp_check_group`(
           check_group int,
           ses smallint unsigned,
           keyno int,
           checkstate bool,
           depth int)
begin
    declare gid int;
    declare cur1 cursor for select ClassID from DevClasses where Parent = check_group;
    declare continue handler for sqlstate '02000' set gid = null; 


      if (depth < 5) then
            if  (checkstate = true) then
                 insert into SessionDevice(DeviceID, SessionID, KeyIndex)
                       select `DeviceList`.`DevID`, ses, keyno from DeviceList where parent = check_group
                on duplicate key update SessionID = values(SessionID);                
            else
                 delete SessionDevice from SessionDevice , DeviceList 
                       where SessionDevice.SessionID = ses and SessionDevice.KeyIndex = keyno 
                                     and SessionDevice.DeviceID = DeviceList.DevID and
                                      DeviceList.parent = check_group;
            end if;  

       open cur1; 
       fetch cur1 into gid; 

       while ( gid is not null )  do
         call sp_check_group(gid, ses, keyno, checkstate, depth+1); 
         fetch cur1 into gid; 
       end while; 
 end if; 
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_copy_mode
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_copy_mode`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_copy_mode`(
    old_modeid int,
    new_enabled boolean
    )
begin
declare new_modeid int default null;

declare old_session smallint default null;
declare new_session smallint default null;

declare mode_task_cur cursor for select  SessionID  from PlaySessions where BrdMode = old_modeid;  
declare continue handler for sqlstate '02000' set old_session = null;

  -- first step: copy mode record
  insert into BroadcastMode(ModeName, Priority, Enabled, StartTime, StopTime, TimeStyle, Active)  
           (select concat(ModeName, " copy"), Priority, new_enabled, StartTime, StopTime, TimeStyle, false from BroadcastMode where idBroadcastMode=old_modeid) ;
   
   set new_modeid = last_insert_id();
   
   if (new_modeid is not null) then
      -- copy mode members;
      insert into BrdModeMember(BrdModeID,DeviceID)  (select new_modeid,DeviceID from BrdModeMember where BrdModeID =  old_modeid);
      
      -- copy mode tasks;
      open  mode_task_cur;  
       fetch mode_task_cur into old_session;  
         
      while ( old_session is not null) do
            set new_session = get_idle_sessionid(false);
             insert into PlaySessions(SessionID,SessionName,SessionType,Priority,`Status`,CircleLength,ClassID,PlayerID,Parent,BrdMode,
                                                                MemberMode,StreamType,SysEnabled,RfDevCtrl,PlayMode, AudioGain)
                                   (select new_session,SessionName,SessionType,Priority,`Status`,CircleLength,ClassID,PlayerID,Parent,new_modeid,
                                                                MemberMode,StreamType,SysEnabled,RfDevCtrl,PlayMode,AudioGain
                                                                from PlaySessions where SessionID = old_session);
            
            insert into PlaySessionTime(SessionID,WeekDay,PlayTime,TempFlag) 
                          (select new_session,WeekDay,PlayTime,TempFlag from PlaySessionTime where SessionID = old_session);
            
            insert into PlayListFiles(FileID,SequenceID,SessionID,Duration,KeyIndex,PlayerID) 
                          (select FileID,SequenceID,new_session,Duration,KeyIndex,PlayerID from PlayListFiles where SessionID = old_session);
                          
             insert into SessionDevice(DeviceID,SessionID,KeyIndex,DevDisabled)
                           (select  DeviceID,new_session,KeyIndex,DevDisabled from  SessionDevice where SessionID = old_session);
             
             fetch mode_task_cur into old_session;  

      end while;
      close mode_task_cur;
   end if;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_del_media_class
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_del_media_class`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_del_media_class`(classid int)
BEGIN
      UPDATE MediaFiles SET ClassID=0 WHERE (Parent=classid) ;
	DELETE FROM MediaClasses WHERE ID = classid;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_del_media_file
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_del_media_file`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_del_media_file`(userid int, media_id int)
BEGIN

	declare tmp_own int default null;
	declare tmp_priority int;
	declare tmp_mediaid int default null;
	declare mediacurs cursor for select MediaID from MediaFiles where Parent = media_id;
	declare continue handler for not found,1329,sqlstate '02000' set tmp_mediaid = null;

	select func_get_mediafile_Owner(media_id) into tmp_own;
	-- select Priority into tmp_priority from Users where User_ID = userid;

	if((tmp_own = userid) or (userid = 0)) then

		open mediacurs;
		fetch mediacurs into tmp_mediaid;
			
		while(tmp_mediaid is not null) do
			call sp_del_media_file(userid,tmp_mediaid);
			fetch mediacurs into tmp_mediaid;
		end while;
		
		
		if ( not exists (select PlayingFileID from  PlayingSessions where PlayingFileID = media_id)) then
			DELETE FROM PlayListFiles WHERE FileID = media_id;
			DELETE FROM MediaFiles WHERE MediaID = media_id; 
		end if;

	end if;

END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_del_session_class
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_del_session_class`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_del_session_class`(classid int)
BEGIN
	UPDATE PlaySessions SET ClassID=NULL WHERE ClassID = classid;
	DELETE FROM SessionClasses WHERE (ClassID=classid);
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_delete_device
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_delete_device`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_delete_device`(dev_id varchar(50))
begin
-- delete devices
delete from UserDevices where DevID = dev_id;
delete from DevCtrlSchedule where DevID = dev_id;
delete from SessionDevice where DeviceID = dev_id;
delete from BrdModeMember where DeviceID = dev_id;
delete from DeviceList where DevID = dev_id;

-- delete player
delete from PlaySessions where PlayerID = dev_id;
delete from PlayerKeys where PlayerID = dev_id;
delete from Players where PlayerID = dev_id;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_delete_group
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_delete_group`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_delete_group`(GrpID int)
begin
delete from PlayGroupDevices where GroupID = GrpID;
delete from PlaySessionGroups where GroupID = GrpID;
delete from PlayGroups where GroupID = GrpID;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_dev_belong_group
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_dev_belong_group`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_dev_belong_group`(dev varchar(50), groupid int) RETURNS tinyint(1)
begin
    declare ret boolean default false ;
    declare gid int default 0;
   
   set gid  = groupid;
   
      if (groupid is null) or (groupid = 0) then
       return true;
    end if;
    
    if (dev is null)  then
       return false;
    end if;
    
   select Parent into gid  from  DeviceList   where DevID = dev;
   
   if (gid = groupid) then
       return true;
    end if;
    
    while (( gid is not null ) and (gid <> 0))  do
         select Parent into gid from  DevClasses   where ClassID = gid;
 
         if (gid = groupid) then
               return true;
          end if; 
    end while;        
   return false;   
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_dev_keepalive
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_dev_keepalive`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_dev_keepalive`(
    devid varchar(50),
    dev_name varbinary(32),
    dev_status  tinyint,
    power tinyint,
    fault tinyint,
    proj  tinyint,
    autual_ses smallint unsigned,
    rf_dev_status binary(16),
    ip_addr varchar(50),
    ip_call tinyint unsigned,
    auth_key varchar(50)
)
BEGIN
    declare tmp int;
    declare ipCall int;
    INSERT INTO DeviceList(DevID,Dev_Name) VALUES (devid, dev_name)
        ON DUPLICATE KEY UPDATE Dev_Name= VALUES(Dev_Name);
    
    set tmp = get_network(ip_addr);
        
    if(length(trim(auth_key)) = 0) then
        set @uid = NULL;
    else
        set @card = LPAD(trim(auth_key), 10, 0);
        set @cardHex = LPAD(conv(auth_key,10, 16), 8, 0);
        set @cardHex = concat(substring(@cardHex, 7,2), substring(@cardHex, 5, 2), substring(@cardHex, 3, 2), substring(@cardHex, 1, 2));
        set @cardSwitch = LPAD(ltrim(conv(@cardHex, 16, 10)), 10, 0);
        select User_ID into @uid from Users where LPAD(trim(Users.IcCard), 10, 0) = @card or LPAD(trim(Users.IcCard), 10, 0) = @cardSwitch;
    end if;
    INSERT INTO DeviceStatus(DeviceID,  DeviceStatus,State_SysPower,
                             State_FaultStatus, State_ProjectorStatus, ActualSessionID,
                             RfDevStatus, IpAddress, NetworkID, State_Pc,IpCallStatus,User_ID)
          VALUES (devid, dev_status, (power & 0x0F), fault, proj, autual_ses, rf_dev_status, ip_addr, tmp, (power >> 6), ip_call, @uid)
          ON DUPLICATE KEY UPDATE
          DeviceStatus= VALUES(DeviceStatus), State_SysPower = VALUES(State_SysPower),
          State_FaultStatus= VALUES(State_FaultStatus),
          State_ProjectorStatus = VALUES(State_ProjectorStatus),
          ActualSessionID = VALUES(ActualSessionID),
          RfDevStatus =  VALUES(RfDevStatus),
          IpAddress = VALUES(IpAddress),
          NetworkID = VALUES(NetworkID),
          State_Pc = VALUES(State_Pc),
          IpCallStatus = VALUES(IpCallStatus),
          User_ID=VALUES(User_ID);
  
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_get_dev_ctrl_tasks
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_get_dev_ctrl_tasks`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_get_dev_ctrl_tasks`(dev_id varchar(50),
        start_datetime datetime)
label_pro: begin
         declare check_day date;
         declare check_start time;
         declare check_stop time;
         declare check_week int;
         
         create temporary table `tmp_dev_tasks` (
                            task_time int,
                            dev_ctrl     int
         ) engine = memory;

         set check_day = date(start_datetime);
         set check_start = time(start_datetime);
         set check_stop = '23:59:59';
         
         select AlteredScheduleDay into check_week from AlternateDate where SpecialDate = check_day;
         if check_week is null then 
              set check_week = weekday(check_day);
         end if;    
         

         
          insert  into tmp_dev_tasks(task_time, dev_ctrl)
            select UNIX_TIMESTAMP(date_add(check_day, interval time(a.PlayTime) hour_second) ),  a.SysEnabled
                  from  (select a.PlayTime, a.WeekDay, b.SessionID, 
                                      b.BrdMode, b.SysEnabled, 
                                      b.MemberMode, b.Priority, c.Priority as modepriority
                                  from PlaySessionTime a
                                  left join PlaySessions b on a.SessionID = b.SessionID
                                  left join BroadcastMode c on c.idBroadcastMode =  b.BrdMode 
                                   where  b.SysEnabled is not null and 
                                                   (check_week =  a.WeekDay  or b.BrdMode > 0) and  
                                                   check_start <= time(a.PlayTime) and 
                                                   check_stop > time(a.PlayTime))  as a
                left join BroadcastMode b on 
                                   b.idBroadcastMode = func_get_dev_mode(dev_id, 
                                                                                           date_add(check_day, interval time(a.PlayTime) hour_second)) 
                left join SessionDevice  c on c.SessionID = a.SessionID and c.DeviceID = dev_id 
            where 
                  ((a.MemberMode = true) and (b.idBroadcastMode = a.BrdMode))  or
                   ((a.MemberMode = false or a.MemberMode is null)   and
                         c.DevDisabled = false and
                         ( ( (a.Priority < b.Priority or b.Priority is null) and (a.BrdMode is null or a.BrdMode = 0) ) or
                          (a.BrdMode > 0 and (a.modepriority <  b.Priority or b.Priority is null)) ));        
       
       -- Get next day scheduled tasks
         set check_day = date_add(check_day, interval 1 day) ;
         set check_start = '00:00:00';
         set check_stop = time(start_datetime);
         
         select AlteredScheduleDay into check_week from AlternateDate where SpecialDate = check_day;
         if check_week is null then 
              set check_week = weekday(check_day);
         end if;    
         
         
         insert  into tmp_dev_tasks(task_time, dev_ctrl)
             select UNIX_TIMESTAMP(date_add(check_day, interval time(a.PlayTime) hour_second) ),  a.SysEnabled
                  from  (select a.PlayTime, a.WeekDay, b.SessionID, 
                                      b.BrdMode, b.SysEnabled, 
                                      b.MemberMode, b.Priority, c.Priority as modepriority
                                  from PlaySessionTime a
                                  left join PlaySessions b on a.SessionID = b.SessionID
                                  left join BroadcastMode c on c.idBroadcastMode =  b.BrdMode 
                                   where  b.SysEnabled is not null and 
                                                   (check_week =  a.WeekDay  or b.BrdMode > 0) and  
                                                   check_start <= time(a.PlayTime) and 
                                                   check_stop > time(a.PlayTime))  as a
                left join BroadcastMode b on 
                                   b.idBroadcastMode = func_get_dev_mode(dev_id, 
                                                                                           date_add(check_day, interval time(a.PlayTime) hour_second)) 
                left join SessionDevice  c on c.SessionID = a.SessionID and c.DeviceID = dev_id 
       where 
                  ((a.MemberMode = true) and (b.idBroadcastMode = a.BrdMode))  or
                   ((a.MemberMode = false or a.MemberMode is null)   and
                         c.DevDisabled = false and
                         ( ( (a.Priority < b.Priority or b.Priority is null) and (a.BrdMode is null or a.BrdMode = 0) ) or
                          (a.BrdMode > 0 and (a.modepriority <  b.Priority or b.Priority is null)) ));          
                          
      select  task_time, dev_ctrl  from   tmp_dev_tasks order by   task_time limit 10;      
      
      drop table tmp_dev_tasks;
         
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_get_dev_scheduled_tasks
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_get_dev_scheduled_tasks`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_get_dev_scheduled_tasks`(dev_id varchar(50),
        start_datetime datetime,
        stop_datetime datetime)
label_pro: begin
         declare check_day date;
         declare check_start time;
         declare check_stop time;
         declare check_week int;

         set check_day = date(start_datetime);
         set check_start = time(start_datetime);
         set check_stop = time(stop_datetime);
         
         select AlteredScheduleDay into check_week from AlternateDate where SpecialDate = check_day;
         if check_week is null then 
              set check_week = weekday(check_day);
         end if;    
         
		 select InfoValue into @templateNow from BaseInfo where InfomationID = 0x101;         
         
         if (check_day <> date(stop_datetime)) or (check_start >= check_stop) then
             leave label_pro;
         end if;  
        
		select PlaySessionTime.ScheduleID as ScheduleID, PlaySessionTime.TempFlag as TempFlag, time(PlaySessionTime.PlayTime) as PlayTime, 
                PlaySessions.SessionID as SessionID,PlaySessions.SessionName as SessionName, 
                devmode.idBroadcastMode as DeviceMode, devmode.ModeName as DeviceModeName,
				taskmode.idBroadcastMode as TaskMode, 
				case when (taskmode.idBroadcastMode is not null) then taskmode.Priority else PlaySessions.Priority end as TaskPriority, 
                devmode.Priority as DevPriority
            FROM nccs.PlaySessions 
                left join PlaySessionTime on PlaySessionTime.SessionID =  PlaySessions.SessionID
                left join BroadcastMode devmode on devmode.idBroadcastMode = func_get_dev_mode(dev_id,  DATE_ADD(check_day, INTERVAL time(PlayTime) HOUR_SECOND ))
				left join BroadcastMode taskmode on taskmode.idBroadcastMode = PlaySessions.BrdMode
                left join SessionDevice on SessionDevice.DeviceID = dev_id and SessionDevice.SessionID = PlaySessions.SessionID
                left join BrdModeMember on BrdModeID = PlaySessions.BrdMode and BrdModeMember.DeviceID = dev_id
			where (    (check_start <= time(PlaySessionTime.PlayTime) and check_stop > time(PlaySessionTime.PlayTime)) and -- Play time is matched
					   (    (    ((taskmode.idBroadcastMode is null) or (taskmode.idBroadcastMode = 0)) and 
                                 (check_week = PlaySessionTime.WeekDay) and
                                 ((PlaySessions.Priority < devmode.Priority) or (devmode.Priority is null))
                            ) or -- non mode task whose date is matched
							(taskmode.idBroadcastMode = devmode.idBroadcastMode) or -- mode task whose mode is matched
                            (   ((devmode.Priority is null) or (devmode.Priority > taskmode.Priority) ) and  -- mode task whose mode priority is higher than device
								(taskmode.Enabled = true) and
							    -- check whether mode task will run
								(
                                    (  (  (  (taskmode.TimeStyle = 0 and check_day = date(taskmode.StartTime)) or
                                             (taskmode.TimeStyle & (0x01 << check_week)  <> 0) 
								          ) and  (time(PlaySessionTime.PlayTime) >= time(taskmode.StartTime))
                                       ) or (taskmode.Active = true)
						            ) 
                                    and   
                                    (   (taskmode.TimeStyle = 0 and check_day <> date(taskmode.StartTime)) or  
							            ( (taskmode.TimeStyle <> 0) and (taskmode.TimeStyle & (0x01 << check_week)  = 0)) or
                                        (time(PlaySessionTime.PlayTime) < time(taskmode.StopTime))
							        )
								)
                            )
						) and 
						(
							( ((PlaySessions.MemberMode is null) or (PlaySessions.MemberMode = 0)) and (SessionDevice.SessionDevID is not null) ) or
							( (PlaySessions.MemberMode > 0) and (BrdModeMember.DevIDMode is not null))
						) 
					and ((PlaySessions.Template is null) or (PlaySessions.Template=@templateNow))
				  )
			 order by PlayTime;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_group_dev_ctrl_func
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_group_dev_ctrl_func`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_group_dev_ctrl_func`(
    ctrl_devid varchar(50),
    ctrl_groupid int,
    cmd int,
    state int,
    extargs varchar(256)) RETURNS int(11)
begin
    declare tmp int default 0 ;
    
    if (ctrl_devid is not null) and (ctrl_devid <>"") then
        select sp_send_dev_ctrl_function(ctrl_devid, IpAddress, cmd,state, 0, 0, extargs )  into tmp from DeviceStatus 
        where DeviceID = ctrl_devid;
     end if;
     
     if (ctrl_groupid is not null) and (ctrl_groupid <> 0) then
         -- set @@max_sp_recursion_depth = 5;       
         -- call sp_send_group_cmd(ctrl_groupid, cmd, state, extargs);
         insert into tmp_result
           select sp_send_dev_ctrl_function(DeviceStatus.DeviceID, DeviceStatus.IpAddress, cmd,state, 0, 0, extargs ) 
               from DeviceStatus , DeviceList
               where  DeviceList.DisableParentSchedule = false and
                              sp_dev_belong_group(DeviceList.DevID, ctrl_groupid) and 
                              DeviceList.DevID = DeviceStatus.DeviceID ;
                              
          delete from tmp_result;                    

     end if;

    return tmp;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_keepalive_send
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_keepalive_send`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_keepalive_send`()
begin
 -- select func_keepalive_transmit(b.idSubNetwork, b.IpAddress, a.IpAddress) from SubNetwork as b 
 --   left join DeviceStatus a  on b.idSubNetwork = a. NetworkID group by  idSubNetwork;
  select func_keepalive_transmit(c.idSubNetwork, c.IpAddress, c.proxy) from 
( select b.idSubNetwork, b.IpAddress, a.IpAddress as proxy from SubNetwork as b 
    left join (select NetworkID, IpAddress from DeviceStatus group by  NetworkID) as a on b.idSubNetwork = a. NetworkID) as c;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_player_keepalive
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_player_keepalive`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_player_keepalive`(
    devid varchar(50),
    player_type tinyint,   -- 0: Autobroadcast player, 1: caller
    player_status tinyint, -- 0: stoped, 1:playing
    actual_ses int , 
    keymap int,           -- recevier members
    key_type tinyint,  -- 0: group call; 1: device call
    ip_addr varchar(50)
    )
BEGIN
    declare net_id int;
    declare key_index int;
    declare group_en tinyint;
    declare dev_en tinyint;
    
if ((player_type <> 2) or exists(select PlayerID from Players where PlayerID = devid)) then
   

    insert into Players(PlayerID, PlayerType ) values (devid, player_type)
        on duplicate key update PlayerType= values(PlayerType);
    
    set net_id = get_network(ip_addr);
        
    insert into PlayerStatus(PlayerID,  ActualSesID, IpAddress, NetID, PlayType)
        values (devid,  actual_ses, ip_addr, net_id, player_type)
        on duplicate key update
            IpAddress = values(IpAddress), ActualSesID =  values(ActualSesID), NetID = values(NetID);

    -- assign an idle port to the player
    update   PlayerStatus set PlayPort = get_idle_port() where PlayPort is null and PlayerID = devid;


    if ((player_type <> 0) and (player_type <> 8)) then
        if (player_status = 1) then
            update   PlayerStatus set SessionID = (select SessionID from PlaySessions where PlayerID = devid) 
                   where  (PlayerID = devid) and (SessionID is null or  SessionID = 0);
        else 
            if (player_status = 0) then
                update   PlayerStatus set SessionID = 0
                    where  (PlayerID = devid) and (SessionID <> 0) ;
            end if;           
        end if;

         -- update keepalive time
        insert into PlayerAlive(PlayerID, ReFreshTime) values(devid, now()) 
            on duplicate key update ReFreshTime=values(ReFreshTime);
    end if;    
 

    if (player_type = 1) then

        -- update key map
        set  key_index = 0;
        while (key_index < 16) do
            if (keymap & (0x01 << key_index) <> 0) then
                if (key_type = 0) then
                    set group_en = 0;
                    set dev_en = 1;
                else
                    set dev_en = 0;
                    set group_en = 1;
                end if;    
            else
                set dev_en = 1;
                set group_en = 1;
            end if;
 
    
            insert into PlayerKeys(PlayerID, `Index`, GroupDisable, DevDisable)  values (devid, key_index + 1, group_en, dev_en)
                on duplicate key update GroupDisable=values(GroupDisable), DevDisable=values(DevDisable) ;
 
		    set  key_index =key_index + 1;

        end while;

    end if;
end if; 
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_player803_keepalive
-- -----------------------------------------------------
USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_player803_keepalive`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_player803_keepalive`(
    devid varchar(50),
    player_type tinyint,
    player_status tinyint, 
    actual_ses int , 
    ip_addr varchar(50)
    )
BEGIN
    declare sesid int;

    if (player_status <> 2) then
        insert into Players(PlayerID, PlayerType ) values (devid, player_type)
            on duplicate key update PlayerType= values(PlayerType);
    end if;
    insert into PlayerStatus(PlayerID,  ActualSesID, IpAddress, NetID, PlayType)
        values (devid,  0, ip_addr, get_network(ip_addr), player_type)
        on duplicate key update
            IpAddress = values(IpAddress), ActualSesID =  values(ActualSesID), NetID = values(NetID);

    if (player_status = 1) then 
        call sp_send_dev_ctrl_cmd(devid, ip_addr, 131, (select SessionID from PlaySessions where PlayerID = devid), 0, 0, get_rtmp_url(devid));
    elseif (player_status = 2) then 
		select SessionID into sesid from PlaySessions where PlayerID = devid;
		if not exists(select SessionID from PlayingSessions where SessionID = sesid)  then
			call sp_session_Ctrl((select SessionID from PlaySessions where PlayerID = devid), 1, null);
		end if;
    elseif (player_status = 0)  and (actual_ses <> 0) then
        call sp_session_Ctrl(actual_ses, 0, null);
        call sp_send_dev_ctrl_cmd(devid, ip_addr, 133, actual_ses, 0, 0, null);
    end if;
	
    insert into PlayerAlive(PlayerID, ReFreshTime) values(devid, now()) 
        on duplicate key update ReFreshTime=values(ReFreshTime);
end$$
DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_reset_player
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_reset_player`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_reset_player`(player varchar(50))
BEGIN
update PlayerStatus set SessionID = 0, ActualSesID = 0 where PlayerID = player ;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_send_dev_cfg_cmd
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_send_dev_cfg_cmd`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_send_dev_cfg_cmd`(
    devid VARCHAR(50),
    Ipaddr VARCHAR(50),
    devcfg VARCHAR(1024)
    )
BEGIN
    declare tmp int;
    set tmp = device_config(Ipaddr, devid,  devcfg);
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_send_dev_ctrl_cmd
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_send_dev_ctrl_cmd`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_send_dev_ctrl_cmd`(
    devid varchar(50),
    Ipaddr varchar(50),
    cmd tinyint unsigned,
    para1 int unsigned,
    para2 int unsigned,
    para3 int unsigned,
    extarg varchar(256)
    )
begin
    declare ret int default null;
    if(cmd = 62) then
        update DeviceDesiredStaus set SysEnabled =
                func_set_device_sysenable(devid, para1)
            where DeviceID = devid;
    elseif(extarg is null) then
        set ret = device_ctrl(Ipaddr, devid, cmd, para1, para2, para3);
    else
        set ret = device_ctrl(Ipaddr, devid, cmd, para1, para2, para3, extarg);
    end if;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_send_dev_ctrl_function
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_send_dev_ctrl_function`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_send_dev_ctrl_function`(
    user_id int,
    devid varchar(50),
    Ipaddr varchar(50),
    cmd int ,
    para1 int ,
    para2 int ,
    para3 int ,
    extarg varchar(256)
    ) RETURNS int(11)
BEGIN

    declare ret int default null;  
    
    if(cmd = 0x40) then
        set ret = device_message(Ipaddr, devid,  para1, extarg);
    else
        set ret = device_ctrl(Ipaddr, devid, cmd, para1, para2, para3);
    end if;
     
    return ret;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_send_group_cmd
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_send_group_cmd`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_send_group_cmd`(
    groupid int,
    cmd int,
    state int,
    extargs varchar(256))
begin

       insert into tmp_result 
              select sp_send_dev_ctrl_function(null,DeviceID, IpAddress, cmd,state, 0, 0, extargs) from DeviceStatus
               where IpAddress is not null  and sp_dev_belong_group(DeviceID,  groupid) = true;
               
        delete from   tmp_result  ;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_session_clean_up
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_session_clean_up`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_session_clean_up`()
begin
 -- delete obseloted sessions
 delete PlaySessions from PlaySessions 
where (SessionType = 0 or SessionType = 8) and 
               (not exists (select ScheduleID from PlaySessionTime where SessionID = PlaySessions.SessionID)) and
               (not exists (select PlayerID from PlayingSessions where SessionID = PlaySessions.SessionID) );

end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_session_ctrl
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_session_ctrl`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_session_ctrl`(ses_id  smallint unsigned, ses_status int, sche_id int)
begin
declare Player int default null;
declare ses_type tinyint unsigned default 0;


if (ses_status = 1) then
     -- start session
     if exists(select Player = PlayerID from PlayerStatus where SessionID = ses_id) then
            -- session has been started and pasued, restart it
            update PlayingSessions set  Pause = 0 where SessionID = ses_id;
     else
            -- start a new session
            select SessionType into ses_type from PlaySessions where SessionID = ses_id limit 1;

            if ((ses_type < 8)  and (ses_type <> 1)) then
                -- start an audio 
                update PlayerStatus set SessionID = ses_id, ScheduleID = sche_id
                            where (SessionID = 0 OR SessionID is null)  and 
                                           (ActualSesID = 0 OR ActualSesID is null)   and PlayType = 0 limit 1;
              else 
                     -- start an video 
                          update PlayerStatus set SessionID = ses_id, ScheduleID = sche_id
                            where (SessionID = 0 OR SessionID is null)  and 
                                           (ActualSesID = 0 OR ActualSesID is null)   and PlayType = 8 limit 1;
             end if;
      end if;
else
      if (ses_status = 0) then
            update PlayerStatus set SessionID = 0 where (SessionID = ses_id) limit 1;
       else
            update PlayingSessions set  Pause = 1 where SessionID = ses_id;
        end if;   
end if;
end$$

DELIMITER ;

-- -----------------------------------------------------
-- function sp_session_start
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`sp_session_start`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `sp_session_start`(
                                   ses_id int, 
                                   sche_id int,
                                   flag tinyint,
                                   stream tinyint,
                                   brd_mode int,
                                   mode_member boolean,
                                   sys_enable tinyint ,
                                   rf_dev_ctrl_cmd binary(16)) RETURNS tinyint(4)
begin
     declare run_priority int default  null;
     if (flag = 2) then 
         return 0;
     end if;
     
    if ((stream & 0x7f) > 0) then
         call sp_session_ctrl(ses_id, 1, sche_id);
     end if;
     
     if  (brd_mode > 0) then
         if  (mode_member = true)  then
                update DeviceDesiredStaus set SysEnabled = 
                    case when sys_enable is not null then
                        func_set_device_sysenable(DeviceDesiredStaus.DeviceID, sys_enable)
                    else DeviceDesiredStaus.SysEnabled 
                    end, DeviceDesiredStaus.RfDevCtrl =     
                    case when rf_dev_ctrl_cmd is not null then
						func_update_rf_ctrl(DeviceDesiredStaus.DeviceID, DeviceDesiredStaus.RfDevCtrl, rf_dev_ctrl_cmd)
					else
						DeviceDesiredStaus.RfDevCtrl 
					end
                    where   DeviceDesiredStaus.BrdMode = brd_mode;
            else
                    select  Priority into run_priority from BroadcastMode where idBroadcastMode =  brd_mode limit 1;
                    
                    update DeviceDesiredStaus, SessionDevice set DeviceDesiredStaus.SysEnabled = 
                            case when sys_enable is not null then
                                func_set_device_sysenable(DeviceDesiredStaus.DeviceID, sys_enable)
                            else DeviceDesiredStaus.SysEnabled 
                            end, DeviceDesiredStaus.RfDevCtrl =    
                            case when rf_dev_ctrl_cmd is not null then
                                func_update_rf_ctrl(DeviceDesiredStaus.DeviceID, DeviceDesiredStaus.RfDevCtrl, rf_dev_ctrl_cmd)
                            else
                                DeviceDesiredStaus.RfDevCtrl 
                            end
                    where   (SessionDevice.SessionID = ses_id) and (SessionDevice.DevDisabled = false) and 
                            (DeviceDesiredStaus.DeviceID =    SessionDevice.DeviceID) and
                            ((DeviceDesiredStaus.ModePriority is null) or (DeviceDesiredStaus.ModePriority >= run_priority));    
                    
            end if;
     else 
          -- non mode task
          select  Priority into run_priority from PlaySessions where SessionID =  ses_id limit 1;
          
                update DeviceDesiredStaus, SessionDevice set DeviceDesiredStaus.SysEnabled = 
                    case when sys_enable is not null then
                        func_set_device_sysenable(DeviceDesiredStaus.DeviceID, sys_enable)
                    else DeviceDesiredStaus.SysEnabled 
                    end, DeviceDesiredStaus.RfDevCtrl =    
                    case when rf_dev_ctrl_cmd is not null then
						func_update_rf_ctrl(DeviceDesiredStaus.DeviceID, DeviceDesiredStaus.RfDevCtrl, rf_dev_ctrl_cmd)
					else
						DeviceDesiredStaus.RfDevCtrl 
					end
                where   (SessionDevice.SessionID = ses_id) and (SessionDevice.DevDisabled = false) and
                        (DeviceDesiredStaus.DeviceID =    SessionDevice.DeviceID) and
                        ((DeviceDesiredStaus.ModePriority is null) or (DeviceDesiredStaus.ModePriority > run_priority));    
          
          
      end if; 
	
	if ((stream & 0x7f) = 0) and (flag = 1) then
		return 127; /*mark the task shall be deleted immidicately*/
	end if;
	
    return flag;
	
    
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_timer_deamon
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_timer_deamon`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_timer_deamon`()
begin

declare last_time datetime default '2012-1-1 00:00:00';
declare cur_time datetime; 
declare active_template int default null;

-- get last processed time
select LastTime into last_time from LastProcessedTime where LastTimeID = 1;

-- select active task template
select InfoValue into active_template from BaseInfo where InfomationID = 0x101;
set  cur_time = now();

if ((last_time > cur_time) or (timestampdiff(second, last_time, cur_time) > 10)) then
    set last_time = timestampadd(second, -2, cur_time);
 end if;   
 
-- delete expired messages
delete from Messages where abs(timestampdiff(second, MsgTime, cur_time)) > 10;

-- update mode status
update BroadcastMode set
             Active = ! Active
             where (Enabled = true) and
                            (func_check_mode_daytime(TimeStyle, 
                                                     case when Active = false then StartTime else StopTime end, 
                                                     last_time, cur_time) = true);
             
-- Update device modes
insert into DeviceDesiredStaus(DeviceID, BrdMode, ModePriority)
        select  DeviceID, BrdModeID, Priority from v_DeviceModes
        on duplicate key update BrdMode = values(BrdMode), ModePriority = values(ModePriority);
                      
 -- play  on time tasks
update PlaySessionTime
                 left join PlaySessions on PlaySessionTime.SessionID = PlaySessions.SessionID
                 set PlaySessionTime.TempFlag = sp_session_start(PlaySessions.SessionID, PlaySessionTime.ScheduleID, 
                                                                 PlaySessionTime.TempFlag,
                                                                 PlaySessions.StreamType, PlaySessions.BrdMode, 
                                                                 PlaySessions.MemberMode, 
                                                                 PlaySessions.SysEnabled, 
                                                                 PlaySessions.RfDevCtrl)
  where ((PlaySessions.BrdMode > 0) or (PlaySessions.Owner != 0) or (active_template = PlaySessions.Template)) and
        ( func_check_session_daytime(PlaySessions.BrdMode, PlaySessionTime. WeekDay, 
                                     PlaySessionTime.PlayTime, last_time, cur_time)  = true);

delete from PlaySessionTime where TempFlag = 127;
 
 -- delete expired alterdate entries
delete from AlternateDate where date(cur_time) > SpecialDate;

update PlaySessions, PlayerStatus, PlayerAlive set PlayerStatus.SessionID = 0
where (PlaySessions.PlayerID = PlayerAlive.PlayerID) 
    and (PlayerStatus.SessionID = PlaySessions.SessionID)
    and (PlaySessions.SessionType = 10)
    and timestampdiff(second, PlayerAlive.RefreshTime, cur_time) > 10;
-- deleted offline Players
delete PlayerStatus,  PlayerAlive from PlayerStatus,  PlayerAlive
where (PlayerStatus.PlayerID = PlayerAlive.PlayerID) and  
             timestampdiff(second, PlayerAlive.RefreshTime, cur_time) > 10;

-- delete unused automatical tasks
if (to_days(last_time) <> to_days(cur_time)) then
	delete PlaySessions from PlaySessions 
			where (SessionType = 0 or SessionType = 8) and 
               (not exists (select ScheduleID from PlaySessionTime where SessionID = PlaySessions.SessionID)) and
               (not exists (select PlayerID from PlayingSessions where SessionID = PlaySessions.SessionID) );
end if;
      
insert into LastProcessedTime(LastTimeID, LastTime) values (1, cur_time) 
              on duplicate key update LastTime = values(LastTime);

-- call sp_session_clean_up();

end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_update_dev_session
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_update_dev_session`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_update_dev_session`(dev_id varchar(50))
begin
 declare modeid int default 0; 
 declare modepriority int default null;
 declare sessionid smallint unsigned default null;
 declare sessionport int default 0; 
 declare sessiontype tinyint default 0; 
 declare streamType tinyint unsigned default 1; 
 declare valid boolean default false; 

 -- lock tables DeviceDesiredStaus write;
 
 select DeviceDesiredStaus.SessionValid,  DeviceDesiredStaus.BrdMode, BroadcastMode.Priority
               into valid, modeid,  modepriority from DeviceDesiredStaus 
               left join BroadcastMode on BroadcastMode.idBroadcastMode = DeviceDesiredStaus.BrdMode
               where DeviceID = dev_id;
   
  if  not (valid=true) then
                
       select SessionList.SessionID,  SessionList.MultiPort , SessionList.SesType,SessionList.StreamType
                 into  sessionid, sessionport , sessiontype, streamType from 
                       (select PlaySessions.SessionID,  PlaySessions.Priority,  PlayingSessions.PlayerID,  
                                        PlayingSessions.MultiPort , PlaySessions.BrdMode, PlaySessions.MemberMode, 
                                        PlayingSessions.SesType, PlayingSessions.StreamType
                                  from PlayingSessions 
                                  left join PlaySessions on PlayingSessions.SessionID = PlaySessions.SessionID 
                                  where   (func_check_dev_stream(dev_id,PlayingSessions.StreamType) = true) and
                                                   (((modeid = 0 or modeid is null ) and (PlaySessions.MemberMode = false) )
                                                               or (PlaySessions.Priority < modepriority) or (PlaySessions.BrdMode = modeid))) 
                                as SessionList                   
               left join SessionDevice on (SessionDevice.DeviceID = dev_id) and 
                                                                      (SessionDevice.SessionID = SessionList.SessionID) and
                                                                      (not DevDisabled = 1)
               left join  PlayerKeys on PlayerKeys.PlayerID = SessionList.PlayerID  and PlayerKeys.GroupDisable = 0                                                    
               where
                            (SessionDevice.DeviceID  is not null) or (SessionList.BrdMode = modeid and  SessionList.MemberMode = true) or
                             (PlayerKeys.GroupID is not null and sp_dev_belong_group(dev_id , PlayerKeys.GroupID))  
                      order by SessionList.Priority, SessionList.SessionID LIMIT 1;
                      
      insert into DeviceDesiredStaus (DeviceID, SessionID, BrdPort,  SessionType, StreamType, SessionValid)
              values(dev_id, sessionid, sessionport,  sessiontype, streamType, true)
              on duplicate key update                       
                  SessionID = values(SessionID), BrdPort = values(BrdPort), 
                  SessionType=values(SessionType),
                  StreamType = values(StreamType),  SessionValid = values(SessionValid);
              
 end if;
 
 -- unlock tables ;
 
select a.SessionID, a.BrdPort, a.SessionType, a.StreamType, a.SysEnabled, b.NetworkID , a.RfDevCtrl, c.SessionName, a.IpCall, a.IpCallPort
                 from DeviceDesiredStaus as a 
                     left join DeviceStatus b on a.DeviceID=b.DeviceID 
                     left join PlaySessions c on a.SessionID= c.SessionID
                          where a.DeviceID = dev_id;
  
end$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_fetch_playing_file
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_fetch_playing_file`;

DELIMITER $$
USE `nccs`$$
create  procedure `sp_fetch_playing_file`(
    sesid smallint,
    file_seq int,
    remained_time int)
begin
	declare random tinyint default 0;
	declare maxid int default 0;

    select PlayMode into random from PlaySessions where  SessionID = sesid;

	if (random > 0) then
		if (remained_time <> 0) then            
           select max(b.SequenceID) into maxid from PlayListFiles b
				   left join MediaFiles c on b.FileID = c.MediaID 
					where b.SessionID = sesid and c.TotalTime > 0;
		   set maxid = round( rand() * maxid);
		   select b.FileID, b.Duration,b.SequenceID, c.Gain, c.FilePath, @@datadir, c.FileName    
                   from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID 
		               where  (b.SessionID = sesid) and (b.SequenceID >= maxid) and (c.TotalTime > 0)
                   order by SequenceID limit 0, 1;
		else
			if (file_seq = 0) then
			    select max(SequenceID) into maxid from PlayListFiles where SessionID = sesid;
			    set maxid = round( rand() * maxid);
			    select b.FileID, b.Duration,1, c.Gain, c.FilePath, @@datadir, c.FileName    
                   from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID 
		           where  (b.SessionID = sesid) and (b.SequenceID >= maxid) order by SequenceID limit 0, 1;
			else
                select null; 
            end if;
		  end if;
    else 
        select b.FileID, b.Duration,b.SequenceID, c.Gain, c.FilePath, @@datadir , c.FileName   
               from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID 
		       where  (b.SessionID = sesid) and (b.SequenceID >= file_seq) order by SequenceID limit 0, 1;
    end if;
	 
    

END$$
DELIMITER ;

-- -----------------------------------------------------
-- funcion func_IcCard_Auhorize
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `func_IcCard_Authorize`;
DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_IcCard_Authorize`(
          IcCard varchar(50),
          DeviceID varchar(50)
         ) RETURNS int(11)
BEGIN
    declare uid int default null; -- Users ID
    declare tt int default null; -- TimeTable featurn enable flag
    declare udid int default null; -- UserDevice ID
    declare tid int default null;  -- table id: UserDevices ID or Timetable ID
    declare nowday INT default null; -- day of week
    declare card varchar(10) default null; -- 十位前导零补齐卡号
    declare cardHex varchar(10) default null; -- 16进制大小端转换卡号(字符串)
    declare cardSwitch varchar(10) default null; -- 十位大小端转换卡号，前导零补齐

    set card = LPAD(ltrim(rtrim(IcCard)), 10, 0);
    set cardHex = LPAD(conv(IcCard,10, 16), 8, 0);
    set cardHex = concat(substring(cardHex, 7,2), substring(cardHex, 5, 2), substring(cardHex, 3, 2), substring(cardHex, 1, 2));
    set cardSwitch = LPAD(conv(cardHex, 16, 10), 10, 0);

    -- check Users and get userid
    select User_ID, Dev_Privilege into uid, @dpri from Users
                    where ( LPAD(ltrim(rtrim(Users.IcCard)), 10, 0) = card or
                            LPAD(ltrim(rtrim(Users.IcCard)), 10, 0) = cardSwitch
                          ) and
                          Users.IC_Status=0 and 
                          (Users.User_Expiry is null or 
                           Users.User_Expiry > date_sub(now(), interval 1 day));
    if(uid is null )then
        return null;
    elseif(uid=0) or (@dpri=1)then
        return uid;
    end if;
    
    select a.UserDevID into udid from UserDevices a
				  left join Users b on b.User_ID = uid
                  where a.UserID = uid and
                        a.DevID = DeviceID and
                        a.Pri&1=1 and
                        (
							(
								b.User_Type=3 and 
								(
									b.User_Expiry is null or 
									ADDDATE(DATE(b.User_Expiry), 1) > DATE(now())
                                )
							) or
							b.User_Type <3
						)
				   LIMIT 1;
	
	-- check UserDevices
    if(udid is not null) then
		return uid;
    end if;
    
    select InfoValue into tt from BaseInfo where InfomationID=280;
    if(tt is null) or (tt <= 0) then
		return null;
    end if;
    
    select AlteredScheduleDay into nowday from AlternateDate where `SpecialDate` = DATE(now());
    if(nowday is null) then
 		set nowday = WEEKDAY(now());
 	end if;
	
    -- check Timetable
    select `Id` into tid from Timetable 
					where 	`UserID` = uid and
							`DevId` = DeviceID and
                            (
                                `OneTime` = 0 and
                                `WeekDay` = nowday and
                                time(now()) > subtime(time(`Start`), '00:30:00') and
                                time(now()) < time(`End`)
                            ) or
                            (
                                `OneTime` = 1 and
                                now() > subtime(`Start`, '00:30:00') and
                                now() < `End`
                            )
					limit 1;
		
	if (tid is not null) then
        return uid;
	end if;
    return null;    
END$$
DELIMITER ;



-- -----------------------------------------------------
-- function func_dulicate_device
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_dulicate_device`;

DELIMITER $$
USE `nccs`$$
CREATE function func_dulicate_device (
    SrcDevice varchar(50),
	DstDevice varchar(50),
    mask tinyint unsigned) returns integer
BEGIN
    declare base_cfg varchar(704) default null;
	declare name_cfg varchar(256) default null;
    declare cfg varchar(960) default null;
    declare ret int default null;

    -- mask bit0: whether copy device configuration
    if ((mask & 0x01) <> 0) then  
       select SUBSTRING(hex(Dev_configuration), 257, 704) into base_cfg from DeviceList where DevID = SrcDevice; 
     
	   -- mask bit 1: whether copy device name and description
	   if ((mask & 0x02) <> 0) then
		   select SUBSTRING(hex(Dev_configuration), 1, 256) into name_cfg from DeviceList where DevID = SrcDevice; 
       else
           select SUBSTRING(hex(Dev_configuration), 1, 256) into name_cfg from DeviceList where DevID = DstDevice; 
	   end if;

       if (base_cfg is null) or (name_cfg is null) then
	       return 0;
	   end if;

       set cfg = CONCAT(name_cfg, base_cfg);
       /*send device config command*/
	   select device_config(IpAddress, DeviceID,  cfg) into ret from DeviceStatus where DeviceID = DstDevice;

       if not (ret = 497) then
          return 0;
       end if;
    end if;

    if ((mask & 0x08) <> 0) then
        update DeviceList set Parent = (select Parent from (select * from DeviceList) as tmp_table 
										where DevID = SrcDevice) where DevID = DstDevice;
    end if;

	-- copy device tasks data
    if ((mask & 0x04) <> 0) then
		delete from SessionDevice where DeviceID = DstDevice;
        insert into SessionDevice(DeviceID, SessionID, KeyIndex, DevDisabled) 
               select DstDevice, SessionID, KeyIndex, DevDisabled from SessionDevice where DeviceID = SrcDevice;
        
		delete from BrdModeMember where DeviceID = DstDevice;
        insert into BrdModeMember(BrdModeID, DeviceID) 
               select BrdModeID, DstDevice from BrdModeMember where DeviceID = SrcDevice;

        delete from DevCtrlSchedule where DevID = DstDevice;
        insert into DevCtrlSchedule(DevID,ActionTime,`Action`,WeekDay,State,ExtArgs,`Disable`)
               select DstDevice,ActionTime,`Action`,WeekDay,State,ExtArgs,`Disable` from DevCtrlSchedule where DevID = SrcDevice; 
               
        insert into Timetable(DevId, UserId, WeekDay, Start, End, Type)
            select DstDevice, UserId, WeekDay, Start, End, Type from Timetable where DevId = SrcDevice;
    end if;
    
    -- copy device privilege
    if ((mask & 0x10) <> 0) then
        delete from UserDevices where DevID = DstDevice;
        insert into UserDevices(UserID, DevID, Pri) 
            select UserID, DstDevice, Pri from UserDevices where DevID = SrcDevice and Pri!=0;
        -- update Timetable
        insert into Timetable(UserId, DevId, WeekDay, Start, End) 
        select `UserId`,DstDevice,`WeekDay`,`Start`,`End` from Timetable where DevId=SrcDevice;
    end if;

    -- delete source device
    if ((mask & 0x80) <> 0) then
        delete from UserDevices where DevID = SrcDevice;
        delete from DevCtrlSchedule where DevID = SrcDevice;
        delete from SessionDevice where DeviceID = SrcDevice;
        delete from BrdModeMember where DeviceID = SrcDevice;
        delete from DeviceList where DevID = SrcDevice;
    end if;
    return 1;
END$$

DELIMITER ;

-- -----------------------------------------------------
-- function func_get_mediafile_Owner
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_get_mediafile_Owner`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_get_mediafile_Owner`(mediaID int) RETURNS int
BEGIN
	declare medid int default null;
	declare pid int default null;
	declare own int default null;
	declare foldflag tinyint default null;

	select mediafile.Parent,mediafile.`Owner`,mediafile.Sysfolder,mediafile.MediaID into pid,own,foldflag,medid from MediaFiles mediafile where mediafile.MediaID = mediaID limit 1;
	if(medid is null) then
		set own = -1;
		return own;
	else
		if((foldflag is not null) and (foldflag = 1)) then
			if(own is null) then
				set own = 0;
			end if;
			return own;
		else
			while((pid is not null) and (pid <> 0)) do
				select mediafile.Parent,mediafile.`Owner`,mediafile.Sysfolder into pid,own,foldflag from MediaFiles mediafile where mediafile.MediaID = pid limit 1;
				
				if((foldflag is not null) and (foldflag = 1)) then
					if(own is null) then
						set own = 0;
					end if;
					return own;
				end if;

			end while;

		end if;
		set own = 0;
		return own;
	end if;
	
END$$

DELIMITER ;

USE `nccs`;
DROP function IF EXISTS `func_check_task_privilege`;

DELIMITER $$
USE `nccs`$$
CREATE FUNCTION `func_check_task_privilege` (
                 user int, 
                 StreamType tinyint,
                 SysEnabled tinyint, 
                 RfDevCtrl BINARY(16))
RETURNS BOOLEAN
BEGIN
	declare Priv int default null;

    if (user is null or user = 0) then
		return true;
    end if;

	select privilege into Priv from Users where User_ID = user;

	if Priv is null then
		return false;
  end if;

	if ((Priv & 0x01) = 0) and (SysEnabled is not null) then         
		return false;
  end if;

	if ((Priv & 0x100) = 0) and (StreamType <> 0) then
		return false;
  end if;
        
  if ((Priv & 0x10000) = 0)  and (RfDevCtrl is not null) and (RfDevCtrl <> 0x00000000000000000000000000000000) then 
		return false;
  end if;

	return true;
END$$

DELIMITER ;



-- -----------------------------------------------------
-- procedure sp_copy_template
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `sp_copy_template`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_copy_template`(
    old_template int
    )
begin
declare new_template int default null;

declare old_session smallint default null;
declare new_session smallint default null;

declare task_cur cursor for select  SessionID  from PlaySessions 
        where (Template = old_template) and ((BrdMode is null) or (BrdMode = 0)) and ((SessionType = 0) or (SessionType = 8));   
declare continue handler for sqlstate '02000' set old_session = null;

  
  insert into TaskTemplate(TemplateName, Enabled)  
           (select concat(TemplateName, " copy"), 0 from TaskTemplate where idTaskTemplate = old_template) ;
   
   set new_template = last_insert_id();
   
   if (new_template is not null) then

      open  task_cur;  
      fetch task_cur into old_session;  
         
      while ( old_session is not null) do
            set new_session = get_idle_sessionid(false);
             insert into PlaySessions(SessionID,SessionName,SessionType,Priority,`Status`,CircleLength,ClassID,PlayerID,Parent,BrdMode,
                                      MemberMode,StreamType,SysEnabled,RfDevCtrl, `Owner`, PlayMode, AudioGain, Template)
                                   (select new_session,SessionName,SessionType,Priority,`Status`,CircleLength,ClassID,PlayerID,Parent,BrdMode,
                                           MemberMode,StreamType,SysEnabled, RfDevCtrl, `Owner`, PlayMode, AudioGain, new_template
                                           from PlaySessions where SessionID = old_session);
            
            insert into PlaySessionTime(SessionID,WeekDay,PlayTime,TempFlag) 
                          (select new_session,WeekDay,PlayTime,TempFlag from PlaySessionTime where SessionID = old_session);
            
            insert into PlayListFiles(FileID,SequenceID,SessionID,Duration,KeyIndex,PlayerID) 
                          (select FileID,SequenceID,new_session,Duration,KeyIndex,PlayerID from PlayListFiles where SessionID = old_session);
                          
             insert into SessionDevice(DeviceID,SessionID,KeyIndex,DevDisabled)
                           (select  DeviceID,new_session,KeyIndex,DevDisabled from  SessionDevice where SessionID = old_session);
             
             fetch task_cur into old_session;  

      end while;
      close task_cur;
   end if;
end$$

DELIMITER ;



-- -----------------------------------------------------
-- View `nccs`.`v_DeviceModes`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_DeviceModes` ;
DROP TABLE IF EXISTS `nccs`.`v_DeviceModes`;
USE `nccs`;
CREATE 
     OR REPLACE ALGORITHM = UNDEFINED 
    DEFINER = `root`@`%` 
    SQL SECURITY DEFINER
VIEW `nccs`.`v_DeviceModes` AS
    select 
        `a`.`DevID` AS `DeviceID`,
        `b`.`BrdModeID` AS `BrdModeID`,
        `b`.`Priority` AS `Priority`
    from
        ((`nccs`.`DeviceList` `a`
        left join `nccs`.`v_active_mode_members` `b` ON ((`b`.`DeviceID` = `a`.`DevID`)))
        left join `nccs`.`v_active_mode_members` `c` ON (((`c`.`DeviceID` = `a`.`DevID`)
            and (`c`.`Priority` < `b`.`Priority`))))
    where
        isnull(`c`.`Priority`);

-- -----------------------------------------------------
-- View `nccs`.`v_Session_Files`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_Session_Files` ;
DROP TABLE IF EXISTS `nccs`.`v_Session_Files`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY 
DEFINER VIEW `nccs`.`v_Session_Files` AS 
select `a`.`SessionID` AS `SessionID`,`b`.`FileID` AS `FileID`,`b`.`SequenceID` AS `SequenceID`,
        `c`.`FileName` AS `FileName`,`c`.`TotalTime` AS `TotalTime`,`b`.`Duration` AS `PlayTime`,
        `c`.`Gain` AS `Gain`,`c`.`FileFmt` AS `FileFmt`,`c`.`FilePath` AS `FilePath` 
from ((`nccs`.`PlaySessions` `a` left join `nccs`.`PlayListFiles` `b` on((`a`.`SessionID` = `b`.`SessionID`))) 
left join `nccs`.`MediaFiles` `c` on((`b`.`FileID` = `c`.`MediaID`))) where (`b`.`FileID` is not null);

-- -----------------------------------------------------
-- View `nccs`.`v_active_mode_members`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_active_mode_members` ;
DROP TABLE IF EXISTS `nccs`.`v_active_mode_members`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_active_mode_members` AS select `nccs`.`BrdModeMember`.`DeviceID` AS `DeviceID`,`nccs`.`BroadcastMode`.`idBroadcastMode` AS `BrdModeID`,`nccs`.`BroadcastMode`.`Priority` AS `Priority` from (`nccs`.`BroadcastMode` left join `nccs`.`BrdModeMember` on((`nccs`.`BroadcastMode`.`idBroadcastMode` = `nccs`.`BrdModeMember`.`BrdModeID`))) where (`nccs`.`BroadcastMode`.`Active` = 1);

-- -----------------------------------------------------
-- View `nccs`.`v_session_info`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_session_info` ;
DROP TABLE IF EXISTS `nccs`.`v_session_info`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_session_info` AS select `nccs`.`PlaySessions`.`SessionID` AS `SessionID`,`nccs`.`PlaySessions`.`SessionName` AS `SessionName`,`nccs`.`PlaySessions`.`SessionType` AS `SessionType`,`nccs`.`PlaySessions`.`Priority` AS `Priority`,`nccs`.`PlaySessions`.`Status` AS `Status`,`nccs`.`PlaySessions`.`CircleLength` AS `CircleLength`,`nccs`.`PlaySessions`.`ClassID` AS `ClassID`,`nccs`.`PlaySessions`.`PlayerID` AS `PlayerID`,`nccs`.`PlaySessions`.`Parent` AS `Parent`,`nccs`.`PlayingSessions`.`PlayingFileID` AS `PlayingFileID`,`nccs`.`PlayingSessions`.`MultiPort` AS `MultiPort`,`nccs`.`PlayingSessions`.`CurrFileProgress` AS `CurrFileProgress`,`nccs`.`PlayingSessions`.`CurrTotalProgress` AS `CurrTotalProgress`,`nccs`.`PlayingSessions`.`Pause` AS `Pause`,`nccs`.`PlayingSessions`.`ScheduleID` AS `ScheduleID`,`nccs`.`PlaySessions`.`MemberMode` AS `MemberMode` from (`nccs`.`PlaySessions` left join `nccs`.`PlayingSessions` on((`nccs`.`PlayingSessions`.`SessionID` = `nccs`.`PlaySessions`.`SessionID`)));

-- -----------------------------------------------------
-- View `nccs`.`v_session_schedules`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_session_schedules` ;
DROP TABLE IF EXISTS `nccs`.`v_session_schedules`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_session_schedules` AS select `a`.`ScheduleID` AS `ScheduleID`,`a`.`TempFlag` AS `TempFlag`,`a`.`PlayTime` AS `PlayTime`,`a`.`WeekDay` AS `WeekDay`,`b`.`SessionID` AS `SessionID`,`b`.`SessionName` AS `SessionName`,`c`.`Pause` AS `Pause`,`b`.`BrdMode` AS `BrdMode`,`b`.`SessionType` AS `SessionType`,`b`.`SysEnabled` AS `SysEnabled`,`b`.`RfDevCtrl` AS `RfDevCtrl`,`b`.`StreamType` AS `StreamType` from ((`nccs`.`PlaySessionTime` `a` left join `nccs`.`PlaySessions` `b` on((`a`.`SessionID` = `b`.`SessionID`))) left join `nccs`.`PlayingSessions` `c` on((`a`.`ScheduleID` = `c`.`ScheduleID`)));

-- -----------------------------------------------------
-- View `nccs`.`v_stream_trans_table`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_stream_trans_table` ;
DROP TABLE IF EXISTS `nccs`.`v_stream_trans_table`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_stream_trans_table` AS select `a`.`NetworkID` AS `NetworkID`,`a`.`IpAddress` AS `proxy`,`b`.`IpAddress` AS `IpAddress`,`c`.`MultiPort` AS `MultiPort`,`c`.`SessionID` AS `SessionID` from ((`nccs`.`DeviceStatus` `a` left join `nccs`.`SubNetwork` `b` on((`b`.`idSubNetwork` = `a`.`NetworkID`))) left join `nccs`.`PlayingSessions` `c` on((`c`.`SessionID` = `a`.`ActualSessionID`))) where (`a`.`ActualSessionID` > 0) group by `c`.`SessionID`,`a`.`NetworkID`;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
USE `nccs`;

DELIMITER $$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_brdmode_delete`
BEFORE DELETE ON `nccs`.`BroadcastMode`
FOR EACH ROW
begin
     delete from PlaySessions  where BrdMode = old.idBroadcastMode;
     delete from BrdModeMember where BrdModeID = old.idBroadcastMode;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_brdmode_update`
AFTER UPDATE ON `nccs`.`BroadcastMode`
FOR EACH ROW
begin
                                  
    if  not (new.Priority = old.Priority) then
        update PlaySessions set Priority =  new.Priority where BrdMode = old.idBroadcastMode  and  (PlaySessions.Priority > new.Priority);
    end if;
    insert into Messages Values (0, 1, 2, 12, now(), null, new.idBroadcastMode, null, null);   
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_update1` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_brdmode_update1`
BEFORE UPDATE ON `nccs`.`BroadcastMode`
FOR EACH ROW
begin
    if (new.Enabled = false) then
            set new.Active = false;
      end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_devclasses_delete`
BEFORE DELETE ON `nccs`.`DevClasses`
FOR EACH ROW
begin
     delete from GroupCtrlSchedule where GroupID = old.ClassID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_devclasses_insert`
BEFORE INSERT ON `nccs`.`DevClasses`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent  into parentid from  DevClasses where ClassID = parentid;
      set count = count + 1;
     end while;
     
     if (count >= 5) then 
     insert DevClasses values(0,' ',0);
     end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_devclasses_update`
AFTER UPDATE ON `nccs`.`DevClasses`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent  into parentid from  DevClasses where ClassID = parentid;
      set count = count + 1;
     end while;
     
     if (count >= 5) then 
     insert DevClasses values(0,' ',0);
     end if;
     
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devicelist_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_devicelist_delete`
BEFORE DELETE ON `nccs`.`DeviceList`
FOR EACH ROW
begin
     delete from DevCtrlSchedule where DevID = old.DevID;
     delete from DeviceDesiredStaus where DeviceID =  old.DevID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceList_AUPD` $$
USE `nccs`$$
CREATE TRIGGER `DeviceList_AUPD` 
AFTER UPDATE ON `DeviceList` FOR EACH ROW

begin
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.DevID, NULL);  
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  
               where  DeviceDesiredStaus.DeviceID = new.DevID;
end
$$

USE `nccs`;
DROP TRIGGER IF EXISTS nccs.tr_DeviceDesiredStaus_after_insert$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`tr_DeviceDesiredStaus_after_insert`
AFTER INSERT ON `nccs`.`DeviceDesiredStaus`
FOR EACH ROW
BEGIN
    select send_msg_to_srv(161, new.DeviceID) into @ret;
END$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_DeviceDesiredStaus_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_DeviceDesiredStaus_update`
BEFORE UPDATE ON `nccs`.`DeviceDesiredStaus`
FOR EACH ROW
begin
    if  (new. BrdMode is null and old.BrdMode is not null) or
         (new. BrdMode is not null and old.BrdMode is null) or
         (new. BrdMode != old.BrdMode) or 
         (new. ModePriority != old.ModePriority) then
        set new.SessionValid = false;
     end if;   
    -- ip call state check
    if(old.IpCall <> new.IpCall) and (new.IpCall <> 0) then
        set new.IpCallEvent = now();
    end if;
end$$


USE `nccs`;
DROP TRIGGER IF EXISTS nccs.tr_dev_changed1$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`tr_dev_changed1`
AFTER UPDATE ON `nccs`.`DeviceStatus`
FOR EACH ROW
begin

	insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.DeviceID, NULL);
	if (old.State_SysPower <> new.State_SysPower) then
		if (new.State_SysPower = 2) then -- disable
			update DeviceLog set EndTime=now() where DeviceID=new.DeviceID and Event=3 order by DevLogID desc limit 1;
            if(old.State_SysPower=1) then -- power on => disable
				update DeviceLog set EndTime=now() where DeviceID=new.DeviceID and Event=2 order by DevLogID desc limit 1;
            end if;
			-- insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `State`)  Values (new.DeviceID, now(), 3, 0);
		else
			if (old.State_SysPower = 2) then   -- disable => power off
				insert into DeviceLog(`DeviceID`, `DateTime`, `Event`)  Values (new.DeviceID, now(), 3);
			else
				if(new.State_SysPower = 0) then -- power on =>  power off
					update DeviceLog set EndTime=now() where DeviceID=new.DeviceID and Event=2 order by DevLogID desc limit 1;
				else  -- power off => power on
					insert into DeviceLog(`DeviceID`, `DateTime`, `Event`, `CtrlUser`)
						 Values (new.DeviceID, now(), 2, new.User_ID);
				end if;
			end if;
         end if;
        -- switch user name
      elseif (new.State_SysPower=1) and (new.User_ID is not null) then
            if(old.User_ID is null)  then
                update DeviceLog set CtrlUser=new.User_ID where DeviceID=new.DeviceID and Event=2 order by DevLogID desc limit 1;
            elseif(old.User_ID <> new.User_ID) then
              update DeviceLog set EndTime=now() where DeviceID=new.DeviceID and Event=2 order by DevLogID desc limit 1;
              insert into DeviceLog(`DeviceID`,`DateTime`,`Event`,`CtrlUser`)
                  Values (new.DeviceID, now(), 2, new.User_ID);
            end if;
      end if;

      if (old.State_ProjectorStatus <> new.State_ProjectorStatus) then
            if(new.State_ProjectorStatus = 1) then
                insert into DeviceLog(`DeviceID`, `DateTime`, `Event`)  Values (new.DeviceID, now(), 4);
            elseif(new.State_ProjectorStatus = 0) then
			    update DeviceLog set EndTime=now() where DeviceID=new.DeviceID and Event=4 order by DevLogID desc limit 1;
            end if;
      end if;
end$$


USE `nccs`;
DROP TRIGGER IF EXISTS nccs.tr_dev_del$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`tr_dev_del`
AFTER DELETE ON `nccs`.`DeviceStatus`
FOR EACH ROW
begin
    declare logID int default null;
	-- delete from tmp_devcice_session  where tmp_devcice_session.DeviceID = old.DeviceID;
    update IpCall set status='idle' where device = old.DeviceID;
    update DeviceDesiredStaus set SessionValid = false, IpCall = 0 where DeviceDesiredStaus.DeviceID = old.DeviceID;
	INSERT INTO Messages Values (0, 1, 2, 3, now(), 0, 0, old.DeviceID, NULL);

	update DeviceLog set EndTime=now() where DeviceID=old.DeviceID and Event=1 order by DevLogID desc limit 1;
end$$


USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.tr_devstatus_before_update$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`tr_devstatus_before_update`
BEFORE UPDATE ON `DeviceStatus` 
FOR EACH ROW
BEGIN
    declare uid int default null;
    declare ret int default null;

    if(new.State_SysPower<>1) and (old.State_SysPower = 1) then
		set new.User_ID=null;
	end if;
    if(new.SysPowerCmd is not null) and (new.State_SysPower <> 2)then
        select sp_send_dev_ctrl_function(NULL, new.DeviceID, new.IpAddress, 48, new.SysPowerCmd, 0, 0, NULL) into ret ;
        set new.SysPowerCmd = NULL;
    end if;
    if (new.RfDevCmd is not null) and (new.RfDevStatus is not null) and (new.IpAddress is not null) then
        set @rfCmd = update_rf_cmd(new.DeviceID, new.IpAddress, new.RfDevStatus, new.RfDevCmd);
        if( @rfCmd is null) or (length(@rfCmd) = 0) then
             set new.RfDevCmd = null;
        else
             set new.RfDevCmd = @rfCmd;
        end if;
    end if;
END$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_instert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_dev_instert`
AFTER INSERT ON `nccs`.`DeviceStatus`
FOR EACH ROW
begin
     -- INSERT INTO Messages Values(0, 1, 1, 1, now(), 55, 0, new.DeviceID, new.IpAddress);
     -- get config for inserting
     call sp_send_dev_ctrl_cmd(new.DeviceID, new.IpAddress, 55, 0, 0, 0, null);
     call sp_send_dev_ctrl_cmd(new.DeviceID, new.IpAddress, 56, 0, 0, 0, null);

     insert into DeviceLog(`DeviceID`, `DateTime`, `Event`)  Values (new.DeviceID, now(), 1);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_player_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_player_delete`
BEFORE DELETE ON `nccs`.`Players`
FOR EACH ROW
begin
-- delete from PlaySessionGroups where PlayerID = old.PlayerID;
-- delete from PlayGroups where PlayerID = old.PlayerID;
delete from PlayerKeys where PlayerID = old.PlayerID;
-- delete from PlayGroupDevices where PlayerID = old.PlayerID;
delete from PlaySessions where PlayerID = old.PlayerID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_player_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_player_insert`
AFTER INSERT ON `nccs`.`Players`
FOR EACH ROW
begin
    if (new.PlayerType = 10) then
	    insert into   PlaySessions(SessionID, SessionType, PlayerID, Priority, SessionName, StreamType)
            values (get_idle_sessionid(false), new.PlayerType, new.PlayerID, new.Priority, new.PlayerID, 3);
    elseif ((new.PlayerType <> 0) and (new.PlayerType <> 8)) then
	    insert into   PlaySessions(SessionID, SessionType, PlayerID, Priority, SessionName)
            values (get_idle_sessionid(false), new.PlayerType, new.PlayerID, new.Priority, new.PlayerID);
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_delete`
BEFORE DELETE ON `nccs`.`Users`
FOR EACH ROW
begin
	declare tmp_mediaid int default 0;
	
	select MediaID into tmp_mediaid from MediaFiles where `Owner` = Old.User_ID and Sysfolder = 1;
	if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
		set max_sp_recursion_depth=10;
		call sp_del_media_file(Old.User_ID,tmp_mediaid); 
	end if;

        delete from UserDevices where UserID = old.User_ID;
        -- delete from Players where PlayerID = old.UsbKey;
		delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and PlaySessionTime. SessionID = PlaySessions.SessionID;
	delete from PlaySessions where Owner = old.User_ID;
	delete from MediaFiles where Owner = Old.User_ID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_insert` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`tr_user_insert`
AFTER INSERT ON `nccs`.`Users`
FOR EACH ROW
begin
	declare tmp_mediaid int default 0;

    if (new.UsbKey is not null) then 
        /*after player insterted, a session will be created*/
        -- insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority) ;
		update PlaySessions set Owner = new.User_ID, SessionType = 1 where (PlaySessions.PlayerID = new.UsbKey);
    end if;

	if ((new.Priority > 0) and (new.privilege & 0x100) <> 0 and (new.User_Name is not null))  then 
        -- have Broadcast privilege 
		
		select MediaID into tmp_mediaid from MediaFiles where Sysfolder=2;

		if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
				new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_mediaid,new.User_ID,1);
		else
			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Sysfolder) values(
				'用户文件',0,0,0,0,0,0,0,0,0,0,0,0,now(),2);

			select MediaID into tmp_mediaid from MediaFiles where Sysfolder=2;

			insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
				Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
				new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_mediaid,new.User_ID,1);
		end if;
		
	end if;

end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_insert_player` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_insert_player`
BEFORE INSERT ON `nccs`.`Users`
FOR EACH ROW
begin
    if (new.UsbKey is not null) then 
        /*after player insterted, a session will be created*/
        insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority) ;
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_update`
AFTER UPDATE ON `nccs`.`Users`
FOR EACH ROW
begin
	declare tmp_root_mediaid int default 0;
	declare tmp_mediaid int default 0;

    if ((new.UsbKey is not null) and (old.UsbKey is null)) or
       ((old.UsbKey is not null) and (new.UsbKey is null)) or 
       (old.UsbKey <> new.UsbKey) then 
        delete from Players where PlayerID = old.UsbKey;

       /*after player insterted, a session will be created*/
        if (new.UsbKey is not null) then 
            -- insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority);
			update PlaySessions set Owner = new.User_ID, SessionType = 1 where (PlaySessions.PlayerID = new.UsbKey);
        end if;

    end if;

    if (new.Priority <> old.Priority) then
        update PlaySessions set  Priority = new.Priority 
               where PlaySessions.Owner = new.User_ID;
    end if;

	if ((new.privilege & 0x01) = 0) then 
        -- Device control privilege has been removed
		delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and 
					 PlaySessionTime. SessionID = PlaySessions.SessionID and 
                     (SysEnabled is not null);
    end if;

	if ((new.privilege & 0x100) = 0)  then 
        -- Broadcast privilege has been removed
        delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and 
					 PlaySessionTime. SessionID = PlaySessions.SessionID and 
                     (PlaySessions.StreamType <> 0);

		-- del MediaFiles user root folder
		select MediaID into tmp_mediaid from MediaFiles where `Owner` = new.User_ID and Sysfolder = 1;
		if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
			set max_sp_recursion_depth=10;
			call sp_del_media_file(new.User_ID,tmp_mediaid); 
		end if;
	else
		if(new.Priority > 0) then
			-- have Broadcast privilege
			select MediaID into tmp_root_mediaid from MediaFiles where Sysfolder = 2;

			if((tmp_root_mediaid is not null) and tmp_root_mediaid <> 0) then

				select MediaID into tmp_mediaid from MediaFiles where `Owner` = new.User_ID and Sysfolder = 1;
				
				if((tmp_mediaid is not null) and tmp_mediaid <> 0) then
					if(new.User_Desc <> Old.User_Desc) then
						update MediaFiles set FileName=new.User_Desc where MediaID = tmp_mediaid;
					end if;
				else
					insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
						Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
						new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_root_mediaid,new.User_ID,1);
				end if;
				
			else
				insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
					Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Sysfolder) values(
					'用户文件',0,0,0,0,0,0,0,0,0,0,0,0,now(),2);

				select MediaID into tmp_root_mediaid from MediaFiles where Sysfolder = 2;

				insert into MediaFiles(FileName,FileSize,TotalTime,FileFmt,BitRate,VedioCodec,
					Height,Width,FrameRate,AudioCodec,Channels,SampleRate,Gain,CreateTime,Parent,`Owner`,Sysfolder) values(
					new.User_Desc,0,0,0,0,0,0,0,0,0,0,0,0,now(),tmp_root_mediaid,new.User_ID,1);
			end if;
		end if;
    end if;

	if ((new.privilege & 0x10000) = 0)  then 
        -- wireless device control privilege has been removed
        delete PlaySessionTime from PlaySessionTime, PlaySessions  
               where PlaySessions.Owner = old.User_ID and 
					 PlaySessionTime. SessionID = PlaySessions.SessionID and 
                     (RfDevCtrl is not null) and (RfDevCtrl <> 0x00000000000000000000000000000000);
    end if;

    if (((new.IcCard is not null) and (old.IcCard is null)) or
       ((new.IcCard is null) and (old.IcCard is not null)) or
       (old.IcCard <> new.IcCard)) then 
           update UserDevices set UserID = new.User_ID where UserID = new.User_ID;
    end if;
    if(new.Dev_Privilege = 1) and (old.Dev_Privilege <> 1) then
        update UserDevices set Pri = Pri & 0xfe where UserID=new.User_ID;
        delete from UserDevices where Pri = 0;
    end if;

    if(new.Mgr_Privilege = 1) and (old.Mgr_Privilege <> 1) then
        update UserDevices set Pri = Pri & 0xfd where UserID=new.User_ID;
        delete from UserDevices where Pri = 0;
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_update_player` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_update_player`
BEFORE UPDATE ON `nccs`.`Users`
FOR EACH ROW
begin
    if ((new.UsbKey is not null) and (old.UsbKey is null)) or
       (old.UsbKey <> new.UsbKey) then 
	    insert into Players(PlayerID, PlayerType, Priority ) values (new.UsbKey, 2, new.Priority);
    end if;
    
    if (old.ServerSync is null) or (old.ServerSync <> 1) then
        set new.ServerSync = 1; 
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_delete_player` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_user_delete_player`
AFTER DELETE ON `nccs`.`Users`
FOR EACH ROW
begin
    delete from Players where PlayerID = old.UsbKey;
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_session_delete`
BEFORE DELETE ON `nccs`.`PlaySessions`
FOR EACH ROW
begin
	 -- stop all sessions while the stoped task is playing
	 update PlayerStatus set SessionID = 0 where (SessionID = old.SessionID);
     -- delete from PlaySessionTime  where SessionID = old.SessionID;    
     if(old.SessionType=10) then
        delete PlayListFiles.*, MediaFiles.* from PlayListFiles,MediaFiles where
                PlayListFiles.FileID=MediaFiles.MediaID and
                PlayListFiles.SessionID=old.SessionID;
    else 
        delete from PlayListFiles where SessionID = old.SessionID;
    end if;
     delete from SessionDevice where SessionID = old.SessionID;
end$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_session_insert`
BEFORE INSERT ON `nccs`.`PlaySessions`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare Sestype int default 0;
     declare mode_priority int default null;
     declare templateId int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent , SessionType into parentid, Sestype from  PlaySessions where SessionID = parentid;
      if (Sestype = 127) then
            set count = count + 1;
        else
           set count =  5;
         end if;
         
     end while;
     
     if (count >= 5) then 
     insert PlaySessions(SessionID) values(0);
     end if;
     
     if (new.BrdMode > 0) then
		     select Priority into mode_priority from BroadcastMode where idBroadcastMode = new.BrdMode;
		     if (new.Priority > mode_priority) then
		         set new.Priority = mode_priority;
		     end if;
     end if;

     if (func_check_task_privilege(new.Owner, new.StreamType, new.SysEnabled, new.RfDevCtrl) = false) then
        insert PlaySessions(SessionID) values(0);
     end if;
    if (new.SessionType = 10) or (new.SessionType = 1) then
        set new.Template = null;
    -- if Template and Owner is null, set new.Template to current templateId 
    elseif (new.Template is null) and (new.Owner is null) then
        select InfoValue into templateId from BaseInfo where InfomationID=257;
        set new.Template = templateId;
    end if;

end$$

USE `nccs`;
DROP TRIGGER IF EXISTS nccs.tr_session_after_insert$$
USE `nccs`$$
CREATE 
DEFINER=`root`@`%` 
TRIGGER `nccs`.`tr_session_after_insert` 
AFTER INSERT ON `PlaySessions` 
FOR EACH ROW
begin
declare id int(11) default null;
if(new.SessionType=10) then
    INSERT INTO MediaFiles(FileName, FileSize, TotalTime, FileFmt, BitRate,
                            VedioCodec, Height, Width, FrameRate, 
                            AudioCodec, Channels,SampleRate, Parent, 
                            Gain, CreateTime, FilePath, Sysfolder)
                            values ( 
                            new.PlayerID, 0 , 10 , -1, 0,
                            -1, 0, 0, 0,
                            -1, 0, 0, null, 
                            0, now(), null, -1);

    select max(MediaID) into id from MediaFiles;
    if(id is not null) then
        insert into PlayListFiles(FileID, SequenceID, SessionID, Duration) values
                                (id, 0, new.sessionID, 0) on duplicate key update
                                FileID=VALUES(FileID), SequenceID=VALUES(SequenceID),
                                SessionID=VALUES(SessionID), Duration=VALUES(Duration);
    end if;
end if;
end$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_session_update`
BEFORE UPDATE ON `nccs`.`PlaySessions`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare Sestype int default 0;
     declare mode_priority int default null;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
        select Parent , SessionType into parentid, Sestype from  PlaySessions where SessionID = parentid;
         if (Sestype = 127) then
            set count = count + 1;
        else
           set count =  5;
         end if;
     end while;
     
     if (count >= 5) then 
         insert PlaySessions(SessionID) values(0);
     end if;
     
     if (func_check_task_privilege(new.Owner, new.StreamType, new.SysEnabled, new.RfDevCtrl) = false) then
        insert PlaySessions(SessionID) values(0);
     end if;

     if (new.BrdMode > 0) then
		     select Priority into mode_priority from BroadcastMode where idBroadcastMode = new.BrdMode;
		     if (new.Priority > mode_priority) then
		         set new.Priority = mode_priority;
		     end if;
     end if;
     
     
     if (new.Priority <> old.Priority) then
         update DeviceDesiredStaus, SessionDevice set  DeviceDesiredStaus.SessionValid = false 
                 where DeviceDesiredStaus.DeviceID = SessionDevice.DeviceID and
                                SessionDevice.SessionID = new.SessionID;
                                
          update DeviceDesiredStaus, PlayerKeys set  DeviceDesiredStaus.SessionValid = false 
                 where PlayerKeys.PlayerID = new.PlayerID and 
                                PlayerKeys.GroupDisable = 0 and
                                PlayerKeys.GroupID is not null and 
                                sp_dev_belong_group(DeviceDesiredStaus. DeviceID, PlayerKeys.GroupID);
     end if;
     
     if (new.MemberMode <> old.MemberMode) then
         if (new.MemberMode = true) then
             delete from SessionDevice where SessionID = new.SessionID;
          end if; 
      
          if (new.BrdMode <> 0) then
               update DeviceDesiredStaus, BrdModeMember set  DeviceDesiredStaus.SessionValid = false 
                   where DeviceDesiredStaus.DeviceID =  BrdModeMember.DeviceID and
                                 BrdModeMember.BrdModeID <> new.BrdMode;
          end if;
      end if;      
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_play_Schedule_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_play_Schedule_delete`
BEFORE DELETE ON `nccs`.`PlaySessionTime`
FOR EACH ROW
begin
 INSERT INTO Messages Values (0, 1, 2, 10, now(), 0, old.ScheduleID, null, null);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_play_Schedule_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_play_Schedule_update`
AFTER UPDATE ON `nccs`.`PlaySessionTime`
FOR EACH ROW
begin
 INSERT INTO Messages Values (0, 1, 2, 10, now(), 0, new.ScheduleID, null, null);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_media_insert`
BEFORE INSERT ON `nccs`.`MediaFiles`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare nodetype int default 0;
     declare last_id int default null;

     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
      select Parent , TotalTime into parentid, nodetype from  MediaFiles where MediaID = parentid;
      if ((nodetype = 0)  or (nodetype is null)) then
            set count = count + 1;
        else
           set count =  5;
         end if;
         
     end while;
     
     if ((count >= 5) or (count = 4 and new.TotalTime = 0)) then 
     insert MediaFiles(MediaID) values(0);
     end if;
	
	select InfoValue into  last_id from BaseInfo where InfomationID=0x100;
    if last_id is not null then 
        set new.MediaID = last_id + 1;
	end if;

end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `nccs`.`tr_media_update`
AFTER UPDATE ON `nccs`.`MediaFiles`
FOR EACH ROW
begin
     declare count int default 0;
     declare parentid int default 0;
     declare nodetype int default 0;
     
     set parentid = new.Parent;
     
     while (parentid is not null)  and (parentid <> 0) and (count < 5) do
        select Parent , TotalTime into parentid, nodetype from  MediaFiles where MediaID = parentid;
        if ((nodetype = 0)  or (nodetype is null)) then
            set count = count + 1;
        else
           set count =  5;
         end if;
     end while;
     
     if (count >= 5) then 
     insert MediaFiles(MediaID) values(0);
     end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_insert1` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_media_insert1`
AFTER INSERT ON `nccs`.`MediaFiles`
FOR EACH ROW
begin
	insert into BaseInfo(InfomationID, InfoValue) values(0x100, new.MediaID) on duplicate key update InfoValue=values(InfoValue);
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_after_delete` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `tr_media_after_delete` AFTER DELETE ON `MediaFiles` FOR EACH ROW
begin
	if(Old.TotalTime <> 0 and Old.FileFmt <> -1 and (Old.FilePath is not null and Old.FilePath!="")) then
		insert into tmp_DelMediaFiles(filepath) values(Old.FilePath);
	end if;
end
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`bef_media_delete` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `bef_media_delete` BEFORE DELETE ON `MediaFiles` FOR EACH ROW
begin
	if(Old.Sysfolder = 2) then
		-- not allow delete
		insert MediaFiles(MediaID) values(0);
	end if;
end;
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`bef_media_update` $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `bef_media_update` BEFORE UPDATE ON `MediaFiles` FOR EACH ROW
begin
	declare tmp_root_mediaid int default 0;

	if(new.Sysfolder = 2 ) then
		-- not allow update
		insert MediaFiles(MediaID) values(0);
	end if;

	select MediaID into tmp_root_mediaid from MediaFiles where Sysfolder = 2 limit 1;
	if((tmp_root_mediaid is not null) and tmp_root_mediaid <> 0) then
		-- not allow move to Sysfolder = 2
		if((new.Parent = tmp_root_mediaid) and (new.Sysfolder is null or new.Sysfolder <> 1)) then			
			insert MediaFiles(MediaID) values(0);
		end if;

		-- not allow move to Sysfolder = 1
		if((new.Sysfolder = 1) and (new.Parent <> tmp_root_mediaid)) then			
			insert MediaFiles(MediaID) values(0);
		end if;

	end if;
end;
$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_PlayerKeys_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_PlayerKeys_update`
AFTER UPDATE ON `nccs`.`PlayerKeys`
FOR EACH ROW
begin                               
     update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false 
                 where old.GroupID is not null and sp_dev_belong_group(DeviceDesiredStaus. DeviceID, old.GroupID);  
                 
    if not (new.GroupID = old.GroupID) then
           update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false 
                 where new.GroupID is not null  and sp_dev_belong_group(DeviceDesiredStaus. DeviceID, new.GroupID);
     end if;            
    
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_delete`
BEFORE DELETE ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin
    delete from PlayingSessions where SessionID = old.SessionID;   
    
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, old.PlayerID, NULL);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_insert`
AFTER INSERT ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin    
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.PlayerID, NULL);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_update`
BEFORE UPDATE ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin

if (new.SessionID is null) or (new.SessionID  = 0) then
    delete from PlayingSessions where SessionID = old.SessionID;
    
    -- not send device command for automatic media player
     if ((new.PlayType <> 0) and (new.PlayType <> 8) and (new.ActualSesID <> 0))  then
        call sp_send_dev_ctrl_cmd(new.PlayerID, new.IpAddress, 133, new.ActualSesID, 0, 0, null);
    end if ;    
    if(old.PlayType = 10) and (old.ActualSesID <> 0) and (new.ActualSesID = 0) then
        update SrsServerStatus, PlayListFiles, MediaFiles 
                set SrsServerStatus.count = SrsServerStatus.count -1
                where PlayListFiles.SessionID= old.ActualSesID
                    and MediaFiles.MediaID = PlayListFiles.FileID
                    and MediaFiles.FilePath like concat("%", SrsServerStatus.server,"%");
    end if;
    if(old.PlayType = 10) and (old.ActualSesID = 0) and (new.ActualSesID <> 0) then
        update SrsServerStatus, PlayListFiles, MediaFiles 
                set SrsServerStatus.count = SrsServerStatus.count + 1
                where PlayListFiles.SessionID= new.ActualSesID
                    and MediaFiles.MediaID = PlayListFiles.FileID
                    and MediaFiles.FilePath like concat("%", SrsServerStatus.server,"%");
    end if;
 else
     insert into PlayingSessions(SessionID, PlayerID, Priority, MultiPort, CircleLength, ScheduleID, BrdMode, SesType, StreamType)
            select  a.SessionID, b.PlayerID, a.Priority, new.PlayPort, a.CircleLength, new.ScheduleID, a.BrdMode, a.SessionType, a.StreamType 
                           from PlaySessions a, Players b
                           where b.PlayerID = new.PlayerID and a.SessionID = new.SessionID
            on duplicate key update PlayerID = values(PlayerID) , Priority = values(Priority) , 
                         MultiPort = values(MultiPort) , CircleLength = values(CircleLength) ,
                         ScheduleID = values(ScheduleID) , BrdMode = values(BrdMode),
                         SesType = values(SesType), StreamType = values(StreamType);
            
     if (not new.SessionID = new.ActualSesID)  and (new.PlayType <> 0) and (new.PlayType <> 8)  then
            call sp_send_dev_ctrl_cmd(new.PlayerID, new.IpAddress, 131, new.SessionID, 
                                                                      8064, get_srv_ip(), null);
     end if;         
end if;    
 
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playerstatus_update_a` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playerstatus_update_a`
AFTER UPDATE ON `nccs`.`PlayerStatus`
FOR EACH ROW
begin    
    insert into Messages Values (0, 1, 2, 3, now(), 0, 0, new.PlayerID, NULL);
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_del` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playing_ses_del`
AFTER DELETE ON `nccs`.`PlayingSessions`
FOR EACH ROW
begin
     INSERT INTO Messages Values (0, 1, 2, 10, now(), old.SessionID, old.ScheduleID, null, null);
     delete from PlaySessionTime where PlaySessionTime.ScheduleID = old.ScheduleID and TempFlag = 1;
     
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false 
           where  DeviceDesiredStaus.SessionID = old.SessionID;
    if(old.SesType = 10) then
        select PlayerStatus.IpAddress, PlaySessions.PlayerID into @ip, @player from PlayerStatus 
            inner join PlaySessions on PlaySessions.PlayerID = PlayerStatus.PlayerID
            where PlaySessions.SessionID = old.SessionID;
        if(@ip is not null) and (@player is not null) then
            call sp_send_dev_ctrl_cmd(@player, @ip, 48, 0, 0, 0, null);
        end if;
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_ins` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playing_ses_ins`
AFTER INSERT ON `nccs`.`PlayingSessions`
FOR EACH ROW
begin
     INSERT INTO Messages Values (0, 1, 2, 10, now(), new.SessionID, new.ScheduleID, null, null);
     
     if (new.BrdMode > 0) then
          update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  where DeviceDesiredStaus.BrdMode = new.BrdMode;
      end if;

      update DeviceDesiredStaus, SessionDevice set  DeviceDesiredStaus.SessionValid = false 
                 where DeviceDesiredStaus.DeviceID = SessionDevice.DeviceID and
                                SessionDevice.SessionID = new.SessionID;
      
      update DeviceDesiredStaus, PlayerKeys set  DeviceDesiredStaus.SessionValid = false 
                 where PlayerKeys.PlayerID = new.PlayerID and 
                                PlayerKeys.GroupDisable = 0 and
                                PlayerKeys.GroupID is not null and 
                                sp_dev_belong_group(DeviceDesiredStaus. DeviceID, PlayerKeys.GroupID);
                                
    
                 
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_playing_ses_update`
AFTER UPDATE ON `nccs`.`PlayingSessions`
FOR EACH ROW
begin
    if (new.Pause <> old.Pause) then
     INSERT INTO Messages Values (0, 1, 2, 10, now(), new.SessionID, new.ScheduleID, null, null);
     end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_del` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_ses_dev_ses_del`
AFTER DELETE ON `nccs`.`SessionDevice`
FOR EACH ROW
begin 
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  
               where  DeviceDesiredStaus.DeviceID = old.DeviceID and 
                              DeviceDesiredStaus.SessionID = old.SessionID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_ins` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_ses_dev_ses_ins`
AFTER INSERT ON `nccs`.`SessionDevice`
FOR EACH ROW
begin 
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  where  DeviceDesiredStaus.DeviceID = new.DeviceID;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_ses_dev_ses_update`
AFTER UPDATE ON `nccs`.`SessionDevice`
FOR EACH ROW
begin 
    update DeviceDesiredStaus set  DeviceDesiredStaus.SessionValid = false  
              where  DeviceDesiredStaus.DeviceID = new.DeviceID;
end$$

USE `nccs`;
DROP TRIGGER IF EXISTS nccs.SrsServer_after_insert$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` 
TRIGGER `nccs`.`SrsServer_after_insert` 
AFTER INSERT ON `SrsServer` 
FOR EACH ROW
BEGIN
    insert into SrsServerStatus values(new.id, new.`server`, 0); 
END$$


USE `nccs`;
DROP TRIGGER IF EXISTS nccs.SrsServer_after_update$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` 
TRIGGER `nccs`.`SrsServer_after_update` 
AFTER UPDATE ON `SrsServer` 
FOR EACH ROW
BEGIN
    update SrsServerStatus set `server` = new.`server`, count=0 where id = new.id; 
END$$


USE `nccs`;
DROP TRIGGER IF EXISTS nccs.SrsServer_after_delete$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` 
TRIGGER `nccs`.`SrsServer_after_delete` 
AFTER DELETE ON `SrsServer` 
FOR EACH ROW
BEGIN
    delete from SrsServerStatus where id=old.id; 
END$$


USE `nccs`;
DROP TRIGGER IF EXISTS nccs.SrsServerStatus_before_update$$
USE `nccs`$$
CREATE 
DEFINER = `root`@`%`
TRIGGER `nccs`.`SrsServerStatus_before_update` 
BEFORE UPDATE ON `SrsServerStatus` 
FOR EACH ROW
BEGIN
    if(new.count < 0) then
        set new.count = 0;
    end if;
END$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_userdev_delete` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_userdev_delete`
BEFORE DELETE ON `nccs`.`UserDevices`
FOR EACH ROW
begin
    
    declare ret integer;
    delete SessionDevice from SessionDevice, PlaySessions 
                        where PlaySessions.Owner = old.UserID and
                              SessionDevice.SessionID =  PlaySessions.SessionID and  
							  SessionDevice.DeviceID = old.DevID;

    select send_msg_to_srv(162, old.DevID) into ret;
       
end$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_usrdev_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_usrdev_insert`
AFTER INSERT ON `nccs`.`UserDevices`
FOR EACH ROW
begin   
    declare ret integer;    
    select send_msg_to_srv(162, new.DevID) into ret;       
end$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_usrdev_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_usrdev_update`
AFTER UPDATE ON `nccs`.`UserDevices`
FOR EACH ROW
begin   
    declare ret integer;    
    select send_msg_to_srv(162, old.DevID) into ret;       
end$$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_TaskTemplate_delete` $$
USE `nccs`$$
CREATE 
DEFINER=`root`@`%`
TRIGGER `nccs`.`tr_TaskTemplate_delete`
BEFORE DELETE ON `nccs`.`TaskTemplate`
FOR EACH ROW
begin
	delete from PlaySessions where Template = old.idTaskTemplate;
end$$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`BaseInfo_BINS` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`BaseInfo_BINS`
BEFORE INSERT ON `nccs`.`BaseInfo`
FOR EACH ROW
begin
    if  (new.InfomationID = 0) then
        set new.InfoValue = 1;
    end if;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`BaseInfo_BUPD` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`BaseInfo_BUPD`
BEFORE UPDATE ON `nccs`.`BaseInfo`
FOR EACH ROW
begin
    if  (new.InfomationID = 0) and ((old.Description <> new.Description)) then
        set new.InfoValue = 1;
    end if;
end$$

USE `nccs`$$

DROP TRIGGER IF EXISTS nccs.DeviceDesiredStaus_After_Update$$
USE `nccs`$$
CREATE TRIGGER `DeviceDesiredStaus_After_Update` 
AFTER UPDATE ON `DeviceDesiredStaus` FOR EACH ROW
begin
	declare ret integer;
    select send_msg_to_srv(161, new.DeviceID) into ret;
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `PwrDisplaySet_ADEL` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`PwrDisplaySet_ADEL`
AFTER DELETE ON `nccs`.`PwrDisplaySet`
FOR EACH ROW
begin   
    declare ret integer;    
    select send_msg_to_srv(179, null) into ret;       
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `PwrDisplaySet_AINS` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`PwrDisplaySet_AINS`
AFTER INSERT ON `nccs`.`PwrDisplaySet`
FOR EACH ROW
begin   
    declare ret integer;    
    select send_msg_to_srv(179, null) into ret;       
end$$


USE `nccs`$$
DROP TRIGGER IF EXISTS `PwrDisplaySet_AUPD` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`PwrDisplaySet_AUPD`
AFTER UPDATE ON `nccs`.`PwrDisplaySet`
FOR EACH ROW
begin   
    declare ret integer;    
    select send_msg_to_srv(179, null) into ret;       
end$$


USE `nccs`$$
DELIMITER $$
DROP TRIGGER IF EXISTS `SubNetwork_befroe_insert` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`SubNetwork_befroe_insert`
BEFORE INSERT ON `SubNetwork`
FOR EACH ROW
BEGIN
	declare mask int default null;
    declare ip int unsigned default null;
	declare maskNew int unsigned default null;
    declare ipNew int unsigned default null;
    declare err int unsigned default null;
    declare finish boolean default false;
	declare tmp CURSOR for select inet_aton(`NetMask`), inet_aton(`IpAddress`) from SubNetwork
							where SubNetwork.`idSubNetWork` > 0;
    declare continue handler for NOT FOUND set finish = true;

    if (new.idSubNetwork > 0) then
        set maskNew = inet_aton(new.NetMask);
        set ipNew = inet_aton(new.IpAddress);
    
        if(((maskNew | (maskNew << 1)) & 0xffffffff) <> maskNew) or (maskNew = 0) then
    		select error_netmask into err from SubNetwork;
        end if;
    
        if(ipNew = 0) or (ipNew & maskNew = 0) then
    		select error_ip into err from SubNetwork;
        end if;
    
        open tmp;
        fetchloop:loop
    		fetch tmp into mask,ip;
            if(finish) then
    			leave fetchloop;
            end if;
            if(((ipNew&maskNew) = (ip&maskNew)) or
    			((ipNew&mask) = (ip&mask))) then
                close tmp;
                select error_ip_or_mask into err from SubNetwork;
    		end if;
        end loop;
        close tmp;
    end if;
END$$
DELIMITER ;


USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS `SubNetwork_before_update` $$
USE `nccs`$$
CREATE
DEFINER=`root`@`%`
TRIGGER `nccs`.`SubNetwork_before_update`
BEFORE UPDATE ON `SubNetwork`
FOR EACH ROW
BEGIN
	declare mask int unsigned default null;
    declare ip int unsigned default null;
	declare maskNew int unsigned default null;
    declare ipNew int unsigned default null;
    declare err int default null;
    declare finish boolean default false;
	declare tmp CURSOR for select inet_aton(`NetMask`), inet_aton(`IpAddress`) from SubNetwork
							where SubNetwork.`idSubNetwork` != new.idSubNetWork and
								  SubNetwork.`idSubNetwork` > 0 ;
    declare continue handler for NOT FOUND set finish = true;
    if (new.idSubNetwork > 0) then
        set maskNew = inet_aton(new.NetMask);
        set ipNew = inet_aton(new.IpAddress);
    
        if(((maskNew | (maskNew << 1)) & 0xffffffff) <> maskNew) or (maskNew = 0) then
    		select error_netmask into err from SubNetwork;
        end if;
    
        if(ipNew = 0) or (ipNew & maskNew = 0) then
    		select error_ip into err from SubNetwork;
        end if;
    
        open tmp;
        fetchloop:loop
    		fetch tmp into mask,ip;
            if(finish) then
    			leave fetchloop;
            end if;
            if(((ipNew&maskNew) = (ip&maskNew)) or
    			((ipNew&mask) = (ip&mask))) then
                close tmp;
                select error_ip_or_mask into err from SubNetWork;
    		end if;
        end loop;
        close tmp;
    end if;
END$$
DELIMITER ;

USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.Timetable_befroe_insert$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`Timetable_befroe_insert` 
BEFORE INSERT ON `Timetable` 
FOR EACH ROW
BEGIN
	declare err int default null;
	if (new.`WeekDay` < 0) and (new.`WeekDay` > 6) then
		select error_weekday_error into err from Timetable;
	end if;    
END$$
DELIMITER ;

USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.Timetable_before_update$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`Timetable_before_update` 
BEFORE UPDATE ON `Timetable` 
FOR EACH ROW
BEGIN
	declare err int default null;
    if (new.`WeekDay` < 0) and (new.`WeekDay` > 6) then
		select error_weekday_error into err from Timetable;
	end if;     
END$$
DELIMITER ;


USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.Event_before_update$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`Event_before_update` 
BEFORE UPDATE ON `Event` 
FOR EACH ROW
BEGIN
    if(new.Version >= 0) then
        set new.Version = old.Version + 1; 
    end if;
END$$
DELIMITER ;


-- -----------------------------------------------------
-- Triger `IpCall_before_insert`
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.IpCall_before_insert$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`IpCall_before_insert` BEFORE INSERT ON `IpCall` FOR EACH ROW
BEGIN
    declare idle_port int default 8500;
    set new.ringing = now();
    set new.status='ringing';
    set new.webrtcStatus = 'idle';
    set new.webrtcUpdate = null;
    
    _loop: loop   
    if not exists(select * from IpCall where audioPort = idle_port) then   
        leave _loop;
    end if;
    set idle_port = idle_port + 2;
    end loop;
    
    set new.audioPort = idle_port;
    set new.wsPort = idle_port + 1;
END$$
DELIMITER ;

-- -----------------------------------------------------
-- Triger `IpCall_after_insert`
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.IpCall_after_insert$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`IpCall_after_insert` AFTER INSERT ON `IpCall` FOR EACH ROW
BEGIN
    declare ecode int;
    select sys_exec(concat('iDsteWebrtc ', new.id, '&')) into ecode;
END$$
DELIMITER ;

-- -----------------------------------------------------
-- Triger `IpCall_before_update`
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.IpCall_before_update$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`IpCall_before_update` BEFORE UPDATE ON `IpCall` FOR EACH ROW
BEGIN
    declare err int default null;
    declare deviceUser int default null; -- device user id

    -- webrtc state changed
    if((old.webrtcStatus <> 'error') and (new.webrtcStatus = 'error')) or 
      ((old.webrtcStatus <> 'idle') and (new.webrtcStatus = 'idle')) then
        set new.status = 'idle';
    elseif(old.webrtcStatus <> 'running') and (new.webrtcStatus = 'running') then
        set new.status = 'talking';
    end if;

    if(new.status = 'idle') and (old.status <> 'idle') then
        -- device log
        select User_ID into deviceUser from DeviceStatus where DeviceID = old.device;
        if(old.direction = 'b2s') then
            insert into DeviceLog (`DeviceID`, `DateTime`, `Event`, `CtrlUser`, `EndTime`)
                values(old.device, old.ringing, 5, deviceUser, now());
        else
            insert into DeviceLog (`DeviceID`, `DateTime`, `Event`, `CtrlUser`, `EndTime`)
                values(old.device, old.ringing, 6, deviceUser, now());
        end if;
        -- set device wait
        update DeviceDesiredStaus set IpCall=
            (
                case `IpCall` when 2 then 3
                when 1 then 3
                else 0
                end
            ), IpCallPort=0 
        where DeviceID = new.device;
    elseif(new.status = 'talking') and (old.status <> 'talking') then
        update DeviceDesiredStaus set IpCall=2,IpCallPort=new.audioPort where DeviceID = new.device;
    end if;
END$$
DELIMITER ;

-- -----------------------------------------------------
-- Triger `IpCall_after_delete`
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.IpCall_after_delete$$
USE `nccs`$$
CREATE DEFINER=`root`@`%` TRIGGER `nccs`.`IpCall_after_delete` AFTER DELETE ON `IpCall` FOR EACH ROW
BEGIN
    if(old.status <> 'idle') then
        update DeviceDesiredStaus set IpCall = 3 where DeviceID=old.device;
    end if;
END$$
DELIMITER ;

-- -----------------------------------------------------
-- Event `ipCall_Monitor`
--  呼叫监控事件，每2秒运行一次
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP EVENT IF EXISTS nccs.`ipCall_Monitor`;
USE `nccs`$$
CREATE DEFINER=`root`@`%` EVENT `ipCall_Monitor`
ON SCHEDULE EVERY 2 SECOND ON COMPLETION PRESERVE
ENABLE DO CALL sp_ipcall_check()
$$
DELIMITER ;

-- -----------------------------------------------------
-- Procedure `sp_ipcall_check`
--  呼叫状态检查，维护设备/浏览器离线/呼叫超时等异常情况下的呼叫状态
-- -----------------------------------------------------
USE `nccs`;
DROP procedure IF EXISTS `sp_ipcall_check`;
DELIMITER $$
USE `nccs`;
CREATE DEFINER=`root`@`%` PROCEDURE `sp_ipcall_check`()
BEGIN
    delete from IpCall where IpCall.status='idle'
        and (addtime(IpCall.webrtcUpdate,  '00:00:10') < now()
             or IpCall.webrtcUpdate > now());

	update IpCall,CallWaiter set IpCall.`status`='idle'
		where IpCall.`status` <> 'idle'
			and ((addtime(CallWaiter.`updateAt`, 10) < now() -- browser error
					and IpCall.waiter = CallWaiter.id)
				or (addtime(IpCall.webrtcUpdate, 10) < now()) -- webrtc error
				or (addtime(IpCall.ringing, 30) < now()
					and IpCall.webrtcStatus <> 'running')); -- call timeout
	update DeviceDesiredStaus set IpCall = 0 where IpCall = 3 and addtime(IpCallEvent, 20) < now();
END$$
DELIMITER ;

-- -----------------------------------------------------
--  Function `func_ipcall_request`
--  ip呼叫请求
-- -----------------------------------------------------
USE `nccs`;
DROP FUNCTION IF EXISTS `func_ipcall_request`;
DELIMITER $$
USE `nccs`;
CREATE DEFINER=`root`@`%` FUNCTION `func_ipcall_request`(
	devid varchar(50),
	request int) RETURNS int(11)
BEGIN
    declare waiterCnt int default 0;
    declare callCnt int default 0;
    declare ret int default 0;

    select IpCallStatus into @callStatus from DeviceStatus where DeviceID=devid;
    if (request = 0) or (@callStatus is null) or (@callStatus & 0x80 <> 0x80) then -- stop call
        update IpCall set status='idle' where device=devid and status <> 'idle';
        update DeviceDesiredStaus set IpCall=0 where DeviceID=devid and IpCall <> 0;
	elseif(request = 1) then -- start call
		select count(*) into waiterCnt from CallWaiter where addtime(updateAt, 10) > now();
        if(waiterCnt = 0) then
			update `DeviceDesiredStaus` set `IpCall` = 3 where DeviceID=devid and IpCall = 0;
        else
            select count(*) into callCnt from IpCall where status <> 'idle';
            if(callCnt < 8) then 
                insert into IpCall (device, direction) values (devid, 'd2s');
				update `DeviceDesiredStaus` set `IpCall` = 1 where DeviceID=devid and IpCall = 0;
            else
				update `DeviceDesiredStaus` set `IpCall` = 3 where DeviceID=devid and IpCall = 0;
            end if;
        end if;
	end if;
    return ret;
END$$
DELIMITER ;

-- -----------------------------------------------------
--  Trigger `PlayerAlive_after_insert`
--  801/803上线触发器
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.PlayerAlive_after_insert$$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` TRIGGER `nccs`.`PlayerAlive_after_insert` 
AFTER INSERT ON `PlayerAlive` FOR EACH ROW
BEGIN 
    insert into DeviceLog (`DeviceID`, `DateTime`,  `Event`) 
        values (new.PlayerID, now(), 1);
END$$
DELIMITER ;
USE `nccs`;

-- -----------------------------------------------------
--  Trigger `PlayerAlive_after_delete`
--  801/803上线触发器
-- -----------------------------------------------------
USE `nccs`;
DELIMITER $$
DROP TRIGGER IF EXISTS nccs.PlayerAlive_after_delete$$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` TRIGGER `nccs`.`PlayerAlive_after_delete` 
AFTER DELETE ON `PlayerAlive` FOR EACH ROW
BEGIN
    update DeviceLog 
        set EndTime=now() 
            where DeviceID=old.PlayerID 
                and Event=1 
            order by DevLogID desc limit 1;
END$$
DELIMITER ;

-- -----------------------------------------------------
--  Trigger `func_set_device_sysenable`
--  设置设备状态
-- -----------------------------------------------------
USE `nccs`;
DROP function IF EXISTS `func_set_device_sysenable`;
DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_set_device_sysenable`(
    devid varchar(50),
    sys_enable tinyint(4)) RETURNS tinyint(4)
BEGIN
    if(sys_enable = 0) or (sys_enable = 1) then
        update DeviceStatus set SysPowerCmd = sys_enable where DeviceID=devid;
        return 1;
    else
        return 0;
    end if;
END$$
DELIMITER ;

-- -----------------------------------------------------
--  FUNCTION `func_update_rf_ctrl`
--  物联控制
-- -----------------------------------------------------

USE `nccs`;
DELIMITER $$
DROP function IF EXISTS `func_update_rf_ctrl`;
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_update_rf_ctrl`(
        dev_id varchar(50),
        old_state binary(16),
        new_state binary(16)
    )RETURNS binary(16)
BEGIN
    update DeviceStatus set RfDevCmd = calc_rf_cmd(RfDevCmd, new_state) where DeviceID=dev_id;
    select update_rf_ctrl(old_state, new_state) into @ret;
    return @ret;
END$$
DELIMITER ;

