


-- -----------------------------------------------------
-- Table `AlternateDate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `AlternateDate` ;

CREATE TABLE IF NOT EXISTS `AlternateDate` (
  `SpecialDate` DATE NOT NULL,
  `AlteredScheduleDay` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`SpecialDate`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `BaseInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `BaseInfo` ;

CREATE TABLE IF NOT EXISTS `BaseInfo` (
  `InfomationID` INT NOT NULL DEFAULT '0' COMMENT '0~0x04 : air condition command description;\n0x80: User name;\n0x100: MediaFile auto_increasement value;\n0x101 Active task template;\n0x200: Version;',
  `Description` VARCHAR(128) NULL DEFAULT NULL,
  `InfoValue` INT NULL DEFAULT NULL,
  PRIMARY KEY (`InfomationID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `BroadcastMode`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `BroadcastMode` ;

CREATE TABLE IF NOT EXISTS `BroadcastMode` (
  `idBroadcastMode` INT(11) NOT NULL AUTO_INCREMENT,
  `ModeName` VARCHAR(50) NULL DEFAULT NULL,
  `Priority` INT(11) NOT NULL DEFAULT '10',
  `Enabled` TINYINT(1) NULL DEFAULT '0',
  `StartTime` DATETIME NULL DEFAULT NULL,
  `StopTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` TINYINT(4) NULL DEFAULT '0' COMMENT '0: means for one day\n   the start date and end date is indicated by starttime and stoptime.\n\nother: means the mode should be repeated weekly.\nbit 0: means sunday\nbit1:  monday\nbit2: tuesday\n...',
  `Active` TINYINT(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idBroadcastMode`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `DevClasses`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DevClasses` ;

CREATE TABLE IF NOT EXISTS `DevClasses` (
  `ClassID` INT(11) NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`ClassID`),
  INDEX `ClassParent` (`Parent` ASC),
  CONSTRAINT `ClassParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `DeviceList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DeviceList` ;

CREATE TABLE IF NOT EXISTS `DeviceList` (
  `DevID` VARCHAR(50) NOT NULL,
  `Dev_Name` VARCHAR(32) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `DisableParentSchedule` TINYINT(4) NULL DEFAULT '0' COMMENT 'Indicate whether disable inheritting schedule setting from parents groups.',
  `Dev_Description` VARBINARY(96) NULL,
  `Dev_Configuration` VARBINARY(1024) NULL,
  `CameraIpAddr` VARCHAR(45) NULL COMMENT 'IP Address for Monitor Camera.',
  `CameraPort` INT NULL COMMENT 'Camera Port',
  `CameraUser` VARCHAR(45) NULL COMMENT 'UserName for Camera',
  `CameraPasswd` VARCHAR(45) NULL COMMENT 'Password for Camera',
  `CameraType` tinyint(4) DEFAULT NULL,
  `CameraChannel` int(11) DEFAULT NULL,
  PRIMARY KEY (`DevID`),
  UNIQUE INDEX `DevID_UNIQUE` (`DevID` ASC),
  INDEX `DevClass` (`Parent` ASC),
  CONSTRAINT `DevClass`
    FOREIGN KEY (`Parent`)
    REFERENCES `DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `BrdModeMember`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `BrdModeMember` ;

CREATE TABLE IF NOT EXISTS `BrdModeMember` (
  `DevIDMode` INT(11) NOT NULL AUTO_INCREMENT,
  `BrdModeID` INT(11) NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`DevIDMode`),
  UNIQUE INDEX `DevIDMode_UNIQUE` (`BrdModeID` ASC, `DeviceID` ASC),
  INDEX `BrdModeID` (`BrdModeID` ASC),
  INDEX `ModeDeviceID` (`DeviceID` ASC),
  CONSTRAINT `BrdModeID`
    FOREIGN KEY (`BrdModeID`)
    REFERENCES `BroadcastMode` (`idBroadcastMode`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `ModeDeviceID`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `DeviceList` (`DevID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `DevCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DevCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `DevCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `DevID` VARCHAR(50) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`DevID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`DevID` ASC),
  INDEX `DeviceID` (`DevID` ASC),
  INDEX `DevCtrlDevId` (`DevID` ASC),
  CONSTRAINT `DevCtrlDevId`
    FOREIGN KEY (`DevID`)
    REFERENCES `DeviceList` (`DevID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `DeviceDesiredStaus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DeviceDesiredStaus` ;

CREATE TABLE IF NOT EXISTS `DeviceDesiredStaus` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdPort` SMALLINT(6) NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `SessionValid` TINYINT(1) NULL DEFAULT '1',
  `SessionType` TINYINT(4) NULL DEFAULT NULL,
  `StreamType` TINYINT(4) UNSIGNED NULL DEFAULT NULL,
  `ModePriority` INT(11) NULL DEFAULT NULL,
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  `IpCall` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '0: idle\n1:ringing\n2:talking',
  `IpCallPort` INT(11) DEFAULT NULL,
  `IpCallEvent` datetime DEFAULT NULL,
  PRIMARY KEY (`DeviceID`),
  INDEX `DesiredDevicesID` (`DeviceID` ASC),
  INDEX `DesiredSessionID` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `DeviceLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DeviceLog` ;

CREATE TABLE IF NOT EXISTS `DeviceLog` (
  `DevLogID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `DeviceID` VARCHAR(50) NULL DEFAULT NULL,
  `DateTime` DATETIME NULL DEFAULT NULL,
  `Event` TINYINT(4) NULL DEFAULT NULL COMMENT '1  offline/online\n2  power on/power off\n3  enabled/  disabled\n4  Normal Text Message' /* comment truncated */ /*5 Urgent Text Message*/,
  `CtrlUser` INT(11) NULL DEFAULT NULL,
  `MsgContext` VARCHAR(256) NULL DEFAULT NULL,
  `EndTime` DATETIME DEFAULT NULL,
  PRIMARY KEY (`DevLogID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = 'Devices log';


-- -----------------------------------------------------
-- Table `DeviceStatistic`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DeviceStatistic` ;

CREATE TABLE IF NOT EXISTS `DeviceStatistic` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `StatisticDay` DATE NOT NULL,
  `PowerConsumed` BINARY(128) NULL DEFAULT NULL,
  `UsedTime` BINARY(128) NULL DEFAULT NULL,
  PRIMARY KEY (`DeviceID`, `StatisticDay`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `DeviceStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DeviceStatus` ;

CREATE TABLE IF NOT EXISTS `DeviceStatus` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `DeviceType` TINYINT(4) NULL DEFAULT '0',
  `DeviceStatus` INT(11) NULL DEFAULT '0',
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `ShouldSessionID` SMALLINT(6) UNSIGNED NULL DEFAULT '0',
  `ActualSessionID` SMALLINT(6) UNSIGNED NULL DEFAULT '0',
  `State_SysPower` TINYINT(4) NULL DEFAULT '0',
  `State_ProjectorStatus` TINYINT(4) NULL DEFAULT '0',
  `State_ProjectorLampStatus` TINYINT(4) NULL DEFAULT '0',
  `State_ExDevice1Status` TINYINT(4) NULL DEFAULT '0',
  `State_ExDevice2Status` TINYINT(4) NULL DEFAULT '0',
  `State_CurrProjectorSrc` TINYINT(4) NULL DEFAULT '0',
  `State_CurrAudio` TINYINT(4) NULL DEFAULT '0',
  `State_CurrAudioVolume` TINYINT(4) NULL DEFAULT '0',
  `State_CurrMicVolume` TINYINT(4) NULL DEFAULT '0',
  `State_FaultStatus` TINYINT(4) NULL DEFAULT '0',
  `State_MicState` TINYINT(4) NULL DEFAULT '0',
  `State_Mute` TINYINT(4) NULL DEFAULT '0',
  `State_CentralUsedTime` INT(11) NULL DEFAULT '0',
  `State_ProjectorUsedTime` INT(11) NULL DEFAULT '0',
  `State_LightUsedTime` INT(11) NULL DEFAULT '0',
  `Cfg_System` TINYINT NULL DEFAULT NULL,
  `Cfg_Remark` VARBINARY(96) NULL DEFAULT NULL,
  `netid` TINYINT(4) NULL DEFAULT '-1',
  `NetworkID` INT(11) NULL DEFAULT '0',
  `BrdPort` INT(11) NULL DEFAULT NULL,
  `RfDevStatus` BINARY(16) NULL DEFAULT NULL,
  `State_Pc` TINYINT(4) DEFAULT '0',
  `User_ID` INT(11) NULL DEFAULT NULL,
  `SysPowerCmd` tinyint(4) DEFAULT NULL COMMENT '0:power off; 1:power on',
  `IpCallStatus` TINYINT(4) UNSIGNED DEFAULT '0',
  `RfDevCmd` BINARY(16) NULL DEFAULT NULL,
  PRIMARY KEY (`DeviceID`),
  UNIQUE INDEX `DeviceID_UNIQUE` (`DeviceID` ASC),
  INDEX `DevID` (`DeviceID` ASC),
  INDEX `Device` (`DeviceID` ASC),
  INDEX `DevicestatusNetworkID` (`NetworkID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `Players`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Players` ;

CREATE TABLE IF NOT EXISTS `Players` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `PlayerName` VARBINARY(32) NULL DEFAULT NULL,
  `PlayerType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: celt audio player\n8: vlc player' /* comment truncated */ /*1: audio play devices*/,
  `Priority` TINYINT(4) NULL DEFAULT '10',
  `Remark` VARBINARY(96) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  UNIQUE INDEX `ID_UNIQUE` (`PlayerID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `Users`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Users` ;

CREATE TABLE IF NOT EXISTS `Users` (
  `User_ID` INT(11) NOT NULL AUTO_INCREMENT,
  `User_Name` VARCHAR(255) NULL,
  `User_Desc` VARCHAR(255) NULL,
  `Pass_Word` VARCHAR(256) NULL DEFAULT 'password, encode with PASSWORD()',
  `UsbKey` VARCHAR(50) NULL DEFAULT NULL COMMENT 'when the user\'s authorization is expired.' /* comment truncated */ /*After expired, all authorized devices will be deleted.*/,
  `Priority` INT(11) NULL DEFAULT '100',
  `privilege` INT(11) NOT NULL DEFAULT '0' COMMENT 'Bit 0: privilege of device control.\nBit1~Bit7: Reservered\n\nBit 8: privilege of creating audio and vedio broadcast tasks.\nBit9~Bit15: Reservered\n' /* comment truncated */ /*Bit 16: privilege of air condition control*/,
  `IcCard` VARCHAR(50) NULL,
  `Phone` VARCHAR(50) NULL,
  `ServerSync` TINYINT(4) DEFAULT '1' COMMENT 'Flag for sync data to cloud server, set when data is inserted or updated, clear after the changed data sysnc to cloud server.',
  `User_Type` TINYINT(4) DEFAULT '3' COMMENT '用户类型：\n1：学生\n2：教师\n3：临时人员',
  `User_Sn` VARCHAR(20) DEFAULT NULL COMMENT '学号或工号',
  `User_Expiry` DATETIME DEFAULT NULL COMMENT '有效期\nUser_Type=3时需要检查用户过期时间\n时间为0表示不过期',
  `Mgr_Privilege` TINYINT(1) DEFAULT '0' COMMENT '设备管理权限标志\n0：具有部分权限，需要查询UserDevices表\n1：具有全部权限，无需查询UserDevices表',
  `Dev_Privilege` TINYINT(1) DEFAULT '0' COMMENT '设备使用权限标志\n0：具有部分权限，需要查询UserDevices表\n1：具有全部权限，无需查询UserDevices表',
  `Create_Type` TINYINT(1) DEFAULT '0' COMMENT '用户创建类型\n0：手动创建\n1：自动(IC卡同步)创建\n',
  `IC_Status` TINYINT(1) DEFAULT '0' COMMENT 'IC卡状态\n0：IC卡正常\n1：IC卡挂失',
  `Dpm_Sn` VARCHAR(20) DEFAULT NULL COMMENT '部门编号',
  `Dpm_Name` VARCHAR(100) DEFAULT NULL COMMENT '部门名称',
  `Del_Flag` TINYINT(1) DEFAULT '0' COMMENT 'delete flag:\n0: normal\n1: deleted',
  PRIMARY KEY (`User_ID`),
  UNIQUE INDEX `UsbKey_UNIQUE` (`UsbKey` ASC),
  UNIQUE INDEX `User_Name_UNIQUE` (`User_Name` ASC),
  UNIQUE INDEX `IcCard_UNIQUE` (`IcCard` ASC),
  UNIQUE KEY `User_Sn_UNIQUE` (`User_Sn`),
  CONSTRAINT `UsbKey`
    FOREIGN KEY (`UsbKey`)
    REFERENCES `Players` (`PlayerID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `TaskTemplate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `TaskTemplate` ;

CREATE TABLE IF NOT EXISTS `TaskTemplate` (
  `idTaskTemplate` INT(11) NOT NULL AUTO_INCREMENT,
  `TemplateName` VARCHAR(45) NULL DEFAULT NULL,
  `Enabled` TINYINT(4) NULL DEFAULT '0',
  PRIMARY KEY (`idTaskTemplate`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `PlaySessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlaySessions` ;

CREATE TABLE IF NOT EXISTS `PlaySessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL DEFAULT '0',
  `SessionName` VARCHAR(50) NOT NULL,
  `SessionType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: automatic broadcast task\n1: player created task\n2: manually played task\n10:BW803 player created task',
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Status` TINYINT(4) NOT NULL DEFAULT '0',
  `CircleLength` INT(11) NOT NULL DEFAULT '0',
  `ClassID` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `MemberMode` TINYINT(1) NOT NULL DEFAULT '0',
  `StreamType` TINYINT(4) UNSIGNED NOT NULL DEFAULT '1' COMMENT 'Stream Type: \n1: valid 0: invalid\nBit 0: audio\nBit1: Video' /* comment truncated */ /*Bit7: Mandatory flag*/,
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  `Owner` INT(11) NULL DEFAULT NULL,
  `PlayMode` TINYINT(4) NULL DEFAULT '0' COMMENT '0: Sequential Playing',
  `AudioGain` TINYINT(4) NULL DEFAULT '0',
  `Template` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  INDEX `Players` (`PlayerID` ASC),
  INDEX `SessionParent` (`Parent` ASC),
  INDEX `SessionMode` (`BrdMode` ASC),
  INDEX `SessionUser` (`Owner` ASC),
  INDEX `TaskTemplate_idx` (`Template` ASC),
  CONSTRAINT `TaskTemplate`
    FOREIGN KEY (`Template`)
    REFERENCES `TaskTemplate` (`idTaskTemplate`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `Players`
    FOREIGN KEY (`PlayerID`)
    REFERENCES `Players` (`PlayerID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `SessionMode`
    FOREIGN KEY (`BrdMode`)
    REFERENCES `BroadcastMode` (`idBroadcastMode`),
  CONSTRAINT `SessionParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `PlaySessions` (`SessionID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `SessionUser`
    FOREIGN KEY (`Owner`)
    REFERENCES `Users` (`User_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PlaySessionTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlaySessionTime` ;

CREATE TABLE IF NOT EXISTS `PlaySessionTime` (
  `ScheduleID` INT(11) NOT NULL AUTO_INCREMENT,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `PlayTime` DATETIME NOT NULL,
  `TempFlag` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`ScheduleID`),
  UNIQUE INDEX `SesTime_UNIQUE` (`SessionID` ASC, `WeekDay` ASC, `PlayTime` ASC),
  INDEX `Schsessionid` (`SessionID` ASC),
  CONSTRAINT `Schsessionid`
    FOREIGN KEY (`SessionID`)
    REFERENCES `PlaySessions` (`SessionID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = 'Auto broadcast playing schedules';


-- -----------------------------------------------------
-- Table `DisableDevSession`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `DisableDevSession` ;

CREATE TABLE IF NOT EXISTS `DisableDevSession` (
  `ScheduleID` INT(11) NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  `Disabled` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`ScheduleID`, `DeviceID`),
  INDEX `DisDevShedule` (`ScheduleID` ASC),
  INDEX `DisabledScheDevice` (`DeviceID` ASC),
  CONSTRAINT `DisabledScheDevice`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `DeviceList` (`DevID`),
  CONSTRAINT `DisDevShedule`
    FOREIGN KEY (`ScheduleID`)
    REFERENCES `PlaySessionTime` (`ScheduleID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `EventModel`
-- -----------------------------------------------------
CREATE TABLE `EventModel` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `Manufacturer` varchar(31) NOT NULL,
  `Model` varchar(31) NOT NULL,
  `Magic` int(11) UNSIGNED NOT NULL,
  PRIMARY KEY (`id`))
ENGINE=InnoDB DEFAULT CHARSET=utf8;
-- -----------------------------------------------------
-- Table `Event`
-- -----------------------------------------------------
CREATE TABLE `Event` (
  `Id` int(11) NOT NULL AUTO_INCREMENT,
  `Name` varchar(31) NOT NULL,
  `StartTask` smallint(6) DEFAULT NULL,
  `EndTask` smallint(6) DEFAULT NULL,
  `Config` varbinary(64) NOT NULL COMMENT '事件配置',
  `Model` int(11) NOT NULL COMMENT '型号',
  `Version` int(11) NOT NULL DEFAULT '0' COMMENT '版本号:自动生成，前端禁止操作',
  PRIMARY KEY (`Id`),
  INDEX `model_idx` (`Model` ASC),
  CONSTRAINT `EventModel`
    FOREIGN KEY (`Model`)
    REFERENCES `EventModel` (`id`))
ENGINE=InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `GroupCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `GroupCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `GroupCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `GroupID` INT(11) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`GroupID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`GroupID` ASC),
  INDEX `DeviceID` (`GroupID` ASC),
  INDEX `DevCtrlGroupID` (`GroupID` ASC),
  CONSTRAINT `DevCtrlGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `DevClasses` (`ClassID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `LastProcessedTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `LastProcessedTime` ;

CREATE TABLE IF NOT EXISTS `LastProcessedTime` (
  `LastTimeID` INT(11) NOT NULL DEFAULT '1' COMMENT 'Only one record in this table',
  `LastTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`LastTimeID`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8
COMMENT = 'a globe time which record last timer process time.';


-- -----------------------------------------------------
-- Table `MediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `MediaFiles` ;

CREATE TABLE IF NOT EXISTS `MediaFiles` (
  `MediaID` INT(11) NOT NULL AUTO_INCREMENT,
  `FileName` VARCHAR(64) NULL,
  `FileSize` BIGINT NULL,
  `TotalTime` INT(11) NOT NULL DEFAULT '0',
  `FileFmt` INT(11) NULL COMMENT '0: celt\n1: mp3\n2: ts\n3: mp4, mov' /* comment truncated */ /*4: avi*/,
  `BitRate` INT(11) NULL DEFAULT NULL,
  `VedioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: h264\n1: mpeg4',
  `Height` INT(11) NULL,
  `Width` INT(11) NULL DEFAULT NULL,
  `FrameRate` INT(11) NULL,
  `AudioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: celt\n1: mp3' /* comment truncated */ /*2: aac*/,
  `Channels` INT(11) NULL DEFAULT NULL,
  `SampleRate` INT(11) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `Gain` TINYINT(4) NULL DEFAULT '0',
  `CreateTime` DATETIME NULL,
  `FilePath` VARCHAR(256) NULL,
  `Owner` INT(11) NULL COMMENT 'sysfolder owner',
  `Sysfolder` TINYINT(4) NULL DEFAULT NULL COMMENT 'system create folder,not update or delete\n1:true' /* comment truncated */ /*0,null:false*/,
  PRIMARY KEY (`MediaID`),
  UNIQUE INDEX `ID_UNIQUE` (`MediaID` ASC),
  INDEX `MediaParent` (`Parent` ASC),
  INDEX `MediaUser_idx` (`Owner` ASC),
  CONSTRAINT `MediaParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `MediaFiles` (`MediaID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `MediaUser`
    FOREIGN KEY (`Owner`)
    REFERENCES `Users` (`User_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `Messages`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Messages` ;

CREATE TABLE IF NOT EXISTS `Messages` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `MsgFrom` TINYINT(4) NOT NULL,
  `MsgTo` TINYINT(4) NOT NULL,
  `MsgType` TINYINT(4) NULL DEFAULT NULL,
  `MsgTime` DATETIME NULL DEFAULT NULL,
  `CmdType` INT(11) NULL DEFAULT NULL,
  `CmdObjType` INT(11) NULL DEFAULT NULL,
  `CmdObjID` VARCHAR(50) NULL DEFAULT NULL,
  `CmdObjIP` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `ID_UNIQUE` (`ID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `MsgTasks`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `MsgTasks` ;

CREATE TABLE IF NOT EXISTS `MsgTasks` (
  `MsgTaskID` INT(11) NOT NULL,
  `PlayedTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` INT(11) NULL DEFAULT NULL COMMENT '0: Play one time.\n    played on PlayedTime.\nother: repeat weekly' /* comment truncated */ /*    bit0~bit7: from monday to sunday.*/,
  `Duration` INT(11) NULL DEFAULT NULL,
  `Content` VARCHAR(256) NULL DEFAULT NULL,
  PRIMARY KEY (`MsgTaskID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `MsgTaskDev`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `MsgTaskDev` ;

CREATE TABLE IF NOT EXISTS `MsgTaskDev` (
  `MsgTaskID` INT(11) NOT NULL,
  `DevID` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`MsgTaskID`, `DevID`),
  INDEX `msgtask` (`MsgTaskID` ASC),
  INDEX `msgtaskdev` (`DevID` ASC),
  CONSTRAINT `msgtask`
    FOREIGN KEY (`MsgTaskID`)
    REFERENCES `MsgTasks` (`MsgTaskID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `msgtaskdev`
    FOREIGN KEY (`DevID`)
    REFERENCES `DeviceList` (`DevID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PlayListFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlayListFiles` ;

CREATE TABLE IF NOT EXISTS `PlayListFiles` (
  `PlayListFIleId` INT(11) NOT NULL AUTO_INCREMENT,
  `FileID` INT(11) NULL DEFAULT NULL,
  `SequenceID` INT(11) NOT NULL,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `Duration` INT(11) NULL DEFAULT '0',
  `KeyIndex` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayListFIleId`),
  UNIQUE INDEX `SessionIDSeq` (`SessionID` ASC, `SequenceID` ASC),
  INDEX `SessionID` (`SessionID` ASC),
  INDEX `FileID` (`FileID` ASC),
  CONSTRAINT `FileID`
    FOREIGN KEY (`FileID`)
    REFERENCES `MediaFiles` (`MediaID`),
  CONSTRAINT `SessionID`
    FOREIGN KEY (`SessionID`)
    REFERENCES `PlaySessions` (`SessionID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PlayerAlive`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlayerAlive` ;

CREATE TABLE IF NOT EXISTS `PlayerAlive` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `RefreshTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerActivePlayerID` (`PlayerID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PlayerKeys`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlayerKeys` ;

CREATE TABLE IF NOT EXISTS `PlayerKeys` (
  `PlayerKeyId` INT(11) NOT NULL AUTO_INCREMENT,
  `PlayerID` VARCHAR(50) NOT NULL,
  `Index` INT(11) NOT NULL,
  `GroupDisable` TINYINT(4) NULL DEFAULT '0',
  `DevDisable` TINYINT(4) NULL DEFAULT '0',
  `GroupID` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerKeyId`),
  UNIQUE INDEX `PlayerIndex` (`PlayerID` ASC, `Index` ASC),
  INDEX `PlayerKey_PlayerID` (`PlayerID` ASC),
  INDEX `PlayerGroupID` (`GroupID` ASC),
  CONSTRAINT `PlayerGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `PlayerKey_PlayerID`
    FOREIGN KEY (`PlayerID`)
    REFERENCES `Players` (`PlayerID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PlayerStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlayerStatus` ;

CREATE TABLE IF NOT EXISTS `PlayerStatus` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `NetID` TINYINT(4) NULL DEFAULT NULL,
  `ActualSesID` INT(11) NULL DEFAULT NULL,
  `PlayPort` INT(11) NULL DEFAULT NULL,
  `PlayType` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerStatusPlayerID` (`PlayerID` ASC),
  INDEX `PlayerStatusSessionID` (`SessionID` ASC),
  INDEX `PlayerStatusScheduleID` (`ScheduleID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PlayingSessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PlayingSessions` ;

CREATE TABLE IF NOT EXISTS `PlayingSessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `PlayingFileID` INT(11) NULL DEFAULT NULL,
  `MultiPort` INT(11) NULL DEFAULT NULL,
  `CircleLength` INT(11) NULL DEFAULT NULL,
  `CurrFileProgress` INT(11) NULL DEFAULT NULL,
  `CurrTotalProgress` INT(11) NULL DEFAULT NULL,
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Pause` TINYINT(4) NOT NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `SesType` TINYINT(4) NULL DEFAULT '0',
  `StreamType` TINYINT(4) UNSIGNED NULL DEFAULT '1',
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  UNIQUE INDEX `PlayerID_UNIQUE` (`PlayerID` ASC),
  INDEX `Session` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `ProjectorType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ProjectorType` ;

CREATE TABLE IF NOT EXISTS `ProjectorType` (
  `Type` VARCHAR(50) NOT NULL,
  `PoweroffDelay` INT(11) NOT NULL,
  `CheckBit` INT(11) NOT NULL,
  `StopBit` INT(11) NOT NULL,
  `DataBit` INT(11) NOT NULL,
  `BaudRate` INT(11) NOT NULL,
  `CmdOpen` VARCHAR(255) NOT NULL,
  `CmdClose` VARCHAR(255) NOT NULL,
  `CmdFromPc` VARCHAR(255) NOT NULL,
  `CmdFromVideo` VARCHAR(255) NOT NULL,
  PRIMARY KEY (`Type`),
  UNIQUE INDEX `Type_UNIQUE` (`Type` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `SessionDevice`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SessionDevice` ;

CREATE TABLE IF NOT EXISTS `SessionDevice` (
  `SessionDevID` INT(11) NOT NULL AUTO_INCREMENT,
  `DeviceID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NOT NULL,
  `KeyIndex` INT(11) NOT NULL DEFAULT '0',
  `DevDisabled` TINYINT(4) NULL DEFAULT '0',
  PRIMARY KEY (`SessionDevID`),
  UNIQUE INDEX `SessionDevKey` (`SessionID` ASC, `DeviceID` ASC, `KeyIndex` ASC),
  INDEX `SessionDevDev` (`DeviceID` ASC),
  INDEX `SessionDevSes` (`SessionID` ASC),
  CONSTRAINT `SessionDevDev`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `DeviceList` (`DevID`),
  CONSTRAINT `SessionDevSes`
    FOREIGN KEY (`SessionID`)
    REFERENCES `PlaySessions` (`SessionID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `SrsServer`
-- -----------------------------------------------------
CREATE TABLE `SrsServer` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(32) NOT NULL,
  `server` varchar(128) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `server_uni` (`server`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `SrsServerStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SrsServerStatus` ;
CREATE TABLE `SrsServerStatus` (
  `id` int(11) NOT NULL,
  `server` varchar(128) NOT NULL,
  `count` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MEMORY DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `SubNetwork`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SubNetwork` ;

CREATE TABLE IF NOT EXISTS `SubNetwork` (
  `idSubNetwork` INT(11) NOT NULL,
  `NetMask` VARCHAR(50) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`idSubNetwork`),
  UNIQUE INDEX `idSubNetwork_UNIQUE` (`idSubNetwork` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `UserDevices`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `UserDevices` ;

CREATE TABLE IF NOT EXISTS `UserDevices` (
  `UserDevID` INT(11) NOT NULL AUTO_INCREMENT,
  `UserID` INT(11) NOT NULL,
  `DevID` VARCHAR(50) NOT NULL,
  `Pri` TINYINT(1) NOT NULL DEFAULT '0' COMMENT 'bit0: 用户可以使用的设备\nbit1: 用户可以管理的设备',
  PRIMARY KEY (`UserDevID`),
  UNIQUE KEY `UserDev` (`UserID`,`DevID`),
  INDEX `user_dev` (`DevID` ASC),
  INDEX `UserId` (`UserID` ASC),
  CONSTRAINT `UserId`
    FOREIGN KEY (`UserID`)
    REFERENCES `Users` (`User_ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `user_dev`
    FOREIGN KEY (`DevID`)
    REFERENCES `DeviceList` (`DevID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `tmp_result`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tmp_result` ;

CREATE TABLE IF NOT EXISTS `tmp_result` (
  `idtmp_result` INT(11) NULL DEFAULT NULL)
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `tmp_DelMediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tmp_DelMediaFiles` ;

CREATE TABLE IF NOT EXISTS `tmp_DelMediaFiles` (
  `filepath` VARCHAR(256) NOT NULL,
  PRIMARY KEY (`filepath`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `PwrDisplaySet`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `PwrDisplaySet` ;
CREATE TABLE `PwrDisplaySet` (
  `PwrID` TINYINT NOT NULL,
  `Name` VARCHAR(45) NULL,
  `Type` TINYINT NULL,
  PRIMARY KEY (`PwrID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `Timetable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Timetable` ;
CREATE TABLE `Timetable` (
  `Id` int(11) NOT NULL AUTO_INCREMENT,
  `DevId` varchar(50) NOT NULL,
  `UserId` int(11) NOT NULL,
  `WeekDay` tinyint(4) NOT NULL,
  `Start` datetime NOT NULL DEFAULT '9999-12-31 23:59:59',
  `End` datetime NOT NULL DEFAULT '0000-01-01 00:00:00',
  `Type` enum('normal','temporary') NOT NULL DEFAULT 'normal' COMMENT 'normal:正课\ntemporary:临课',
  `OneTime` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`Id`),
  UNIQUE KEY `only` (`DevId`, `UserId`,`WeekDay`,`Start`,`End`,`Type`),
  KEY `deviceId_idx` (`DevId`),
  KEY `table_idx` (`DevId`,`UserId`),
  KEY `userIdKey_idx` (`UserId`),
  CONSTRAINT `userIdKey` 
    FOREIGN KEY (`UserId`) 
    REFERENCES `Users` (`User_ID`) 
    ON DELETE CASCADE 
    ON UPDATE NO ACTION,
  CONSTRAINT `deviceIdKey` 
    FOREIGN KEY (`DevId`) 
    REFERENCES `DeviceList` (`DevID`) 
    ON DELETE NO ACTION 
    ON UPDATE NO ACTION
) 
ENGINE=InnoDB 
DEFAULT CHARSET=utf8 
COMMENT='课表';


-- -----------------------------------------------------
-- Table `IpCameraRtmp` 监控推流表
-- -----------------------------------------------------
DROP TABLE IF EXISTS `IpCameraRtmp` ;
CREATE TABLE `IpCameraRtmp` (
  `name` varchar(128) DEFAULT NULL COMMENT 'key经md5生成',
  `key` varchar(45) NOT NULL COMMENT 'rtmp节目key值，由摄像头Ip/端口/通道/主副码(main或sub)',
  `pushId` int(11) NOT NULL DEFAULT '-1' COMMENT 'ffmpeg推流ID',
  `pullCnt` int(11) NOT NULL DEFAULT '0' COMMENT 'rtmp拉流计数',
  `updateAt` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`key`),
  UNIQUE KEY `key_UNIQUE` (`key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
-- -----------------------------------------------------
-- Table `IpCall` IP呼叫表
-- -----------------------------------------------------
DROP TABLE IF EXISTS `IpCall` ;
CREATE TABLE `IpCall` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `device` varchar(45) DEFAULT NULL COMMENT 'device id',
  `waiter` int(11) DEFAULT NULL,
  `audioPort` int(11) DEFAULT NULL,
  `ringing` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `status` enum('ringing','talking','idle') DEFAULT 'ringing',
  `direction` enum('b2s','d2s') DEFAULT 'b2s',
  `webrtcUpdate` timestamp NULL DEFAULT NULL,
  `webrtcStatus` enum('running','error','ready','idle') DEFAULT 'idle',
  `wsPort` int(11) DEFAULT NULL COMMENT 'websocket listen port',
  PRIMARY KEY (`id`),
  UNIQUE KEY `port_unique` (`audioPort`),
  UNIQUE KEY `webrtcPort_UNIQUE` (`wsPort`)
) ENGINE=MEMORY DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `CallWaiter` 在线控制台表
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CallWaiter` ;
CREATE TABLE `CallWaiter` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user` int(11) NOT NULL,
  `session` varchar(45) NOT NULL,
  `updateAt` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `session_unique` (`session`)
) ENGINE=MEMORY DEFAULT CHARSET=utf8;
